@@ -1,12 +1,10 @@
 #!/usr/bin/python
+# -*- coding: utf-8 -*-
+
 # Copyright: Ansible Project
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
-
-
-DOCUMENTATION = r'''
+DOCUMENTATION = r"""
 ---
 module: ec2_instance_info
 version_added: 1.0.0
@@ -23,6 +21,7 @@ options:
     required: false
     type: list
     elements: str
+    default: []
   filters:
     description:
       - A dict of filters to apply. Each dict item consists of a filter key and a filter value. See
@@ -37,15 +36,38 @@ options:
     required: false
     aliases: ['uptime']
     type: int
-
+  include_attributes:
+    description:
+      - Describes the specified attributes of the returned instances.
+    required: false
+    type: list
+    elements: str
+    choices:
+    - instanceType
+    - kernel
+    - ramdisk
+    - userData
+    - disableApiTermination
+    - instanceInitiatedShutdownBehavior
+    - rootDeviceName
+    - blockDeviceMapping
+    - productCodes
+    - sourceDestCheck
+    - groupSet
+    - ebsOptimized
+    - sriovNetSupport
+    - enclaveOptions
+    - disableApiStop
+    aliases: ['attributes']
+    version_added: 6.3.0
 
 extends_documentation_fragment:
-- amazon.aws.aws
-- amazon.aws.ec2
+  - amazon.aws.common.modules
+  - amazon.aws.region.modules
+  - amazon.aws.boto3
+"""
 
-'''
-
-EXAMPLES = r'''
+EXAMPLES = r"""
 # Note: These examples do not set authentication details, see the AWS Guide for details.
 
 - name: Gather information about all instances
@@ -69,7 +91,7 @@ EXAMPLES = r'''
 - name: Gather information about any instance in states "shutting-down", "stopping", "stopped"
   amazon.aws.ec2_instance_info:
     filters:
-      instance-state-name: [ "shutting-down", "stopping", "stopped" ]
+      instance-state-name: ["shutting-down", "stopping", "stopped"]
 
 - name: Gather information about any instance with Name beginning with RHEL and an uptime of at least 60 minutes
   amazon.aws.ec2_instance_info:
@@ -77,14 +99,20 @@ EXAMPLES = r'''
     uptime: 60
     filters:
       "tag:Name": "RHEL-*"
-      instance-state-name: [ "running"]
+      instance-state-name: ["running"]
   register: ec2_node_info
 
-'''
+- name: Gather information about a particular instance using ID and include kernel attribute
+  amazon.aws.ec2_instance_info:
+    instance_ids:
+      - i-12345678
+    include_attributes:
+      - kernel
+"""
 
-RETURN = r'''
+RETURN = r"""
 instances:
-    description: a list of ec2 instances
+    description: A list of ec2 instances.
     returned: always
     type: complex
     contains:
@@ -94,7 +122,7 @@ instances:
             type: int
             sample: 0
         architecture:
-            description: The architecture of the image
+            description: The architecture of the image.
             returned: always
             type: str
             sample: x86_64
@@ -129,10 +157,18 @@ instances:
                             type: str
                             sample: attached
                         volume_id:
-                            description: The ID of the EBS volume
+                            description: The ID of the EBS volume.
                             returned: always
                             type: str
                             sample: vol-12345678
+        capacity_reservation_specification:
+            description: Information about the Capacity Reservation targeting option.
+            type: complex
+            contains:
+                capacity_reservation_preference:
+                    description: Describes the Capacity Reservation preferences.
+                    type: str
+                    sample: open
         cpu_options:
             description: The CPU options set for the instance.
             returned: always
@@ -153,11 +189,38 @@ instances:
             returned: always
             type: str
             sample: mytoken
+        current_instance_boot_mode:
+            description: The boot mode that is used to boot the instance at launch or start.
+            type: str
+            sample: legacy-bios
         ebs_optimized:
             description: Indicates whether the instance is optimized for EBS I/O.
             returned: always
             type: bool
             sample: false
+        ena_support:
+            description: Specifies whether enhanced networking with ENA is enabled.
+            returned: always
+            type: bool
+            sample: true
+        enclave_options:
+            description: Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves.
+            type: dict
+            contains:
+                enabled:
+                    description: If this parameter is set to true, the instance is enabled for Amazon Web Services Nitro Enclaves.
+                    returned: always
+                    type: bool
+                    sample: false
+        hibernation_options:
+            description: Indicates whether the instance is enabled for hibernation.
+            type: dict
+            contains:
+                configured:
+                    description: If true, your instance is enabled for hibernation; otherwise, it is not enabled for hibernation.
+                    returned: always
+                    type: bool
+                    sample: false
         hypervisor:
             description: The hypervisor type of the instance.
             returned: always
@@ -165,16 +228,15 @@ instances:
             sample: xen
         iam_instance_profile:
             description: The IAM instance profile associated with the instance, if applicable.
-            returned: always
             type: complex
             contains:
                 arn:
                     description: The Amazon Resource Name (ARN) of the instance profile.
                     returned: always
                     type: str
-                    sample: "arn:aws:iam::000012345678:instance-profile/myprofile"
+                    sample: "arn:aws:iam::123456789012:instance-profile/myprofile"
                 id:
-                    description: The ID of the instance profile
+                    description: The ID of the instance profile.
                     returned: always
                     type: str
                     sample: JFJ397FDG400FG9FD1N
@@ -203,6 +265,44 @@ instances:
             returned: always
             type: str
             sample: "2017-03-23T22:51:24+00:00"
+        maintenance_options:
+            description: Provides information on the recovery and maintenance options of your instance.
+            returned: always
+            type: dict
+            contains:
+                auto_recovery:
+                    description: Provides information on the current automatic recovery behavior of your instance.
+                    type: str
+                    sample: default
+        metadata_options:
+            description: The metadata options for the instance.
+            returned: always
+            type: complex
+            contains:
+                http_endpoint:
+                    description: Indicates whether the HTTP metadata endpoint on your instances is enabled or disabled.
+                    type: str
+                    sample: enabled
+                http_protocol_ipv6:
+                    description: Indicates whether the IPv6 endpoint for the instance metadata service is enabled or disabled.
+                    type: str
+                    sample: disabled
+                http_put_response_hop_limit:
+                    description: The maximum number of hops that the metadata token can travel.
+                    type: int
+                    sample: 1
+                http_tokens:
+                    description: Indicates whether IMDSv2 is required.
+                    type: str
+                    sample: optional
+                instance_metadata_tags:
+                    description: Indicates whether access to instance tags from the instance metadata is enabled or disabled.
+                    type: str
+                    sample: disabled
+                state:
+                    description: The state of the metadata option changes.
+                    type: str
+                    sample: applied
         monitoring:
             description: The monitoring for the instance.
             returned: always
@@ -263,6 +363,11 @@ instances:
                             returned: always
                             type: int
                             sample: 0
+                        network_card_index:
+                            description: The index of the network card.
+                            returned: always
+                            type: int
+                            sample: 0
                         status:
                             description: The attachment state.
                             returned: always
@@ -289,6 +394,11 @@ instances:
                             returned: always
                             type: str
                             sample: mygroup
+                interface_type:
+                    description: The type of network interface.
+                    returned: always
+                    type: str
+                    sample: interface
                 ipv6_addresses:
                     description: One or more IPv6 addresses associated with the network interface.
                     returned: always
@@ -315,6 +425,11 @@ instances:
                     returned: always
                     type: str
                     sample: 01234567890
+                private_dns_name:
+                    description: The private DNS hostname name assigned to the instance.
+                    type: str
+                    returned: always
+                    sample: ip-10-1-0-156.ec2.internal
                 private_ip_address:
                     description: The IPv4 address of the network interface within the subnet.
                     returned: always
@@ -328,7 +443,6 @@ instances:
                     contains:
                         association:
                             description: The association information for an Elastic IP address (IPv4) associated with the network interface.
-                            returned: always
                             type: complex
                             contains:
                                 ip_owner_id:
@@ -351,6 +465,11 @@ instances:
                             returned: always
                             type: bool
                             sample: true
+                        private_dns_name:
+                            description: The private DNS hostname name assigned to the instance.
+                            type: str
+                            returned: always
+                            sample: ip-10-1-0-156.ec2.internal
                         private_ip_address:
                             description: The private IPv4 address of the network interface.
                             returned: always
@@ -396,11 +515,32 @@ instances:
                     returned: always
                     type: str
                     sample: default
+        platform_details:
+            description: The platform details value for the instance.
+            returned: always
+            type: str
+            sample: Linux/UNIX
         private_dns_name:
             description: The private DNS name.
             returned: always
             type: str
             sample: ip-10-0-0-1.ap-southeast-2.compute.internal
+        private_dns_name_options:
+            description: The options for the instance hostname.
+            type: dict
+            contains:
+                enable_resource_name_dns_a_record:
+                    description: Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
+                    type: bool
+                    sample: false
+                enable_resource_name_dns_aaaa_record:
+                    description: Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
+                    type: bool
+                    sample: false
+                hostname_type:
+                    description: The type of hostname to assign to an instance.
+                    type: str
+                    sample: ip-name
         private_ip_address:
             description: The IPv4 address of the network interface within the subnet.
             returned: always
@@ -428,12 +568,12 @@ instances:
             type: str
             sample:
         public_ip_address:
-            description: The public IPv4 address assigned to the instance
+            description: The public IPv4 address assigned to the instance.
             returned: always
             type: str
             sample: 52.0.0.1
         root_device_name:
-            description: The device name of the root device
+            description: The device name of the root device.
             returned: always
             type: str
             sample: /dev/sda1
@@ -503,7 +643,21 @@ instances:
             returned: always
             type: dict
             sample: vpc-0011223344
-'''
+        attributes:
+            description: The details of the instance attribute specified on input.
+            returned: when include_attribute is specified
+            type: dict
+            sample:
+                {
+                    'disable_api_termination': {
+                        'value': True
+                    },
+                    'ebs_optimized': {
+                        'value': True
+                    }
+                }
+            version_added: 6.3.0
+"""
 
 import datetime
 
@@ -514,22 +668,21 @@ except ImportError:
 
 from ansible.module_utils.common.dict_transformations import camel_dict_to_snake_dict
 
-from ansible_collections.amazon.aws.plugins.module_utils.core import AnsibleAWSModule
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import AWSRetry
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import ansible_dict_to_boto3_filter_list
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import boto3_tag_list_to_ansible_dict
+from ansible_collections.amazon.aws.plugins.module_utils.modules import AnsibleAWSModule
+from ansible_collections.amazon.aws.plugins.module_utils.retries import AWSRetry
+from ansible_collections.amazon.aws.plugins.module_utils.tagging import boto3_tag_list_to_ansible_dict
+from ansible_collections.amazon.aws.plugins.module_utils.transformation import ansible_dict_to_boto3_filter_list
 
 
 @AWSRetry.jittered_backoff()
 def _describe_instances(connection, **params):
-    paginator = connection.get_paginator('describe_instances')
+    paginator = connection.get_paginator("describe_instances")
     return paginator.paginate(**params).build_full_result()
 
 
 def list_ec2_instances(connection, module):
-
     instance_ids = module.params.get("instance_ids")
-    uptime = module.params.get('minimum_uptime')
+    uptime = module.params.get("minimum_uptime")
     filters = ansible_dict_to_boto3_filter_list(module.params.get("filters"))
 
     try:
@@ -543,45 +696,80 @@ def list_ec2_instances(connection, module):
         timedelta = int(uptime) if uptime else 0
         oldest_launch_time = datetime.datetime.utcnow() - datetime.timedelta(minutes=timedelta)
         # Get instances from reservations
-        for reservation in reservations['Reservations']:
-            instances += [instance for instance in reservation['Instances'] if instance['LaunchTime'].replace(tzinfo=None) < oldest_launch_time]
+        for reservation in reservations["Reservations"]:
+            instances += [
+                instance
+                for instance in reservation["Instances"]
+                if instance["LaunchTime"].replace(tzinfo=None) < oldest_launch_time
+            ]
     else:
-        for reservation in reservations['Reservations']:
-            instances = instances + reservation['Instances']
+        for reservation in reservations["Reservations"]:
+            instances = instances + reservation["Instances"]
+
+    # include instances attributes
+    attributes = module.params.get("include_attributes")
+    if attributes:
+        for instance in instances:
+            instance["attributes"] = describe_instance_attributes(connection, instance["InstanceId"], attributes)
 
     # Turn the boto3 result in to ansible_friendly_snaked_names
     snaked_instances = [camel_dict_to_snake_dict(instance) for instance in instances]
 
     # Turn the boto3 result in to ansible friendly tag dictionary
     for instance in snaked_instances:
-        instance['tags'] = boto3_tag_list_to_ansible_dict(instance.get('tags', []), 'key', 'value')
+        instance["tags"] = boto3_tag_list_to_ansible_dict(instance.get("tags", []), "key", "value")
 
     module.exit_json(instances=snaked_instances)
 
 
-def main():
+def describe_instance_attributes(connection, instance_id, attributes):
+    result = {}
+    for attr in attributes:
+        response = connection.describe_instance_attribute(Attribute=attr, InstanceId=instance_id)
+        for key in response:
+            if key not in ("InstanceId", "ResponseMetadata"):
+                result[key] = response[key]
+    return result
 
+
+def main():
+    instance_attributes = [
+        "instanceType",
+        "kernel",
+        "ramdisk",
+        "userData",
+        "disableApiTermination",
+        "instanceInitiatedShutdownBehavior",
+        "rootDeviceName",
+        "blockDeviceMapping",
+        "productCodes",
+        "sourceDestCheck",
+        "groupSet",
+        "ebsOptimized",
+        "sriovNetSupport",
+        "enclaveOptions",
+        "disableApiStop",
+    ]
     argument_spec = dict(
-        minimum_uptime=dict(required=False, type='int', default=None, aliases=['uptime']),
-        instance_ids=dict(default=[], type='list', elements='str'),
-        filters=dict(default={}, type='dict')
+        minimum_uptime=dict(required=False, type="int", default=None, aliases=["uptime"]),
+        instance_ids=dict(default=[], type="list", elements="str"),
+        filters=dict(default={}, type="dict"),
+        include_attributes=dict(type="list", elements="str", aliases=["attributes"], choices=instance_attributes),
     )
 
     module = AnsibleAWSModule(
         argument_spec=argument_spec,
-        mutually_exclusive=[
-            ['instance_ids', 'filters']
-        ],
+        mutually_exclusive=[["instance_ids", "filters"]],
         supports_check_mode=True,
     )
 
     try:
-        connection = module.client('ec2')
+        connection = module.client("ec2")
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
-        module.fail_json_aws(e, msg='Failed to connect to AWS')
+        module.fail_json_aws(e, msg="Failed to connect to AWS")
 
     list_ec2_instances(connection, module)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
