@@ -20,9 +20,11 @@ options:
     resource_group:
         description:
             - Name of an Azure resource group.
+        type: str
     name:
         description:
             - Cosmos DB database account name.
+        type: str
     tags:
         description:
             - Limit results by providing a list of tags. Format tags as 'key' or 'key:value'.
@@ -49,17 +51,17 @@ author:
 '''
 
 EXAMPLES = '''
-  - name: Get instance of Database Account
-    azure_rm_cosmosdbaccount_info:
-      resource_group: myResourceGroup
-      name: testaccount
+- name: Get instance of Database Account
+  azure_rm_cosmosdbaccount_info:
+    resource_group: myResourceGroup
+    name: testaccount
 
-  - name: List instances of Database Account
-    azure_rm_cosmosdbaccount_info:
-      resource_group: myResourceGroup
-      tags:
-        - key
-        - key:value
+- name: List instances of Database Account
+  azure_rm_cosmosdbaccount_info:
+    resource_group: myResourceGroup
+    tags:
+      - key
+      - key:value
 '''
 
 RETURN = '''
@@ -302,7 +304,7 @@ accounts:
                     type: str
                     sample: "/subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/myResourceGroup/providers/Microsoft.Network/virtualNet
                              works/testvnet/subnets/testsubnet1"
-                ignore_missing_vnet_service_endpoint:
+                ignore_missing_v_net_service_endpoint:
                     description:
                         - Create Cosmos DB account without existing virtual network service endpoint.
                     type: bool
@@ -378,7 +380,7 @@ from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common
 from ansible.module_utils.common.dict_transformations import _camel_to_snake
 
 try:
-    from msrestazure.azure_exceptions import CloudError
+    from azure.core.exceptions import ResourceNotFoundError
     from azure.mgmt.cosmosdb import CosmosDBManagementClient
 except ImportError:
     # This is handled in azure_rm_common
@@ -446,7 +448,7 @@ class AzureRMCosmosDBAccountInfo(AzureRMModuleBase):
             response = self.mgmt_client.database_accounts.get(resource_group_name=self.resource_group,
                                                               account_name=self.name)
             self.log("Response : {0}".format(response))
-        except CloudError as e:
+        except ResourceNotFoundError as e:
             self.log('Could not get facts for Database Account.')
 
         if response and self.has_tags(response.tags, self.tags):
@@ -460,7 +462,7 @@ class AzureRMCosmosDBAccountInfo(AzureRMModuleBase):
         try:
             response = self.mgmt_client.database_accounts.list_by_resource_group(resource_group_name=self.resource_group)
             self.log("Response : {0}".format(response))
-        except CloudError as e:
+        except Exception as e:
             self.log('Could not get facts for Database Account.')
 
         if response is not None:
@@ -476,7 +478,7 @@ class AzureRMCosmosDBAccountInfo(AzureRMModuleBase):
         try:
             response = self.mgmt_client.database_accounts.list()
             self.log("Response : {0}".format(response))
-        except CloudError as e:
+        except Exception as e:
             self.log('Could not get facts for Database Account.')
 
         if response is not None:
