@@ -10,11 +10,6 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-ANSIBLE_METADATA = {'metadata_version': '1.1',
-                    'status': ['preview'],
-                    'supported_by': 'community'}
-
-
 DOCUMENTATION = '''
 ---
 module: azure_rm_networkinterface
@@ -35,21 +30,25 @@ options:
         description:
             - Name of a resource group where the network interface exists or will be created.
         required: true
+        type: str
     name:
         description:
             - Name of the network interface.
         required: true
+        type: str
     state:
         description:
             - Assert the state of the network interface. Use C(present) to create or update an interface and
               C(absent) to delete an interface.
         default: present
+        type: str
         choices:
             - absent
             - present
     location:
         description:
             - Valid Azure location. Defaults to location of the resource group.
+        type: str
     virtual_network:
         description:
             - An existing virtual network with which the network interface will be associated. Required when creating a network interface.
@@ -57,78 +56,58 @@ options:
             - Make sure your virtual network is in the same resource group as NIC when you give only the name.
             - It can be the virtual network's resource id.
             - It can be a dict which contains I(name) and I(resource_group) of the virtual network.
+            - Required when creating.
+        type: raw
         aliases:
             - virtual_network_name
-        required: true
     subnet_name:
         description:
             - Name of an existing subnet within the specified virtual network. Required when creating a network interface.
             - Use the C(virtual_network)'s resource group.
+            - Required when creating.
         aliases:
             - subnet
-        required: true
+        type: str
     os_type:
         description:
             - Determines any rules to be added to a default security group.
             - When creating a network interface, if no security group name is provided, a default security group will be created.
             - If the I(os_type=Windows), a rule allowing RDP access will be added.
             - If the I(os_type=Linux), a rule allowing SSH access will be added.
+        type: str
         choices:
             - Windows
             - Linux
         default: Linux
-    private_ip_address:
-        description:
-            - (Deprecate) Valid IPv4 address that falls within the specified subnet.
-            - This option will be deprecated in 2.9, use I(ip_configurations) instead.
-    private_ip_allocation_method:
-        description:
-            - (Deprecate) Whether or not the assigned IP address is permanent.
-            - When creating a network interface, if you specify I(private_ip_address=Static), you must provide a value for I(private_ip_address).
-            - You can update the allocation method to C(Static) after a dynamic private IP address has been assigned.
-            - This option will be deprecated in 2.9, use I(ip_configurations) instead.
-        default: Dynamic
-        choices:
-            - Dynamic
-            - Static
-    public_ip:
-        description:
-            - (Deprecate) When creating a network interface, if no public IP address name is provided a default public IP address will be created.
-            - Set to C(false) if you do not want a public IP address automatically created.
-            - This option will be deprecated in 2.9, use I(ip_configurations) instead.
-        type: bool
-        default: 'yes'
-    public_ip_address_name:
-        description:
-            - (Deprecate) Name of an existing public IP address object to associate with the security group.
-            - This option will be deprecated in 2.9, use I(ip_configurations) instead.
-        aliases:
-            - public_ip_address
-            - public_ip_name
-    public_ip_allocation_method:
-        description:
-            - (Deprecate) If a I(public_ip_address_name) is not provided, a default public IP address will be created.
-            - The allocation method determines whether or not the public IP address assigned to the network interface is permanent.
-            - This option will be deprecated in 2.9, use I(ip_configurations) instead.
-        choices:
-            - Dynamic
-            - Static
-        default: Dynamic
     ip_configurations:
         description:
             - List of IP configurations. Each configuration object should include
               field I(private_ip_address), I(private_ip_allocation_method), I(public_ip_address_name), I(public_ip), I(public_ip_allocation_method), I(name).
+        type: list
+        elements: dict
+        default: []
         suboptions:
             name:
                 description:
                     - Name of the IP configuration.
                 required: true
+                type: str
             private_ip_address:
                 description:
                     - Private IP address for the IP configuration.
+                type: str
+            private_ip_address_version:
+                description:
+                    - The version of the IP configuration.
+                type: str
+                choices:
+                    - IPv4
+                    - IPv6
+                default: IPv4
             private_ip_allocation_method:
                 description:
                     - Private IP allocation method.
+                type: str
                 choices:
                     - Dynamic
                     - Static
@@ -136,12 +115,14 @@ options:
             public_ip_address_name:
                 description:
                     - Name of the public IP address. None for disable IP address.
+                type: str
                 aliases:
                     - public_ip_address
                     - public_ip_name
             public_ip_allocation_method:
                 description:
                     - Public IP allocation method.
+                type: str
                 choices:
                     - Dynamic
                     - Static
@@ -151,6 +132,16 @@ options:
                     - List of existing load-balancer backend address pools to associate with the network interface.
                     - Can be written as a resource ID.
                     - Also can be a dict of I(name) and I(load_balancer).
+                type: list
+                elements: raw
+            application_gateway_backend_address_pools:
+                description:
+                    - List of existing application gateway backend address pools to associate with the network interface.
+                    - Can be written as a resource ID.
+                    - Also can be a dict of I(name) and I(application_gateway).
+                type: list
+                elements: raw
+                version_added: "1.10.0"
             primary:
                 description:
                     - Whether the IP configuration is the primary one in the list.
@@ -161,6 +152,8 @@ options:
                 description:
                     - List of application security groups in which the IP configuration is included.
                     - Element of the list could be a resource id of application security group, or dict of I(resource_group) and I(name).
+                type: list
+                elements: raw
     enable_accelerated_networking:
         description:
             - Whether the network interface should be created with the accelerated networking feature or not.
@@ -182,11 +175,14 @@ options:
             - It can be a dict contains security_group's I(name) and I(resource_group).
         aliases:
             - security_group_name
+        type: raw
     open_ports:
         description:
             - When a default security group is created for a Linux host a rule will be added allowing inbound TCP
               connections to the default SSH port C(22), and for a Windows host rules will be added allowing inbound
               access to RDP ports C(3389) and C(5986). Override the default ports by providing a list of open ports.
+        type: list
+        elements: str
     enable_ip_forwarding:
         description:
             - Whether to enable IP forwarding.
@@ -199,6 +195,7 @@ options:
             - Which DNS servers should the NIC lookup.
             - List of IP addresses.
         type: list
+        elements: str
 extends_documentation_fragment:
     - azure.azcollection.azure
     - azure.azcollection.azure_tags
@@ -210,108 +207,122 @@ author:
 '''
 
 EXAMPLES = '''
-    - name: Create a network interface with minimal parameters
-      azure_rm_networkinterface:
-        name: nic001
-        resource_group: myResourceGroup
-        virtual_network: vnet001
-        subnet_name: subnet001
-        ip_configurations:
-          - name: ipconfig1
-            public_ip_address_name: publicip001
-            primary: True
+- name: Create a network interface with minimal parameters
+  azure_rm_networkinterface:
+    name: nic001
+    resource_group: myResourceGroup
+    virtual_network: vnet001
+    subnet_name: subnet001
+    ip_configurations:
+      - name: ipconfig1
+        public_ip_address_name: publicip001
+        primary: true
 
-    - name: Create a network interface with private IP address only (no Public IP)
-      azure_rm_networkinterface:
-        name: nic001
-        resource_group: myResourceGroup
-        virtual_network: vnet001
-        subnet_name: subnet001
-        create_with_security_group: False
-        ip_configurations:
-          - name: ipconfig1
-            primary: True
+- name: Create a network interface with private IP address only (no Public IP)
+  azure_rm_networkinterface:
+    name: nic001
+    resource_group: myResourceGroup
+    virtual_network: vnet001
+    subnet_name: subnet001
+    create_with_security_group: false
+    ip_configurations:
+      - name: ipconfig1
+        primary: true
 
-    - name: Create a network interface for use in a Windows host (opens RDP port) with custom RDP port
-      azure_rm_networkinterface:
-        name: nic002
-        resource_group: myResourceGroup
-        virtual_network: vnet001
-        subnet_name: subnet001
-        os_type: Windows
-        rdp_port: 3399
-        security_group: "/subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroup/myResourceGroup/providers/Microsoft.Network/networkSecurit
-                         yGroups/nsg001"
-        ip_configurations:
-          - name: ipconfig1
-            public_ip_address_name: publicip001
-            primary: True
+- name: Create a network interface for use in a Windows host (opens RDP port) with custom RDP port
+  azure_rm_networkinterface:
+    name: nic002
+    resource_group: myResourceGroup
+    virtual_network: vnet001
+    subnet_name: subnet001
+    os_type: Windows
+    rdp_port: 3399
+    security_group: "/subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroup/myResourceGroup/providers/Microsoft.Network/networkSecurit
+                     yGroups/nsg001"
+    ip_configurations:
+      - name: ipconfig1
+        public_ip_address_name: publicip001
+        primary: true
 
-    - name: Create a network interface using existing security group and public IP
-      azure_rm_networkinterface:
-        name: nic003
-        resource_group: myResourceGroup
-        virtual_network: vnet001
-        subnet_name: subnet001
-        security_group: secgroup001
-        ip_configurations:
-          - name: ipconfig1
-            public_ip_address_name: publicip001
-            primary: True
+- name: Create a network interface using existing security group and public IP
+  azure_rm_networkinterface:
+    name: nic003
+    resource_group: myResourceGroup
+    virtual_network: vnet001
+    subnet_name: subnet001
+    security_group: secgroup001
+    ip_configurations:
+      - name: ipconfig1
+        public_ip_address_name: publicip001
+        primary: true
 
-    - name: Create a network with multiple ip configurations
-      azure_rm_networkinterface:
-        name: nic004
-        resource_group: myResourceGroup
-        subnet_name: subnet001
-        virtual_network: vnet001
-        security_group:
-          name: testnic002
-          resource_group: Testing1
-        ip_configurations:
-          - name: ipconfig1
-            public_ip_address_name: publicip001
-            primary: True
-          - name: ipconfig2
-            load_balancer_backend_address_pools:
-              - "{{ loadbalancer001.state.backend_address_pools[0].id }}"
-              - name: backendaddrpool1
-                load_balancer: loadbalancer001
+- name: Create a network with multiple ip configurations
+  azure_rm_networkinterface:
+    name: nic004
+    resource_group: myResourceGroup
+    subnet_name: subnet001
+    virtual_network: vnet001
+    security_group:
+      name: testnic002
+      resource_group: Testing1
+    ip_configurations:
+      - name: ipconfig1
+        public_ip_address_name: publicip001
+        primary: true
+      - name: ipconfig2
+        load_balancer_backend_address_pools:
+          - "{{ loadbalancer001.state.backend_address_pools[0].id }}"
+          - name: backendaddrpool1
+            load_balancer: loadbalancer001
 
-    - name: Create a network interface in accelerated networking mode
-      azure_rm_networkinterface:
-        name: nic005
-        resource_group: myResourceGroup
-        virtual_network_name: vnet001
-        subnet_name: subnet001
-        enable_accelerated_networking: True
+- name: Create network interface attached to application gateway backend address pool
+  azure_rm_networkinterface:
+    name: nic-appgw
+    resource_group: myResourceGroup
+    virtual_network: vnet001
+    subnet_name: subnet001
+    create_with_security_group: false
+    ip_configurations:
+      - name: default
+        primary: true
+        application_gateway_backend_address_pools:
+          - name: myApplicationGatewayBackendAddressPool
+            application_gateway: myApplicationGateway
 
-    - name: Create a network interface with IP forwarding
-      azure_rm_networkinterface:
-        name: nic001
-        resource_group: myResourceGroup
-        virtual_network: vnet001
-        subnet_name: subnet001
-        ip_forwarding: True
-        ip_configurations:
-          - name: ipconfig1
-            public_ip_address_name: publicip001
-            primary: True
+- name: Create a network interface in accelerated networking mode
+  azure_rm_networkinterface:
+    name: nic005
+    resource_group: myResourceGroup
+    virtual_network_name: vnet001
+    subnet_name: subnet001
+    enable_accelerated_networking: true
 
-    - name: Create a network interface with dns servers
-      azure_rm_networkinterface:
-        name: nic009
-        resource_group: myResourceGroup
-        virtual_network: vnet001
-        subnet_name: subnet001
-        dns_servers:
-          - 8.8.8.8
+- name: Create a network interface with IP forwarding
+  azure_rm_networkinterface:
+    name: nic001
+    resource_group: myResourceGroup
+    virtual_network: vnet001
+    subnet_name: subnet001
+    ip_forwarding: true
+    ip_configurations:
+      - name: ipconfig1
+        public_ip_address_name: publicip001
+        primary: true
 
-    - name: Delete network interface
-      azure_rm_networkinterface:
-        resource_group: myResourceGroup
-        name: nic003
-        state: absent
+- name: Create a network interface with dns servers
+  azure_rm_networkinterface:
+    name: nic009
+    resource_group: myResourceGroup
+    virtual_network: vnet001
+    subnet_name: subnet001
+    dns_servers:
+      - 8.8.8.8
+
+- name: Delete network interface
+  azure_rm_networkinterface:
+    resource_group: myResourceGroup
+    name: nic003
+    state: absent
 '''
 
 RETURN = '''
@@ -372,13 +383,25 @@ state:
                     sample: default
                 load_balancer_backend_address_pools:
                     description:
-                        - List of existing load-balancer backend address pools to associate with the network interface.
+                        - List of existing load-balancer backend address pools associated with the network interface.
                     type: list
+                application_gateway_backend_address_pools:
+                    description:
+                        - List of existing application gateway backend address pool resource IDs associated with the network interface.
+                    type: list
+                    version_added: "1.10.0"
+                    sample: ["/subscriptions/xxx/resourceGroups/myResourceGroup/providers/Microsoft.Network/applicationGateways/myGateway/
+                        backendAddressPools/myBackendAddressPool"]
                 private_ip_address:
                     description:
                         - Private IP address for the IP configuration.
                     type: str
                     sample: "10.1.0.10"
+                private_ip_address_version:
+                    description:
+                        - The version of the IP configuration.
+                    type: str
+                    sample: "IPv4"
                 private_ip_allocation_method:
                     description:
                         - Private IP allocation method.
@@ -450,8 +473,8 @@ state:
 '''
 
 try:
-    from msrestazure.tools import parse_resource_id, resource_id, is_valid_resource_id
-    from msrestazure.azure_exceptions import CloudError
+    from azure.mgmt.core.tools import resource_id, is_valid_resource_id
+    from azure.core.exceptions import ResourceNotFoundError
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -479,11 +502,14 @@ def nic_to_dict(nic):
         dict(
             name=config.name,
             private_ip_address=config.private_ip_address,
+            private_ip_address_version=config.private_ip_address_version,
             private_ip_allocation_method=config.private_ip_allocation_method,
             subnet=subnet_to_dict(config.subnet),
-            primary=config.primary,
+            primary=config.primary if config.primary else False,
             load_balancer_backend_address_pools=([item.id for item in config.load_balancer_backend_address_pools]
                                                  if config.load_balancer_backend_address_pools else None),
+            application_gateway_backend_address_pools=([item.id for item in config.application_gateway_backend_address_pools]
+                                                       if config.application_gateway_backend_address_pools else None),
             public_ip_address=dict(
                 id=config.public_ip_address.id,
                 name=azure_id_to_dict(config.public_ip_address.id).get('publicIPAddresses'),
@@ -523,10 +549,12 @@ def nic_to_dict(nic):
 ip_configuration_spec = dict(
     name=dict(type='str', required=True),
     private_ip_address=dict(type='str'),
+    private_ip_address_version=dict(type='str', choices=['IPv4', 'IPv6'], default='IPv4'),
     private_ip_allocation_method=dict(type='str', choices=['Dynamic', 'Static'], default='Dynamic'),
     public_ip_address_name=dict(type='str', aliases=['public_ip_address', 'public_ip_name']),
     public_ip_allocation_method=dict(type='str', choices=['Dynamic', 'Static'], default='Dynamic'),
-    load_balancer_backend_address_pools=dict(type='list'),
+    load_balancer_backend_address_pools=dict(type='list', elements='raw'),
+    application_gateway_backend_address_pools=dict(type='list', elements='raw'),
     primary=dict(type='bool', default=False),
     application_security_groups=dict(type='list', elements='raw')
 )
@@ -544,18 +572,13 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
             create_with_security_group=dict(type='bool', default=True),
             security_group=dict(type='raw', aliases=['security_group_name']),
             state=dict(default='present', choices=['present', 'absent']),
-            private_ip_address=dict(type='str'),
-            private_ip_allocation_method=dict(type='str', choices=['Dynamic', 'Static'], default='Dynamic'),
-            public_ip_address_name=dict(type='str', aliases=['public_ip_address', 'public_ip_name']),
-            public_ip=dict(type='bool', default=True),
             subnet_name=dict(type='str', aliases=['subnet']),
             virtual_network=dict(type='raw', aliases=['virtual_network_name']),
-            public_ip_allocation_method=dict(type='str', choices=['Dynamic', 'Static'], default='Dynamic'),
-            ip_configurations=dict(type='list', default=None, elements='dict', options=ip_configuration_spec),
+            ip_configurations=dict(type='list', default=[], elements='dict', options=ip_configuration_spec),
             os_type=dict(type='str', choices=['Windows', 'Linux'], default='Linux'),
-            open_ports=dict(type='list'),
+            open_ports=dict(type='list', elements='str'),
             enable_ip_forwarding=dict(type='bool', aliases=['ip_forwarding'], default=False),
-            dns_servers=dict(type='list'),
+            dns_servers=dict(type='list', elements='str'),
         )
 
         required_if = [
@@ -568,13 +591,8 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
         self.create_with_security_group = None
         self.enable_accelerated_networking = None
         self.security_group = None
-        self.private_ip_address = None
-        self.private_ip_allocation_method = None
-        self.public_ip_address_name = None
-        self.public_ip = None
         self.subnet_name = None
         self.virtual_network = None
-        self.public_ip_allocation_method = None
         self.state = None
         self.tags = None
         self.os_type = None
@@ -633,17 +651,13 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
                     if len(asgs) > 0:
                         config['application_security_groups'] = asgs
 
+        # If ip_confiurations is not specified then provide the default
+        # private interface
         if self.state == 'present' and not self.ip_configurations:
-            # construct the ip_configurations array for compatible
-            self.deprecate('Setting ip_configuration flatten is deprecated and will be removed.'
-                           ' Using ip_configurations list to define the ip configuration', version=(2, 9))
             self.ip_configurations = [
                 dict(
-                    private_ip_address=self.private_ip_address,
-                    private_ip_allocation_method=self.private_ip_allocation_method,
-                    public_ip_address_name=self.public_ip_address_name if self.public_ip else None,
-                    public_ip_allocation_method=self.public_ip_allocation_method,
                     name='default',
+                    private_ip_allocation_method='Dynamic',
                     primary=True
                 )
             ]
@@ -714,14 +728,23 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
                 # name, private_ip_address, public_ip_address_name, private_ip_allocation_method, subnet_name
                 ip_configuration_result = self.construct_ip_configuration_set(results['ip_configurations'])
                 ip_configuration_request = self.construct_ip_configuration_set(self.ip_configurations)
-                if ip_configuration_result != ip_configuration_request:
-                    self.log("CHANGED: network interface {0} ip configurations".format(self.name))
-                    changed = True
+                ip_configuration_result_name = [item['name'] for item in ip_configuration_result]
+                for item_request in ip_configuration_request:
+                    if item_request['name'] not in ip_configuration_result_name:
+                        changed = True
+                        break
+                    else:
+                        for item_result in ip_configuration_result:
+                            if len(ip_configuration_request) == 1 and len(ip_configuration_result) == 1:
+                                item_request['primary'] = True
+                            if item_request['name'] == item_result['name'] and item_request != item_result:
+                                changed = True
+                                break
 
             elif self.state == 'absent':
                 self.log("CHANGED: network interface {0} exists but requested state is 'absent'".format(self.name))
                 changed = True
-        except CloudError:
+        except ResourceNotFoundError:
             self.log('Network interface {0} does not exist'.format(self.name))
             if self.state == 'present':
                 self.log("CHANGED: network interface {0} does not exist but requested state is 'present'".format(self.name))
@@ -737,7 +760,7 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
             if self.state == 'present':
                 subnet = self.network_models.SubResource(
                     id='/subscriptions/{0}/resourceGroups/{1}/providers/Microsoft.Network/virtualNetworks/{2}/subnets/{3}'.format(
-                        self.virtual_network['subscription_id'],
+                        self.virtual_network['subscription'] if self.virtual_network.get('subscription') else self.virtual_network['subscription_id'],
                         self.virtual_network['resource_group'],
                         self.virtual_network['name'],
                         self.subnet_name))
@@ -746,12 +769,17 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
                     self.network_models.NetworkInterfaceIPConfiguration(
                         private_ip_allocation_method=ip_config.get('private_ip_allocation_method'),
                         private_ip_address=ip_config.get('private_ip_address'),
+                        private_ip_address_version=ip_config.get('private_ip_address_version'),
                         name=ip_config.get('name'),
                         subnet=subnet,
                         public_ip_address=self.get_or_create_public_ip_address(ip_config),
                         load_balancer_backend_address_pools=([self.network_models.BackendAddressPool(id=self.backend_addr_pool_id(bap_id))
                                                               for bap_id in ip_config.get('load_balancer_backend_address_pools')]
                                                              if ip_config.get('load_balancer_backend_address_pools') else None),
+                        application_gateway_backend_address_pools=([self.network_models.ApplicationGatewayBackendAddressPool
+                                                                    (id=self.gateway_backend_addr_pool_id(bap_id))
+                                                                    for bap_id in ip_config.get('application_gateway_backend_address_pools')]
+                                                                   if ip_config.get('application_gateway_backend_address_pools') else None),
                         primary=ip_config.get('primary'),
                         application_security_groups=([self.network_models.ApplicationSecurityGroup(id=asg_id)
                                                       for asg_id in ip_config.get('application_security_groups')]
@@ -791,7 +819,7 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
     def get_or_create_public_ip_address(self, ip_config):
         name = ip_config.get('public_ip_address_name')
 
-        if not (self.public_ip and name):
+        if not name:
             return None
 
         pip = self.get_public_ip_address(name)
@@ -801,15 +829,15 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
                 public_ip_allocation_method=ip_config.get('public_ip_allocation_method'),
             )
             try:
-                poller = self.network_client.public_ip_addresses.create_or_update(self.resource_group, name, params)
+                poller = self.network_client.public_ip_addresses.begin_create_or_update(self.resource_group, name, params)
                 pip = self.get_poller_result(poller)
-            except CloudError as exc:
+            except Exception as exc:
                 self.fail("Error creating {0} - {1}".format(name, str(exc)))
         return pip
 
     def create_or_update_nic(self, nic):
         try:
-            poller = self.network_client.network_interfaces.create_or_update(self.resource_group, self.name, nic)
+            poller = self.network_client.network_interfaces.begin_create_or_update(self.resource_group, self.name, nic)
             new_nic = self.get_poller_result(poller)
             return nic_to_dict(new_nic)
         except Exception as exc:
@@ -817,7 +845,7 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
 
     def delete_nic(self):
         try:
-            poller = self.network_client.network_interfaces.delete(self.resource_group, self.name)
+            poller = self.network_client.network_interfaces.begin_delete(self.resource_group, self.name)
             self.get_poller_result(poller)
         except Exception as exc:
             self.fail("Error deleting network interface {0} - {1}".format(self.name, str(exc)))
@@ -827,14 +855,14 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
         self.log("Fetching public ip address {0}".format(name))
         try:
             return self.network_client.public_ip_addresses.get(self.resource_group, name)
-        except Exception as exc:
+        except ResourceNotFoundError as exc:
             return None
 
     def get_security_group(self, resource_group, name):
         self.log("Fetching security group {0}".format(name))
         try:
             return self.network_client.network_security_groups.get(resource_group, name)
-        except Exception as exc:
+        except ResourceNotFoundError as exc:
             return None
 
     def backend_addr_pool_id(self, val):
@@ -851,8 +879,22 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
                                    child_name_1=name)
         return val
 
+    def gateway_backend_addr_pool_id(self, val):
+        if isinstance(val, dict):
+            appgw = val.get('application_gateway', None)
+            name = val.get('name', None)
+            if appgw and name:
+                return resource_id(subscription=self.subscription_id,
+                                   resource_group=self.resource_group,
+                                   namespace='Microsoft.Network',
+                                   type='applicationGateways',
+                                   name=appgw,
+                                   child_type_1='backendAddressPools',
+                                   child_name_1=name)
+        return val
+
     def construct_ip_configuration_set(self, raw):
-        configurations = [str(dict(
+        configurations = [dict(
             private_ip_allocation_method=to_native(item.get('private_ip_allocation_method')),
             public_ip_address_name=(to_native(item.get('public_ip_address').get('name'))
                                     if item.get('public_ip_address') else to_native(item.get('public_ip_address_name'))),
@@ -860,11 +902,14 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
             load_balancer_backend_address_pools=(set([to_native(self.backend_addr_pool_id(id))
                                                       for id in item.get('load_balancer_backend_address_pools')])
                                                  if item.get('load_balancer_backend_address_pools') else None),
+            application_gateway_backend_address_pools=(set([to_native(self.gateway_backend_addr_pool_id(id))
+                                                           for id in item.get('application_gateway_backend_address_pools')])
+                                                       if item.get('application_gateway_backend_address_pools') else None),
             application_security_groups=(set([to_native(asg_id) for asg_id in item.get('application_security_groups')])
                                          if item.get('application_security_groups') else None),
             name=to_native(item.get('name'))
-        )) for item in raw]
-        return set(configurations)
+        ) for item in raw]
+        return configurations
 
 
 def main():
