@@ -17,6 +17,7 @@ from ansible.module_utils.common import validation
 from abc import ABCMeta, abstractmethod
 try:
     import logging
+    import ipaddress
 except ImportError:
     LOGGING_IN_STANDARD = False
 else:
@@ -28,6 +29,7 @@ import json
 import inspect
 import re
 import socket
+import time
 
 
 class DnacBase():
@@ -66,6 +68,7 @@ class DnacBase():
                                         'parsed': self.verify_diff_parsed
                                         }
         self.dnac_log = dnac_params.get("dnac_log")
+        self.max_timeout = self.params.get('dnac_api_task_timeout')
 
         if self.dnac_log and not DnacBase.__is_log_init:
             self.dnac_log_level = dnac_params.get("dnac_log_level") or 'WARNING'
@@ -78,9 +81,10 @@ class DnacBase():
             self.logger = logging.getLogger('logger')
             DnacBase.__is_log_init = True
             self.log('Logging configured and initiated', "DEBUG")
-        elif not self.dnac_log:
+        else:
             # If dnac_log is False, return an empty logger
             self.logger = logging.getLogger('empty_logger')
+            self.logger.addHandler(logging.NullHandler())
 
         self.log('Cisco Catalyst Center parameters: {0}'.format(dnac_params), "DEBUG")
         self.supported_states = ["merged", "deleted", "replaced", "overridden", "gathered", "rendered", "parsed"]
@@ -228,11 +232,11 @@ class DnacBase():
         # self.log("status: {0}, msg:{1}".format(self.status, self.msg), frameIncrement=1)
         self.log("status: {0}, msg: {1}".format(self.status, self.msg), "DEBUG")
         if "failed" in self.status:
-            self.module.fail_json(msg=self.msg, response=[])
+            self.module.fail_json(msg=self.msg, response=self.result.get('response', []))
         elif "exited" in self.status:
             self.module.exit_json(**self.result)
         elif "invalid" in self.status:
-            self.module.fail_json(msg=self.msg, response=[])
+            self.module.fail_json(msg=self.msg, response=self.result.get('response', []))
 
     def is_valid_password(self, password):
         """
@@ -255,6 +259,30 @@ class DnacBase():
 
         return re.match(pattern, password) is not None
 
+    def is_valid_email(self, email):
+        """
+        Validate an email address.
+        Args:
+            self (object): An instance of a class that provides access to Cisco Catalyst Center.
+            email (str): The email address to be validated.
+        Returns:
+            bool: True if the email is valid, False otherwise.
+        Description:
+            This function checks if the provided email address is valid based on the following criteria:
+            - It contains one or more alphanumeric characters or allowed special characters before the '@'.
+            - It contains one or more alphanumeric characters or dashes after the '@' and before the domain.
+            - It contains a period followed by at least two alphabetic characters at the end of the string.
+        The allowed special characters before the '@' are: ._%+-.
+        """
+
+        # Define the regex pattern for a valid email address
+        pattern = r'^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$'
+        # Use re.match to see if the email matches the pattern
+        if re.match(pattern, email):
+            return True
+        else:
+            return False
+
     def get_dnac_params(self, params):
         """Store the Cisco Catalyst Center parameters from the playbook"""
 
@@ -299,14 +327,31 @@ class DnacBase():
 
         return result
 
-    def check_task_response_status(self, response, validation_string, data=False):
+    def get_device_details_limit(self):
+        """
+        Retrieves the limit for 'get_device_list' API to collect the device details..
+        Parameters:
+            self (object): An instance of a class that provides access to Cisco Catalyst Center.
+        Returns:
+            int: The limit for 'get_device_list' api device details, which is set to 500 by default.
+        Description:
+            This method returns a predefined limit for the number of device details that can be processed or retrieved
+            from 'get_device_list' api. Currently, the limit is set to a fixed value of 500.
+        """
+
+        api_response_limit = 500
+        return api_response_limit
+
+    def check_task_response_status(self, response, validation_string, api_name, data=False):
         """
         Get the site id from the site name.
 
         Parameters:
             self - The current object details.
             response (dict) - API response.
-            validation_string (string) - String used to match the progress status.
+            validation_string (str) - String used to match the progress status.
+            api_name (str) - API name.
+            data (bool) - Set to True if the API is returning any information. Else, False.
 
         Returns:
             self
@@ -329,13 +374,27 @@ class DnacBase():
             return self
 
         task_id = response.get("taskId")
+        start_time = time.time()
         while True:
+            end_time = time.time()
+            if (end_time - start_time) >= self.max_timeout:
+                self.msg = "Max timeout of {max_timeout} sec has reached for the task id '{task_id}'. " \
+                           .format(max_timeout=self.max_timeout, task_id=task_id) + \
+                           "Exiting the loop due to unexpected API '{api_name}' status.".format(api_name=api_name)
+                self.log(self.msg, "WARNING")
+                self.status = "failed"
+                break
+
             task_details = self.get_task_details(task_id)
             self.log('Getting task details from task ID {0}: {1}'.format(task_id, task_details), "DEBUG")
 
             if task_details.get("isError") is True:
                 if task_details.get("failureReason"):
                     self.msg = str(task_details.get("failureReason"))
+                    string_check = "check task tree"
+                    if string_check in self.msg.lower():
+                        time.sleep(self.params.get('dnac_task_poll_interval'))
+                        self.msg = self.check_task_tree_response(task_id)
                 else:
                     self.msg = str(task_details.get("progress"))
                 self.status = "failed"
@@ -348,7 +407,7 @@ class DnacBase():
                 self.status = "success"
                 break
 
-            self.log("progress set to {0} for taskid: {1}".format(task_details.get('progress'), task_id), "DEBUG")
+            self.log("Progress is {0} for task ID: {1}".format(task_details.get('progress'), task_id), "DEBUG")
 
         return self
 
@@ -378,12 +437,13 @@ class DnacBase():
         self.log("Response for the current execution: {0}".format(response))
         return response
 
-    def check_execution_response_status(self, response):
+    def check_execution_response_status(self, response, api_name):
         """
         Checks the reponse status provided by API in the Cisco Catalyst Center
 
         Parameters:
             response (dict) - API response
+            api_name (str) - API name
 
         Returns:
             self
@@ -399,9 +459,19 @@ class DnacBase():
             self.status = "failed"
             return self
 
-        executionid = response.get("executionId")
+        execution_id = response.get("executionId")
+        start_time = time.time()
         while True:
-            execution_details = self.get_execution_details(executionid)
+            end_time = time.time()
+            if (end_time - start_time) >= self.max_timeout:
+                self.msg = "Max timeout of {max_timeout} sec has reached for the execution id '{execution_id}'. "\
+                           .format(max_timeout=self.max_timeout, execution_id=execution_id) + \
+                           "Exiting the loop due to unexpected API '{api_name}' status.".format(api_name=api_name)
+                self.log(self.msg, "WARNING")
+                self.status = "failed"
+                break
+
+            execution_details = self.get_execution_details(execution_id)
             if execution_details.get("status") == "SUCCESS":
                 self.result['changed'] = True
                 self.msg = "Successfully executed"
@@ -510,6 +580,79 @@ class DnacBase():
         except socket.error:
             return False
 
+    def check_status_api_events(self, status_execution_id):
+        """
+        Checks the status of API events in Cisco Catalyst Center until completion or timeout.
+        Args:
+            self (object): An instance of a class used for interacting with Cisco Catalyst Center.
+            status_execution_id (str): The execution ID for the event to check the status.
+        Returns:
+            dict or None: The response from the API once the status is no longer "IN_PROGRESS",
+                        or None if the maximum timeout is reached.
+        Description:
+            This method repeatedly checks the status of an API event in Cisco Catalyst Center using the provided
+            execution ID. The status is checked at intervals specified by the 'dnac_task_poll_interval' parameter
+            until the status is no longer "IN_PROGRESS" or the maximum timeout ('dnac_api_task_timeout') is reached.
+            If the status becomes anything other than "IN_PROGRESS" before the timeout, the method returns the
+            response from the API. If the timeout is reached first, the method logs a warning and returns None.
+        """
+
+        events_response = None
+        start_time = time.time()
+
+        while True:
+            end_time = time.time()
+            if (end_time - start_time) >= self.max_timeout:
+                self.log("""Max timeout of {0} sec has reached for the execution id '{1}' for the event and unexpected
+                        api status so moving out of the loop.""".format(self.max_timeout, status_execution_id), "WARNING")
+                break
+            # Now we check the status of API Events for configuring destination and notifications
+            response = self.dnac._exec(
+                family="event_management",
+                function='get_status_api_for_events',
+                op_modifies=True,
+                params={"execution_id": status_execution_id}
+            )
+            self.log("Received API response from 'get_status_api_for_events': {0}".format(str(response)), "DEBUG")
+            if response['apiStatus'] != "IN_PROGRESS":
+                events_response = response
+                break
+            time.sleep(self.params.get('dnac_task_poll_interval'))
+
+        return events_response
+
+    def is_valid_server_address(self, server_address):
+        """
+        Validates the server address to check if it's a valid IPv4, IPv6 address, or a valid hostname.
+        Args:
+            self (object): An instance of a class used for interacting with Cisco Catalyst Center.
+            server_address (str): The server address to validate.
+        Returns:
+            bool: True if the server address is valid, otherwise False.
+        """
+        # Check if the address is a valid IPv4 or IPv6 address
+        try:
+            ipaddress.ip_address(server_address)
+            return True
+        except ValueError:
+            pass
+
+        # Define the regex for a valid hostname
+        hostname_regex = re.compile(
+            r'^('  # Start of the string
+            r'([A-Za-z0-9]+([A-Za-z0-9-]*[A-Za-z0-9])?\.)+[A-Za-z]{2,6}|'  # Domain name (e.g., example.com)
+            r'localhost|'  # Localhost
+            r'(\d{1,3}\.)+\d{1,3}|'  # Custom IPv4-like format (e.g., 2.2.3.31.3.4.4)
+            r'[A-Fa-f0-9:]+$'  # IPv6 address (e.g., 2f8:192:3::40:41:41:42)
+            r')$'  # End of the string
+        )
+
+        # Check if the address is a valid hostname
+        if hostname_regex.match(server_address):
+            return True
+
+        return False
+
     def is_path_exists(self, file_path):
         """
         Check if the file path 'file_path' exists or not.
@@ -521,7 +664,11 @@ class DnacBase():
             True/False (bool) - True if the file path exists, else False.
         """
 
-        if not os.path.exists(file_path):
+        current_working_directory = os.getcwd()
+        final_file_path = os.path.join(current_working_directory, file_path)
+        self.log(str(final_file_path))
+        if not os.path.exists(final_file_path):
+            self.log("The specified path '{0}' is not valid. Please provide a valid path.".format(final_file_path), "ERROR")
             return False
 
         return True
@@ -546,6 +693,37 @@ class DnacBase():
             self.log("The provided file '{0}' is not in JSON format".format(file_path), "CRITICAL")
             return False
 
+    def check_task_tree_response(self, task_id):
+        """
+        Returns the task tree response of the task ID.
+
+        Parameters:
+            task_id (string) - The unique identifier of the task for which you want to retrieve details.
+
+        Returns:
+            error_msg (str) - Returns the task tree error message of the task ID.
+        """
+
+        response = self.dnac._exec(
+            family="task",
+            function='get_task_tree',
+            params={"task_id": task_id}
+        )
+        self.log("Retrieving task tree details by the API 'get_task_tree' using task ID: {task_id}, Response: {response}"
+                 .format(task_id=task_id, response=response), "DEBUG")
+        error_msg = ""
+        if response and isinstance(response, dict):
+            result = response.get('response')
+            error_messages = []
+            for item in result:
+                if item.get("isError") is True:
+                    error_messages.append(item.get("progress"))
+
+            if error_messages:
+                error_msg = ". ".join(error_messages) + "."
+
+        return error_msg
+
 
 def is_list_complex(x):
     return isinstance(x[0], dict) or isinstance(x[0], list)
@@ -871,10 +1049,15 @@ def validate_list_of_dicts(param_list, spec, module=None):
     return normalized, invalid_params
 
 
+RATE_LIMIT_MESSAGE = "Rate Limit exceeded"
+RATE_LIMIT_RETRY_AFTER = 15
+
+
 class DNACSDK(object):
     def __init__(self, params):
         self.result = dict(changed=False, result="")
         self.validate_response_schema = params.get("validate_response_schema")
+        self.logger = logging.getLogger('dnacentersdk')
         if DNAC_SDK_IS_INSTALLED:
             self.api = api.DNACenterAPI(
                 username=params.get("dnac_username"),
@@ -887,7 +1070,7 @@ class DNACSDK(object):
                 debug=params.get("dnac_debug"),
             )
             if params.get("dnac_debug") and LOGGING_IN_STANDARD:
-                logging.getLogger('dnacentersdk').addHandler(logging.StreamHandler())
+                self.logger.addHandler(logging.StreamHandler())
         else:
             self.fail_json(msg="DNA Center Python SDK is not installed. Execute 'pip install dnacentersdk'")
 
@@ -928,6 +1111,8 @@ class DNACSDK(object):
         return os.path.basename(file_path)
 
     def _exec(self, family, function, params=None, op_modifies=False, **kwargs):
+        family_name = family
+        function_name = function
         try:
             family = getattr(self.api, family)
             func = getattr(family, function)
@@ -953,8 +1138,30 @@ class DNACSDK(object):
                     params["active_validation"] = False
 
                 response = func(**params)
+
             else:
                 response = func()
+
+            if response and isinstance(response, dict) and response.get("executionId"):
+                execution_id = response.get("executionId")
+                exec_details_params = {"execution_id": execution_id}
+                exec_details_func = getattr(
+                    getattr(self.api, "task"), "get_business_api_execution_details"
+                )
+
+                while True:
+                    execution_details = exec_details_func(**exec_details_params)
+                    if execution_details.get("status") == "SUCCESS":
+                        break
+
+                    bapi_error = execution_details.get("bapiError")
+                    if bapi_error and RATE_LIMIT_MESSAGE in bapi_error:
+                        self.logger.warning("!!!!! %s !!!!!", RATE_LIMIT_MESSAGE)
+                        time.sleep(RATE_LIMIT_RETRY_AFTER)
+                        return self._exec(
+                            family_name, function_name, params, op_modifies, **kwargs
+                        )
+
         except exceptions.dnacentersdkException as e:
             self.fail_json(
                 msg=(
