@@ -306,7 +306,7 @@ class Provision(DnacBase):
           - device_type: A string indicating the type of the
                        device (wired/wireless).
         Example:
-          Post creation of the validated input, we this method gets the
+          Post creation of the validated input, we use this method to get the
           type of the device.
         """
         try:
@@ -558,7 +558,7 @@ class Provision(DnacBase):
             )
         except Exception:
             self.log("Exception occurred as \
-                site '{0}' was not found".format(self.want.get("site_name")), "CRITICAL")
+                site '{0}' was not found".format(site_name_hierarchy), "CRITICAL")
             self.module.fail_json(msg="Site not found", response=[])
 
         if response:
@@ -615,7 +615,40 @@ class Provision(DnacBase):
 
         return (site_exists, site_id)
 
-    def get_site_assignment(self):
+    def is_device_assigned_to_site(self, uuid):
+        """
+        Checks if a device, specified by its UUID, is assigned to any site.
+
+        Parameters:
+          - self: The instance of the class containing the 'config' attribute
+                  to be validated.
+          - uuid (str): The UUID of the device to check for site assignment.
+        Returns:
+          - boolean:  True if the device is assigned to a site, False otherwise.
+
+        """
+
+        self.log("Checking site assignment for device with UUID: {0}".format(uuid), "INFO")
+        try:
+            site_response = self.dnac_apply['exec'](
+                family="devices",
+                function='get_device_detail',
+                params={"search_by": uuid ,
+                        "identifier": "uuid"},
+                op_modifies=True
+            )
+            self.log("Response collected from the API 'get_device_detail' {0}".format(site_response))
+            site_response = site_response.get("response")
+            if site_response.get("location"):
+                return True
+            else:
+                return False
+        except Exception as e:
+            msg = "Failed to find device with UUID {0} due to: {1}".format(uuid, e)
+            self.log(msg, "CRITICAL")
+            self.module.fail_json(msg=msg)
+
+    def get_site_assign(self):
         """
         Fetches the details of devices assigned to a site
 
@@ -630,9 +663,9 @@ class Provision(DnacBase):
         """
 
         site_name_hierarchy = self.validated_config[0].get("site_name_hierarchy")
-        site_exits, site_id = self.get_site_details(site_name_hierarchy=site_name_hierarchy)
+        site_exists, site_id = self.get_site_details(site_name_hierarchy=site_name_hierarchy)
         serial_number = self.get_serial_number()
-        if site_exits:
+        if site_exists:
             site_response = self.dnac_apply['exec'](
                 family="sites",
                 function='get_membership',
@@ -902,7 +935,8 @@ class Provision(DnacBase):
                         return self
 
                 else:
-                    if self.get_site_assignment() is True:
+                    uuid = self.get_device_id()
+                    if self.is_device_assigned_to_site(uuid) is True:
                         self.result["changed"] = False
                         self.result['msg'] = "Device is already assigned to the desired site"
                         self.result['diff'] = self.want
@@ -1056,8 +1090,9 @@ class Provision(DnacBase):
         device_type = self.want.get("device_type")
         provisioning = self.validated_config[0].get("provisioning")
         site_name_hierarchy = self.validated_config[0].get("site_name_hierarchy")
+        uuid = self.get_device_id()
         if provisioning is False:
-            if self.get_site_assignment() is True:
+            if self.is_device_assigned_to_site(uuid) is True:
                 self.log("Requested device is already added to the site {0}".format(site_name_hierarchy), "INFO")
             else:
                 self.log("Requested device is not added to the site {0}".format(site_name_hierarchy), "INFO")
