@@ -134,6 +134,12 @@ class Cliconf(CliconfBase):
 
         return self._device_info
 
+    def restore(self, filename=None, path=""):
+        if not filename:
+            raise ValueError("'file_name' value is required for restore")
+        cmd = f"configure replace {path}{filename} best-effort"
+        return self.send_command(cmd)
+
     def get_diff(
         self,
         candidate=None,
@@ -182,7 +188,7 @@ class Cliconf(CliconfBase):
         diff["config_diff"] = dumps(configdiffobjs, "commands") if configdiffobjs else ""
         return diff
 
-    def get_config(self, source="running", format="text", flags=None):
+    def get_config(self, source="running", flags=None, format="text"):
         options_values = self.get_option_values()
         if format not in options_values["format"]:
             raise ValueError(
@@ -204,38 +210,65 @@ class Cliconf(CliconfBase):
 
         return self.send_command(cmd)
 
-    def edit_config(self, candidate=None, commit=True, replace=None, comment=None):
+    def edit_config(
+        self,
+        candidate=None,
+        commit=True,
+        replace=None,
+        comment=None,
+        err_responses=None,
+    ):
         resp = {}
         operations = self.get_device_operations()
-        self.check_edit_config_capability(operations, candidate, commit, replace, comment)
+        self.check_edit_config_capability(
+            operations,
+            candidate,
+            commit,
+            replace,
+            comment,
+        )
         results = []
         requests = []
 
+        if err_responses:
+            # update platform default stderr regexes to include modules specific ones
+            err_responses = [re.compile(to_bytes(err_re)) for err_re in err_responses]
+            current_stderr_re = self._connection._get_terminal_std_re(
+                "terminal_stderr_re",
+            )
+            current_stderr_re.extend(err_responses)
+
         if replace:
-            device_info = self.get_device_info()
             # not all NX-OS versions support `config replace`
             # we let the device throw the invalid command error
-            candidate = "config replace {0}".format(replace)
+            candidate = f"config replace {replace}"
 
-        if commit:
-            self.send_command("configure terminal")
+        try:
+            if commit:
+                self.send_command("configure terminal")
 
-            for line in to_list(candidate):
-                if not isinstance(line, Mapping):
-                    line = {"command": line}
+                for line in to_list(candidate):
+                    if not isinstance(line, Mapping):
+                        line = {"command": line}
 
-                cmd = line["command"]
-                if cmd != "end":
-                    results.append(self.send_command(**line))
-                    requests.append(cmd)
+                    cmd = line["command"]
+                    if cmd != "end":
+                        results.append(self.send_command(**line))
+                        requests.append(cmd)
 
-            self.send_command("end")
-        else:
-            raise ValueError("check mode is not supported")
+                self.send_command("end")
+            else:
+                raise ValueError("check mode is not supported")
 
-        resp["request"] = requests
-        resp["response"] = results
-        return resp
+            resp["request"] = requests
+            resp["response"] = results
+            return resp
+
+        finally:
+            # always reset terminal regexes to platform default
+            if err_responses:
+                for x in err_responses:
+                    current_stderr_re.remove(x)
 
     def get(
         self,
@@ -243,8 +276,8 @@ class Cliconf(CliconfBase):
         prompt=None,
         answer=None,
         sendonly=False,
-        output=None,
         newline=True,
+        output=None,
         check_all=False,
     ):
         if output:
@@ -314,7 +347,7 @@ class Cliconf(CliconfBase):
             "format": ["text", "json"],
             "diff_match": ["line", "strict", "exact", "none"],
             "diff_replace": ["line", "block", "config"],
-            "output": ["text", "json"],
+            "output": ["text", "json", "json-pretty"],
         }
 
     def get_capabilities(self):
@@ -402,6 +435,7 @@ class Cliconf(CliconfBase):
                 out = self._connection.get_prompt()
 
     def _get_command_with_output(self, command, output):
+        output_re = r".+\|\s*json(?:-pretty)?$"
         options_values = self.get_option_values()
         if output not in options_values["output"]:
             raise ValueError(
@@ -409,15 +443,15 @@ class Cliconf(CliconfBase):
                 % (output, ",".join(options_values["output"])),
             )
 
-        if output == "json" and not command.endswith("| json"):
+        if output in ["json", "json-pretty"] and not re.search(output_re, command):
             device_info = self.get_device_info()
             model = device_info.get("network_os_model", "")
             platform = device_info.get("network_os_platform", "")
             if platform.startswith("DS-") and "MDS" in model:
                 cmd = "%s | json native" % command
             else:
-                cmd = "%s | json" % command
-        elif output == "text" and command.endswith("| json"):
+                cmd = "%s | %s" % (command, output)
+        elif output == "text" and re.search(output_re, command):
             cmd = command.rsplit("|", 1)[0]
         else:
             cmd = command
