@@ -4,7 +4,8 @@
 # Copyright (c) 2016, Paul Durivage <paul.durivage@gmail.com>
 # Copyright (c) 2016, Chris Houseknecht <house@redhat.com>
 # Copyright (c) 2016, James Tanner <jtanner@redhat.com>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import (absolute_import, division, print_function)
 
@@ -13,23 +14,22 @@ __metaclass__ = type
 
 DOCUMENTATION = '''
 name: docker_containers
-short_description: Ansible dynamic inventory plugin for Docker containers.
+short_description: Ansible dynamic inventory plugin for Docker containers
 version_added: 1.1.0
 author:
     - Felix Fontein (@felixfontein)
-requirements:
-    - L(Docker SDK for Python,https://docker-py.readthedocs.io/en/stable/) >= 1.10.0
 extends_documentation_fragment:
     - ansible.builtin.constructed
-    - community.docker.docker
-    - community.docker.docker.docker_py_1_documentation
+    - community.docker.docker.api_documentation
+    - community.docker.docker.ssl_version_deprecation
+    - community.library_inventory_filtering_v1.inventory_filter
 description:
     - Reads inventories from the Docker API.
     - Uses a YAML configuration file that ends with C(docker.[yml|yaml]).
 options:
     plugin:
         description:
-            - The name of this plugin, it should always be set to C(community.docker.docker_containers)
+            - The name of this plugin, it should always be set to V(community.docker.docker_containers)
               for this plugin to recognize it as it's own.
         type: str
         required: true
@@ -38,14 +38,14 @@ options:
     connection_type:
         description:
             - Which connection type to use the containers.
-            - One way to connect to containers is to use SSH (C(ssh)). For this, the options I(default_ip) and
-              I(private_ssh_port) are used. This requires that a SSH daemon is running inside the containers.
-            - Alternatively, C(docker-cli) selects the
-              R(docker connection plugin,ansible_collections.community.docker.docker_connection),
-              and C(docker-api) (default) selects the
-              R(docker_api connection plugin,ansible_collections.community.docker.docker_api_connection).
-            - When C(docker-api) is used, all Docker daemon configuration values are passed from the inventory plugin
-              to the connection plugin. This can be controlled with I(configure_docker_daemon).
+            - One way to connect to containers is to use SSH (V(ssh)). For this, the options O(default_ip) and
+              O(private_ssh_port) are used. This requires that a SSH daemon is running inside the containers.
+            - Alternatively, V(docker-cli) selects the P(community.docker.docker#connection) connection plugin,
+              and V(docker-api) (default) selects the P(community.docker.docker_api#connection) connection plugin.
+            - When V(docker-api) is used, all Docker daemon configuration values are passed from the inventory plugin
+              to the connection plugin. This can be controlled with O(configure_docker_daemon).
+            - Note that the P(community.docker.docker_api#connection) does B(not work with TCP TLS sockets)!
+              See U(https://github.com/ansible-collections/community.docker/issues/605) for more information.
         type: str
         default: docker-api
         choices:
@@ -56,7 +56,7 @@ options:
     configure_docker_daemon:
         description:
             - Whether to pass all Docker daemon configuration from the inventory plugin to the connection plugin.
-            - Only used when I(connection_type=docker-api).
+            - Only used when O(connection_type=docker-api).
         type: bool
         default: true
         version_added: 1.8.0
@@ -66,8 +66,8 @@ options:
             - Toggle to (not) include all available inspection metadata.
             - Note that all top-level keys will be transformed to the format C(docker_xxx).
               For example, C(HostConfig) is converted to C(docker_hostconfig).
-            - If this is C(false), these values can only be used during I(constructed), I(groups), and I(keyed_groups).
-            - The C(docker) inventory script always added these variables, so for compatibility set this to C(true).
+            - If this is V(false), these values can only be used during O(compose), O(groups), and O(keyed_groups).
+            - The C(docker) inventory script always added these variables, so for compatibility set this to V(true).
         type: bool
         default: false
 
@@ -75,14 +75,14 @@ options:
         description:
             - The IP address to assign to ansible_host when the container's SSH port is mapped to interface
               '0.0.0.0'.
-            - Only used if I(connection_type) is C(ssh).
+            - Only used if O(connection_type) is V(ssh).
         type: str
         default: 127.0.0.1
 
     private_ssh_port:
         description:
             - The port containers use for SSH.
-            - Only used if I(connection_type) is C(ssh).
+            - Only used if O(connection_type) is V(ssh).
         type: int
         default: 22
 
@@ -95,20 +95,23 @@ options:
             - "C(image_<image name>): contains the containers that have the image C(<image name>)."
             - "C(stack_<stack name>): contains the containers that belong to the stack C(<stack name>)."
             - "C(service_<service name>): contains the containers that belong to the service C(<service name>)"
-            - "C(<docker_host>): contains the containers which belong to the Docker daemon I(docker_host).
+            - "C(<docker_host>): contains the containers which belong to the Docker daemon O(docker_host).
               Useful if you run this plugin against multiple Docker daemons."
             - "C(running): contains all containers that are running."
             - "C(stopped): contains all containers that are not running."
-            - If this is not set to C(true), you should use keyed groups to add the containers to groups.
+            - If this is not set to V(true), you should use keyed groups to add the containers to groups.
               See the examples for how to do that.
         type: bool
         default: false
+
+    filters:
+        version_added: 3.5.0
 '''
 
 EXAMPLES = '''
 # Minimal example using local Docker daemon
 plugin: community.docker.docker_containers
-docker_host: unix://var/run/docker.sock
+docker_host: unix:///var/run/docker.sock
 
 # Minimal example using remote Docker daemon
 plugin: community.docker.docker_containers
@@ -123,7 +126,7 @@ tls: true
 plugin: community.docker.docker_containers
 docker_host: tcp://my-docker-host:2376
 validate_certs: true
-ca_cert: /somewhere/ca.pem
+ca_path: /somewhere/ca.pem
 client_key: /somewhere/key.pem
 client_cert: /somewhere/cert.pem
 
@@ -139,13 +142,25 @@ keyed_groups:
   - prefix: os
     key: docker_platform
 
-# Example using SSH connection with an explicit fallback for when port 22 hasn't been
+# Example using SSH connection with an explicit fallback for when port 22 has not been
 # exported: use container name as ansible_ssh_host and 22 as ansible_ssh_port
 plugin: community.docker.docker_containers
 connection_type: ssh
 compose:
   ansible_ssh_host: ansible_ssh_host | default(docker_name[1:], true)
   ansible_ssh_port: ansible_ssh_port | default(22, true)
+
+# Only consider containers which have a label 'foo', or whose name starts with 'a'
+plugin: community.docker.docker_containers
+filters:
+  # Accept all containers which have a label called 'foo'
+  - include: >-
+      "foo" in docker_config.Labels
+  # Next accept all containers whose inventory_hostname starts with 'a'
+  - include: >-
+      inventory_hostname.startswith("a")
+  # Exclude all containers that didn't match any of the above filters
+  - exclude: true
 '''
 
 import re
@@ -154,21 +169,20 @@ from ansible.errors import AnsibleError
 from ansible.module_utils.common.text.converters import to_native
 from ansible.plugins.inventory import BaseInventoryPlugin, Constructable
 
-from ansible_collections.community.docker.plugins.module_utils.common import (
+from ansible_collections.community.docker.plugins.module_utils.common_api import (
     RequestException,
+)
+from ansible_collections.community.docker.plugins.module_utils.util import (
     DOCKER_COMMON_ARGS_VARS,
 )
-from ansible_collections.community.docker.plugins.plugin_utils.common import (
+from ansible_collections.community.docker.plugins.plugin_utils.common_api import (
     AnsibleDockerClient,
 )
 
-try:
-    from docker.errors import DockerException, APIError
-except Exception:
-    # missing Docker SDK for Python handled in ansible_collections.community.docker.plugins.module_utils.common
-    pass
+from ansible_collections.community.docker.plugins.module_utils._api.errors import APIError, DockerException
+from ansible_collections.community.docker.plugins.plugin_utils.unsafe import make_unsafe
+from ansible_collections.community.library_inventory_filtering_v1.plugins.plugin_utils.inventory_filter import parse_filters, filter_host
 
-MIN_DOCKER_PY = '1.7.0'
 MIN_DOCKER_API = None
 
 
@@ -191,7 +205,15 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
         add_legacy_groups = self.get_option('add_legacy_groups')
 
         try:
-            containers = client.containers(all=True)
+            params = {
+                'limit': -1,
+                'all': 1,
+                'size': 0,
+                'trunc_cmd': 0,
+                'since': None,
+                'before': None,
+            }
+            containers = client.get_json('/containers/json', params=params)
         except APIError as exc:
             raise AnsibleError("Error listing containers: %s" % to_native(exc))
 
@@ -206,6 +228,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
                 if value is not None:
                     extra_facts[var_name] = value
 
+        filters = parse_filters(self.get_option('filters'))
         for container in containers:
             id = container.get('Id')
             short_id = id[:13]
@@ -217,15 +240,14 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
                 name = short_id
                 full_name = id
 
-            self.inventory.add_host(name)
             facts = dict(
-                docker_name=name,
-                docker_short_id=short_id
+                docker_name=make_unsafe(name),
+                docker_short_id=make_unsafe(short_id),
             )
             full_facts = dict()
 
             try:
-                inspect = client.inspect_container(id)
+                inspect = client.get_json('/containers/{0}/json', id)
             except APIError as exc:
                 raise AnsibleError("Error inspecting container %s - %s" % (name, str(exc)))
 
@@ -235,31 +257,33 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
 
             running = state.get('Running')
 
+            groups = []
+
             # Add container to groups
             image_name = config.get('Image')
             if image_name and add_legacy_groups:
-                self.inventory.add_group('image_{0}'.format(image_name))
-                self.inventory.add_host(name, group='image_{0}'.format(image_name))
+                groups.append('image_{0}'.format(image_name))
 
             stack_name = labels.get('com.docker.stack.namespace')
             if stack_name:
                 full_facts['docker_stack'] = stack_name
                 if add_legacy_groups:
-                    self.inventory.add_group('stack_{0}'.format(stack_name))
-                    self.inventory.add_host(name, group='stack_{0}'.format(stack_name))
+                    groups.append('stack_{0}'.format(stack_name))
 
             service_name = labels.get('com.docker.swarm.service.name')
             if service_name:
                 full_facts['docker_service'] = service_name
                 if add_legacy_groups:
-                    self.inventory.add_group('service_{0}'.format(service_name))
-                    self.inventory.add_host(name, group='service_{0}'.format(service_name))
+                    groups.append('service_{0}'.format(service_name))
 
+            ansible_connection = None
             if connection_type == 'ssh':
                 # Figure out ssh IP and Port
                 try:
                     # Lookup the public facing port Nat'ed to ssh port.
-                    port = client.port(container, ssh_port)[0]
+                    network_settings = inspect.get('NetworkSettings') or {}
+                    port_settings = network_settings.get('Ports') or {}
+                    port = port_settings.get('%d/tcp' % (ssh_port, ))[0]
                 except (IndexError, AttributeError, TypeError):
                     port = dict()
 
@@ -275,23 +299,38 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
             elif connection_type == 'docker-cli':
                 facts.update(dict(
                     ansible_host=full_name,
-                    ansible_connection='community.docker.docker',
                 ))
+                ansible_connection = 'community.docker.docker'
             elif connection_type == 'docker-api':
                 facts.update(dict(
                     ansible_host=full_name,
-                    ansible_connection='community.docker.docker_api',
                 ))
                 facts.update(extra_facts)
+                ansible_connection = 'community.docker.docker_api'
 
             full_facts.update(facts)
             for key, value in inspect.items():
                 fact_key = self._slugify(key)
                 full_facts[fact_key] = value
 
+            full_facts = make_unsafe(full_facts)
+
+            if ansible_connection:
+                for d in (facts, full_facts):
+                    if 'ansible_connection' not in d:
+                        d['ansible_connection'] = ansible_connection
+
+            if not filter_host(self, name, full_facts, filters):
+                continue
+
             if verbose_output:
                 facts.update(full_facts)
 
+            self.inventory.add_host(name)
+            for group in groups:
+                self.inventory.add_group(group)
+                self.inventory.add_host(name, group=group)
+
             for key, value in facts.items():
                 self.inventory.set_variable(name, key, value)
 
@@ -328,7 +367,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
             path.endswith(('docker.yaml', 'docker.yml')))
 
     def _create_client(self):
-        return AnsibleDockerClient(self, min_docker_version=MIN_DOCKER_PY, min_docker_api_version=MIN_DOCKER_API)
+        return AnsibleDockerClient(self, min_docker_api_version=MIN_DOCKER_API)
 
     def parse(self, inventory, loader, path, cache=True):
         super(InventoryModule, self).parse(inventory, loader, path, cache)
@@ -338,9 +377,9 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
             self._populate(client)
         except DockerException as e:
             raise AnsibleError(
-                'An unexpected docker error occurred: {0}'.format(e)
+                'An unexpected Docker error occurred: {0}'.format(e)
             )
         except RequestException as e:
             raise AnsibleError(
-                'An unexpected requests error occurred when docker-py tried to talk to the docker daemon: {0}'.format(e)
+                'An unexpected requests error occurred when trying to talk to the Docker daemon: {0}'.format(e)
             )
