@@ -18,10 +18,11 @@ DOCUMENTATION = '''
       _uri:
         description:
           - A colon separated string of connection information for Redis.
-          - The format is C(host:port:db:password), for example C(localhost:6379:0:changeme).
-          - To use encryption in transit, prefix the connection with C(tls://), as in C(tls://localhost:6379:0:changeme).
-          - To use redis sentinel, use separator C(;), for example C(localhost:26379;localhost:26379;0:changeme). Requires redis>=2.9.0.
-        required: True
+          - The format is V(host:port:db:password), for example V(localhost:6379:0:changeme).
+          - To use encryption in transit, prefix the connection with V(tls://), as in V(tls://localhost:6379:0:changeme).
+          - To use redis sentinel, use separator V(;), for example V(localhost:26379;localhost:26379;0:changeme). Requires redis>=2.9.0.
+        type: string
+        required: true
         env:
           - name: ANSIBLE_CACHE_PLUGIN_CONNECTION
         ini:
@@ -29,6 +30,7 @@ DOCUMENTATION = '''
             section: defaults
       _prefix:
         description: User defined prefix to use when creating the DB entries
+        type: string
         default: ansible_facts
         env:
           - name: ANSIBLE_CACHE_PLUGIN_PREFIX
@@ -37,6 +39,7 @@ DOCUMENTATION = '''
             section: defaults
       _keyset_name:
         description: User defined name for cache keyset name.
+        type: string
         default: ansible_cache_keys
         env:
           - name: ANSIBLE_CACHE_REDIS_KEYSET_NAME
@@ -46,6 +49,7 @@ DOCUMENTATION = '''
         version_added: 1.3.0
       _sentinel_service_name:
         description: The redis sentinel service name (or referenced as cluster name).
+        type: string
         env:
           - name: ANSIBLE_CACHE_REDIS_SENTINEL
         ini:
@@ -54,25 +58,24 @@ DOCUMENTATION = '''
         version_added: 1.3.0
       _timeout:
         default: 86400
+        type: integer
+        # TODO: determine whether it is OK to change to: type: float
         description: Expiration timeout in seconds for the cache plugin data. Set to 0 to never expire
         env:
           - name: ANSIBLE_CACHE_PLUGIN_TIMEOUT
         ini:
           - key: fact_caching_timeout
             section: defaults
-        type: integer
 '''
 
 import re
 import time
 import json
 
-from ansible import constants as C
 from ansible.errors import AnsibleError
 from ansible.module_utils.common.text.converters import to_native
 from ansible.parsing.ajson import AnsibleJSONEncoder, AnsibleJSONDecoder
 from ansible.plugins.cache import BaseCacheModule
-from ansible.release import __version__ as ansible_base_version
 from ansible.utils.display import Display
 
 try:
@@ -152,7 +155,7 @@ class CacheModule(BaseCacheModule):
         # format: "localhost:26379;localhost2:26379;0:changeme"
         connections = uri.split(';')
         connection_args = connections.pop(-1)
-        if len(connection_args) > 0:  # hanle if no db nr is given
+        if len(connection_args) > 0:  # handle if no db nr is given
             connection_args = connection_args.split(':')
             kw['db'] = connection_args.pop(0)
             try:
