@@ -188,13 +188,14 @@ requirements:
    - mysql (command line binary)
    - mysqldump (command line binary)
 notes:
-   - Supports C(check_mode).
    - Requires the mysql and mysqldump binaries on the remote host.
    - This module is B(not idempotent) when I(state) is C(import),
      and will import the dump file each time if run more than once.
+attributes:
+  check_mode:
+    support: full
 extends_documentation_fragment:
 - community.mysql.mysql
-
 '''
 
 EXAMPLES = r'''
@@ -576,14 +577,14 @@ def db_create(cursor, db, encoding, collation):
 def main():
     argument_spec = mysql_common_argument_spec()
     argument_spec.update(
-        name=dict(type='list', required=True, aliases=['db']),
+        name=dict(type='list', elements='str', required=True, aliases=['db']),
         encoding=dict(type='str', default=''),
         collation=dict(type='str', default=''),
         target=dict(type='path'),
         state=dict(type='str', default='present', choices=['absent', 'dump', 'import', 'present']),
         single_transaction=dict(type='bool', default=False),
         quick=dict(type='bool', default=True),
-        ignore_tables=dict(type='list', default=[]),
+        ignore_tables=dict(type='list', elements='str', default=[]),
         hex_blob=dict(default=False, type='bool'),
         force=dict(type='bool', default=False),
         master_data=dict(type='int', default=0, choices=[0, 1, 2]),
