@@ -26,6 +26,7 @@ description:
     L(create an issue in the community.routeros Issue Tracker,https://github.com/ansible-collections/community.routeros/issues/).
 extends_documentation_fragment:
   - community.routeros.api
+  - community.routeros.api.restrict
   - community.routeros.attributes
   - community.routeros.attributes.actiongroup_api
   - community.routeros.attributes.info_module
@@ -125,6 +126,7 @@ options:
         - ip dhcp-server
         - ip dhcp-server config
         - ip dhcp-server lease
+        - ip dhcp-server matcher
         - ip dhcp-server network
         - ip dhcp-server option
         - ip dhcp-server option sets
@@ -173,6 +175,7 @@ options:
         - ipv6 firewall nat
         - ipv6 firewall raw
         - ipv6 nd
+        - ipv6 nd prefix
         - ipv6 nd prefix default
         - ipv6 route
         - ipv6 settings
@@ -208,6 +211,7 @@ options:
         - routing ospf area range
         - routing ospf instance
         - routing ospf interface-template
+        - routing ospf static-neighbor
         - routing pimsm instance
         - routing pimsm interface-template
         - routing rip
@@ -218,6 +222,7 @@ options:
         - snmp community
         - system clock
         - system clock manual
+        - system health settings
         - system identity
         - system leds settings
         - system logging
@@ -227,6 +232,7 @@ options:
         - system ntp client servers
         - system ntp server
         - system package update
+        - system resource irq rps
         - system routerboard settings
         - system scheduler
         - system script
@@ -296,6 +302,10 @@ options:
     type: bool
     default: false
     version_added: 2.10.0
+  restrict:
+    description:
+      - Restrict output to entries matching the following criteria.
+    version_added: 2.18.0
 seealso:
   - module: community.routeros.api
   - module: community.routeros.api_facts
@@ -313,6 +323,18 @@ EXAMPLES = '''
     path: ip address
   register: ip_addresses
 
+- name: Print data for IP addresses
+  ansible.builtin.debug:
+    var: ip_addresses.result
+
+- name: Get IP addresses
+  community.routeros.api_info:
+    hostname: "{{ hostname }}"
+    password: "{{ password }}"
+    username: "{{ username }}"
+    path: ip address
+  register: ip_addresses
+
 - name: Print data for IP addresses
   ansible.builtin.debug:
     var: ip_addresses.result
@@ -353,6 +375,12 @@ from ansible_collections.community.routeros.plugins.module_utils._api_data impor
     split_path,
 )
 
+from ansible_collections.community.routeros.plugins.module_utils._api_helper import (
+    restrict_argument_spec,
+    restrict_entry_accepted,
+    validate_and_prepare_restrict,
+)
+
 try:
     from librouteros.exceptions import LibRouterosError
 except Exception:
@@ -378,6 +406,7 @@ def main():
         include_read_only=dict(type='bool', default=False),
     )
     module_args.update(api_argument_spec())
+    module_args.update(restrict_argument_spec())
 
     module = AnsibleModule(
         argument_spec=module_args,
@@ -406,6 +435,7 @@ def main():
     include_dynamic = module.params['include_dynamic']
     include_builtin = module.params['include_builtin']
     include_read_only = module.params['include_read_only']
+    restrict_data = validate_and_prepare_restrict(module, path_info)
     try:
         api_path = compose_api_path(api, path)
 
@@ -418,6 +448,8 @@ def main():
             if not include_builtin:
                 if entry.get('builtin', False):
                     continue
+            if not restrict_entry_accepted(entry, path_info, restrict_data):
+                continue
             if not unfiltered:
                 for k in list(entry):
                     if k == '.id':
