@@ -1,19 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright: (c) 2021, Felix Fontein <felix@fontein.de>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# Copyright (c) 2021, Felix Fontein <felix@fontein.de>
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 DOCUMENTATION = '''
 name: decrpyt
-short_description: Decrypt sops encrypted data
+short_description: Decrypt SOPS-encrypted data
 version_added: 1.1.0
 author:
     - Felix Fontein (@felixfontein)
 description:
-    - Decrypt sops encrypted data.
+    - Decrypt SOPS-encrypted data.
     - Allows to decrypt data that has been provided by an arbitrary source.
     - Note that due to Ansible lazy-evaluating expressions, it is better to use M(ansible.builtin.set_fact)
       to store the result of an evaluation in a fact to avoid recomputing the value every time the expression
@@ -31,9 +32,9 @@ options:
         default: true
     input_type:
         description:
-            - Tell sops how to interpret the encrypted data.
+            - Tell SOPS how to interpret the encrypted data.
             - There is no auto-detection since we do not have a filename. By default
-              sops is told to treat the input as YAML. If that is wrong, please set this
+              SOPS is told to treat the input as YAML. If that is wrong, please set this
               option to the correct value.
         type: str
         choices:
@@ -44,10 +45,10 @@ options:
         default: yaml
     output_type:
         description:
-            - Tell sops how to interpret the decrypted file.
-            - Please note that the output is always text or bytes, depending on the value of I(decode_output).
-              To parse the resulting JSON or YAML, use corresponding filters such as C(ansible.builtin.from_json)
-              and C(ansible.builtin.from_yaml).
+            - Tell SOPS how to interpret the decrypted file.
+            - Please note that the output is always text or bytes, depending on the value of O(decode_output).
+              To parse the resulting JSON or YAML, use corresponding filters such as P(ansible.builtin.from_json#filter)
+              and P(ansible.builtin.from_yaml#filter).
         type: str
         choices:
             - binary
@@ -58,12 +59,18 @@ options:
     decode_output:
         description:
             - Whether to decode the output to bytes.
-            - When I(output_type=binary), and the file isn't known to contain UTF-8 encoded text,
-              this should better be set to C(false) to prevent mangling the data with UTF-8 decoding.
+            - When O(output_type=binary), and the file isn't known to contain UTF-8 encoded text,
+              this should better be set to V(false) to prevent mangling the data with UTF-8 decoding.
         type: bool
         default: true
 extends_documentation_fragment:
     - community.sops.sops
+seealso:
+    - plugin: community.sops.sops
+      plugin_type: lookup
+    - plugin: community.sops.sops
+      plugin_type: vars
+    - module: community.sops.load_vars
 '''
 
 EXAMPLES = '''
@@ -73,8 +80,8 @@ EXAMPLES = '''
   tasks:
     - name: Fetch file from URL
       ansible.builtin.uri:
-        url: https://raw.githubusercontent.com/mozilla/sops/master/functional-tests/res/comments.enc.yaml
-        return_content: yes
+        url: https://raw.githubusercontent.com/getsops/sops/master/functional-tests/res/comments.enc.yaml
+        return_content: true
       register: encrypted_content
 
     - name: Show encrypted data
@@ -93,11 +100,11 @@ EXAMPLES = '''
 RETURN = '''
 _value:
     description:
-        - Decrypted data as text (I(decode_output=true), default) or binary string (I(decode_output=false)).
+        - Decrypted data as text (O(decode_output=true), default) or binary string (O(decode_output=false)).
     type: string
 '''
 
-from ansible.errors import AnsibleError, AnsibleFilterError
+from ansible.errors import AnsibleFilterError
 from ansible.module_utils.common.text.converters import to_bytes, to_native
 from ansible.utils.display import Display
 
@@ -109,7 +116,7 @@ _VALID_TYPES = set(['binary', 'json', 'yaml', 'dotenv'])
 
 def decrypt_filter(data, input_type='yaml', output_type='yaml', sops_binary='sops', rstrip=True, decode_output=True,
                    aws_profile=None, aws_access_key_id=None, aws_secret_access_key=None, aws_session_token=None,
-                   config_path=None, enable_local_keyservice=False, keyservice=None):
+                   config_path=None, enable_local_keyservice=False, keyservice=None, age_key=None, age_keyfile=None):
     '''Decrypt sops-encrypted data.'''
 
     # Check parameters
@@ -124,6 +131,10 @@ def decrypt_filter(data, input_type='yaml', output_type='yaml', sops_binary='sop
     def get_option_value(argument_name):
         if argument_name == 'sops_binary':
             return sops_binary
+        if argument_name == 'age_key':
+            return age_key
+        if argument_name == 'age_keyfile':
+            return age_keyfile
         if argument_name == 'aws_profile':
             return aws_profile
         if argument_name == 'aws_access_key_id':
