@@ -1,22 +1,8 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright 2018 Edoardo Tenani <e.tenani@arduino.cc> [@endorama]
-#
-# This file is part of Ansible.
-#
-# Ansible is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# Ansible is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Ansible.  If not, see <http://www.gnu.org/licenses/>.
-#
+# Copyright 2018 Edoardo Tenani <e.tenani@arduino.cc> (@endorama)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
@@ -24,7 +10,7 @@ __metaclass__ = type
 DOCUMENTATION = """
     name: sops
     author: Edoardo Tenani (@endorama) <e.tenani@arduino.cc>
-    short_description: Read sops encrypted file contents
+    short_description: Read SOPS-encrypted file contents
     version_added: '0.1.0'
     description:
         - This lookup returns the contents from a file on the Ansible controller's file system.
@@ -45,8 +31,8 @@ DOCUMENTATION = """
             default: false
         input_type:
             description:
-                - Tell sops how to interpret the encrypted file.
-                - By default, sops will chose the input type from the file extension.
+                - Tell SOPS how to interpret the encrypted file.
+                - By default, SOPS will chose the input type from the file extension.
                   If it detects the wrong type for a file, this could result in decryption
                   failing.
             type: str
@@ -57,8 +43,8 @@ DOCUMENTATION = """
                 - dotenv
         output_type:
             description:
-                - Tell sops how to interpret the decrypted file.
-                - By default, sops will chose the output type from the file extension.
+                - Tell SOPS how to interpret the decrypted file.
+                - By default, SOPS will chose the output type from the file extension.
                   If it detects the wrong type for a file, this could result in decryption
                   failing.
             type: str
@@ -69,7 +55,7 @@ DOCUMENTATION = """
                 - dotenv
         empty_on_not_exist:
             description:
-                - When set to C(true), will not raise an error when a file cannot be found,
+                - When set to V(true), will not raise an error when a file cannot be found,
                   but return an empty string instead.
             type: bool
             default: false
@@ -80,6 +66,14 @@ DOCUMENTATION = """
         - community.sops.sops.ansible_ini
     notes:
         - This lookup does not understand 'globbing' - use the fileglob lookup instead.
+    seealso:
+        - plugin: community.sops.decrypt
+          plugin_type: filter
+          description: The decrypt filter can be used to descrypt SOPS-encrypted in-memory data.
+        - plugin: community.sops.sops
+          plugin_type: vars
+          description: The sops vars plugin can be used to load SOPS-encrypted host or group variables.
+        - module: community.sops.load_vars
 """
 
 EXAMPLES = """
