@@ -1,9 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright: (c) 2018, VMware, Inc.
 # Copyright: (c) 2019, Abhijeet Kasurde <akasurde@redhat.com>
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -17,16 +18,11 @@ description:
     - This module can be used to manage distributed switch Network IO Control configurations.
 author:
     - Joseph Andreatta (@vmwjoseph)
-notes:
-    - Tested on vSphere 6.7
-requirements:
-    - "python >= 2.6"
-    - PyVmomi
 options:
     switch:
         description:
         - The name of the distributed switch.
-        required: True
+        required: true
         aliases: ['dvswitch']
         type: str
     version:
@@ -35,14 +31,14 @@ options:
         choices:
         - 'version2'
         - 'version3'
-        required: False
+        required: false
         type: str
     state:
         description:
         - Enable or disable NIOC on the distributed switch.
         default: 'present'
         choices: ['present', 'absent']
-        required: False
+        required: false
         type: str
     resources:
         description:
@@ -52,7 +48,7 @@ options:
                 description:
                 - Resource name.
                 choices: ["faultTolerance", "hbr", "iSCSI", "management", "nfs", "vdp", "virtualMachine", "vmotion", "vsan", "backupNfc", "nvmetcp"]
-                required: True
+                required: true
                 type: str
             limit:
                 description:
@@ -69,6 +65,7 @@ options:
                 - Ignored unless version is "version3".
                 - Amount of bandwidth resource that is guaranteed available to the host infrastructure traffic class.
                 type: int
+                default: 0
 
             shares_level:
                 description:
@@ -80,10 +77,11 @@ options:
             shares:
                 description:
                 - The number of shares allocated.
-                - Ignored unless C(shares_level) is "custom".
+                - Ignored unless O(resources.shares_level=custom).
                 type: int
-        required: False
+        required: false
         type: list
+        default: []
         elements: dict
 extends_documentation_fragment:
 - community.vmware.vmware.documentation
