@@ -87,7 +87,7 @@ options:
             archive-block:
                 type: list
                 elements: str
-                description: Deprecated, please rename it to archive_block.
+                description: Deprecated, please rename it to archive_block. Select the archive types to block.
                 choices:
                     - 'encrypted'
                     - 'corrupted'
@@ -101,7 +101,7 @@ options:
             archive-log:
                 type: list
                 elements: str
-                description: Deprecated, please rename it to archive_log.
+                description: Deprecated, please rename it to archive_log. Select the archive types to log.
                 choices:
                     - 'encrypted'
                     - 'corrupted'
@@ -121,7 +121,7 @@ options:
             options:
                 type: list
                 elements: str
-                description: No description.
+                description: Enable/disable SMB AntiVirus scanning, monitoring, and quarantine.
                 choices:
                     - 'scan'
                     - 'quarantine'
@@ -281,9 +281,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_partial_curd(argument_specs=module_arg_spec)
