@@ -95,7 +95,7 @@ options:
         suboptions:
             category:
                 type: str
-                description: No description.
+                description: Category.
                 choices:
                     - 'app-ctrl'
                     - 'attack'
@@ -112,23 +112,23 @@ options:
             fields:
                 type: list
                 elements: dict
-                description: No description.
+                description: Fields.
                 suboptions:
                     args:
                         type: raw
-                        description: (list) No description.
+                        description: (list) Args.
                     field:
                         type: str
-                        description: No description.
+                        description: Field.
                     negate:
                         type: str
-                        description: No description.
+                        description: Negate.
                         choices:
                             - 'disable'
                             - 'enable'
             id:
                 type: int
-                description: No description.
+                description: Id.
                 required: true
 '''
 
@@ -257,9 +257,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
