@@ -79,7 +79,7 @@ options:
         suboptions:
             desc:
                 type: str
-                description: No description.
+                description: Desc.
 '''
 
 EXAMPLES = '''
@@ -185,9 +185,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='workflow')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_exec(argument_specs=module_arg_spec)
