@@ -1,19 +1,7 @@
 #!/usr/bin/python
 from __future__ import absolute_import, division, print_function
-# Copyright 2019-2023 Fortinet, Inc.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+# Copyright 2019-2024 Fortinet, Inc.
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 __metaclass__ = type
 
@@ -38,35 +26,33 @@ author:
     - Frank Shen (@fshen01)
     - Hongbin Lu (@fgtdev-hblu)
 notes:
+    - Starting in version 2.4.0, all input arguments are named using the underscore naming convention (snake_case).
+      Please change the arguments such as "var-name" to "var_name".
+      Old argument names are still available yet you will receive deprecation warnings.
+      You can ignore this warning by setting deprecation_warnings=False in ansible.cfg.
     - Running in workspace locking mode is supported in this FortiManager module, the top
       level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
     - To create or update an object, use state present directive.
     - To delete an object, use state absent directive.
     - Normally, running one module can fail when a non-zero rc is returned. you can also override
       the conditions to fail or succeed with parameters rc_failed and rc_succeeded
-
 options:
     access_token:
         description: The token to access FortiManager without using username and password.
-        required: false
         type: str
     bypass_validation:
         description: Only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters.
-        required: false
         type: bool
         default: false
     enable_log:
         description: Enable/Disable logging for task.
-        required: false
         type: bool
         default: false
     forticloud_access_token:
         description: Authenticate Ansible client with forticloud API access token.
-        required: false
         type: str
     proposed_method:
         description: The overridden method for the underlying Json RPC request.
-        required: false
         type: str
         choices:
           - update
@@ -75,12 +61,10 @@ options:
     rc_succeeded:
         description: The rc codes list with which the conditions to succeed will be overriden.
         type: list
-        required: false
         elements: int
     rc_failed:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
-        required: false
         elements: int
     state:
         description: The directive to create, update or delete an object.
@@ -91,27 +75,29 @@ options:
           - absent
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
-        required: false
         type: str
     workspace_locking_timeout:
         description: The maximum time in seconds to wait for other user to release the workspace lock.
-        required: false
         type: int
         default: 300
     adom:
-        description: the parameter (adom) in requested url
+        description: The parameter (adom) in requested url.
         type: str
         required: true
     access-proxy6:
-        description: the parameter (access-proxy6) in requested url
+        description: Deprecated, please use "access_proxy6"
+        type: str
+    access_proxy6:
+        description: The parameter (access-proxy6) in requested url.
         type: str
-        required: true
     api-gateway:
-        description: the parameter (api-gateway) in requested url
+        description: Deprecated, please use "api_gateway"
+        type: str
+    api_gateway:
+        description: The parameter (api-gateway) in requested url.
         type: str
-        required: true
     firewall_accessproxy6_apigateway_sslciphersuites:
-        description: the top level parameters set
+        description: The top level parameters set.
         required: false
         type: dict
         suboptions:
@@ -194,47 +180,44 @@ options:
                 type: int
                 description: SSL/TLS cipher suites priority.
             versions:
-                description: description
                 type: list
                 elements: str
+                description: SSL/TLS versions that the cipher suite can be used with.
                 choices:
                     - 'tls-1.0'
                     - 'tls-1.1'
                     - 'tls-1.2'
                     - 'tls-1.3'
-
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
-   collections:
-     - fortinet.fortimanager
-   connection: httpapi
-   vars:
-      ansible_httpapi_use_ssl: True
-      ansible_httpapi_validate_certs: False
-      ansible_httpapi_port: 443
-   tasks:
+- name: Example playbook (generated based on argument schema)
+  hosts: fortimanagers
+  connection: httpapi
+  vars:
+    ansible_httpapi_use_ssl: true
+    ansible_httpapi_validate_certs: false
+    ansible_httpapi_port: 443
+  tasks:
     - name: SSL/TLS cipher suites to offer to a server, ordered by priority.
-      fmgr_firewall_accessproxy6_apigateway_sslciphersuites:
-         bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         access-proxy6: <your own value>
-         api-gateway: <your own value>
-         state: <value in [present, absent]>
-         firewall_accessproxy6_apigateway_sslciphersuites:
-            cipher: <value in [TLS-RSA-WITH-RC4-128-MD5, TLS-RSA-WITH-RC4-128-SHA, TLS-RSA-WITH-DES-CBC-SHA, ...]>
-            priority: <value of integer>
-            versions:
-              - tls-1.0
-              - tls-1.1
-              - tls-1.2
-              - tls-1.3
-
+      fortinet.fortimanager.fmgr_firewall_accessproxy6_apigateway_sslciphersuites:
+        # bypass_validation: false
+        workspace_locking_adom: <value in [global, custom adom including root]>
+        workspace_locking_timeout: 300
+        # rc_succeeded: [0, -2, -3, ...]
+        # rc_failed: [-2, -3, ...]
+        adom: <your own value>
+        access_proxy6: <your own value>
+        api_gateway: <your own value>
+        state: present # <value in [present, absent]>
+        firewall_accessproxy6_apigateway_sslciphersuites:
+          cipher: <value in [TLS-RSA-WITH-RC4-128-MD5, TLS-RSA-WITH-RC4-128-SHA, TLS-RSA-WITH-DES-CBC-SHA, ...]>
+          priority: <integer>
+          versions:
+            - tls-1.0
+            - tls-1.1
+            - tls-1.2
+            - tls-1.3
 '''
 
 RETURN = '''
@@ -281,228 +264,83 @@ from ansible.module_utils.connection import Connection
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
     jrpc_urls = [
-        '/pm/config/global/obj/firewall/access-proxy6/{access-proxy6}/api-gateway/{api-gateway}/ssl-cipher-suites',
-        '/pm/config/adom/{adom}/obj/firewall/access-proxy6/{access-proxy6}/api-gateway/{api-gateway}/ssl-cipher-suites'
+        '/pm/config/adom/{adom}/obj/firewall/access-proxy6/{access-proxy6}/api-gateway/{api-gateway}/ssl-cipher-suites',
+        '/pm/config/global/obj/firewall/access-proxy6/{access-proxy6}/api-gateway/{api-gateway}/ssl-cipher-suites'
     ]
 
     perobject_jrpc_urls = [
-        '/pm/config/global/obj/firewall/access-proxy6/{access-proxy6}/api-gateway/{api-gateway}/ssl-cipher-suites/{ssl-cipher-suites}',
-        '/pm/config/adom/{adom}/obj/firewall/access-proxy6/{access-proxy6}/api-gateway/{api-gateway}/ssl-cipher-suites/{ssl-cipher-suites}'
+        '/pm/config/adom/{adom}/obj/firewall/access-proxy6/{access-proxy6}/api-gateway/{api-gateway}/ssl-cipher-suites/{ssl-cipher-suites}',
+        '/pm/config/global/obj/firewall/access-proxy6/{access-proxy6}/api-gateway/{api-gateway}/ssl-cipher-suites/{ssl-cipher-suites}'
     ]
 
     url_params = ['adom', 'access-proxy6', 'api-gateway']
     module_primary_key = None
     module_arg_spec = {
-        'access_token': {
-            'type': 'str',
-            'required': False,
-            'no_log': True
-        },
-        'bypass_validation': {
-            'type': 'bool',
-            'required': False,
-            'default': False
-        },
-        'enable_log': {
-            'type': 'bool',
-            'required': False,
-            'default': False
-        },
-        'forticloud_access_token': {
-            'type': 'str',
-            'required': False,
-            'no_log': True
-        },
-        'proposed_method': {
-            'type': 'str',
-            'required': False,
-            'choices': [
-                'set',
-                'update',
-                'add'
-            ]
-        },
-        'rc_succeeded': {
-            'required': False,
-            'type': 'list',
-            'elements': 'int'
-        },
-        'rc_failed': {
-            'required': False,
-            'type': 'list',
-            'elements': 'int'
-        },
-        'state': {
-            'type': 'str',
-            'required': True,
-            'choices': [
-                'present',
-                'absent'
-            ]
-        },
-        'workspace_locking_adom': {
-            'type': 'str',
-            'required': False
-        },
-        'workspace_locking_timeout': {
-            'type': 'int',
-            'required': False,
-            'default': 300
-        },
-        'adom': {
-            'required': True,
-            'type': 'str'
-        },
-        'access-proxy6': {
-            'required': True,
-            'type': 'str'
-        },
-        'api-gateway': {
-            'required': True,
-            'type': 'str'
-        },
+        'adom': {'required': True, 'type': 'str'},
+        'access-proxy6': {'type': 'str', 'api_name': 'access_proxy6'},
+        'access_proxy6': {'type': 'str'},
+        'api-gateway': {'type': 'str', 'api_name': 'api_gateway'},
+        'api_gateway': {'type': 'str'},
         'firewall_accessproxy6_apigateway_sslciphersuites': {
-            'required': False,
             'type': 'dict',
-            'revision': {
-                '7.2.1': True,
-                '7.2.2': True,
-                '7.4.0': True
-            },
+            'v_range': [['7.2.1', '']],
             'options': {
                 'cipher': {
-                    'required': False,
-                    'revision': {
-                        '7.2.1': True,
-                        '7.2.2': True,
-                        '7.4.0': True
-                    },
+                    'v_range': [['7.2.1', '']],
                     'choices': [
-                        'TLS-RSA-WITH-RC4-128-MD5',
-                        'TLS-RSA-WITH-RC4-128-SHA',
-                        'TLS-RSA-WITH-DES-CBC-SHA',
-                        'TLS-RSA-WITH-3DES-EDE-CBC-SHA',
-                        'TLS-RSA-WITH-AES-128-CBC-SHA',
-                        'TLS-RSA-WITH-AES-256-CBC-SHA',
-                        'TLS-RSA-WITH-AES-128-CBC-SHA256',
-                        'TLS-RSA-WITH-AES-256-CBC-SHA256',
-                        'TLS-RSA-WITH-CAMELLIA-128-CBC-SHA',
-                        'TLS-RSA-WITH-CAMELLIA-256-CBC-SHA',
-                        'TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256',
-                        'TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256',
-                        'TLS-RSA-WITH-SEED-CBC-SHA',
-                        'TLS-RSA-WITH-ARIA-128-CBC-SHA256',
-                        'TLS-RSA-WITH-ARIA-256-CBC-SHA384',
-                        'TLS-DHE-RSA-WITH-DES-CBC-SHA',
-                        'TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA',
-                        'TLS-DHE-RSA-WITH-AES-128-CBC-SHA',
-                        'TLS-DHE-RSA-WITH-AES-256-CBC-SHA',
-                        'TLS-DHE-RSA-WITH-AES-128-CBC-SHA256',
-                        'TLS-DHE-RSA-WITH-AES-256-CBC-SHA256',
-                        'TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA',
-                        'TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA',
-                        'TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256',
-                        'TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256',
-                        'TLS-DHE-RSA-WITH-SEED-CBC-SHA',
-                        'TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256',
-                        'TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384',
-                        'TLS-ECDHE-RSA-WITH-RC4-128-SHA',
-                        'TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA',
-                        'TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA',
-                        'TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA',
-                        'TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256',
-                        'TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256',
-                        'TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256',
-                        'TLS-DHE-RSA-WITH-AES-128-GCM-SHA256',
-                        'TLS-DHE-RSA-WITH-AES-256-GCM-SHA384',
-                        'TLS-DHE-DSS-WITH-AES-128-CBC-SHA',
-                        'TLS-DHE-DSS-WITH-AES-256-CBC-SHA',
-                        'TLS-DHE-DSS-WITH-AES-128-CBC-SHA256',
-                        'TLS-DHE-DSS-WITH-AES-128-GCM-SHA256',
-                        'TLS-DHE-DSS-WITH-AES-256-CBC-SHA256',
-                        'TLS-DHE-DSS-WITH-AES-256-GCM-SHA384',
-                        'TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256',
-                        'TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256',
-                        'TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384',
-                        'TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384',
-                        'TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA',
-                        'TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256',
-                        'TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256',
-                        'TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384',
-                        'TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384',
-                        'TLS-RSA-WITH-AES-128-GCM-SHA256',
-                        'TLS-RSA-WITH-AES-256-GCM-SHA384',
-                        'TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA',
-                        'TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA',
-                        'TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256',
-                        'TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256',
-                        'TLS-DHE-DSS-WITH-SEED-CBC-SHA',
-                        'TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256',
-                        'TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384',
-                        'TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256',
-                        'TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384',
-                        'TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256',
-                        'TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384',
-                        'TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA',
-                        'TLS-DHE-DSS-WITH-DES-CBC-SHA',
-                        'TLS-AES-128-GCM-SHA256',
-                        'TLS-AES-256-GCM-SHA384',
-                        'TLS-CHACHA20-POLY1305-SHA256',
-                        'TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA'
+                        'TLS-RSA-WITH-RC4-128-MD5', 'TLS-RSA-WITH-RC4-128-SHA', 'TLS-RSA-WITH-DES-CBC-SHA', 'TLS-RSA-WITH-3DES-EDE-CBC-SHA',
+                        'TLS-RSA-WITH-AES-128-CBC-SHA', 'TLS-RSA-WITH-AES-256-CBC-SHA', 'TLS-RSA-WITH-AES-128-CBC-SHA256',
+                        'TLS-RSA-WITH-AES-256-CBC-SHA256', 'TLS-RSA-WITH-CAMELLIA-128-CBC-SHA', 'TLS-RSA-WITH-CAMELLIA-256-CBC-SHA',
+                        'TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256', 'TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256', 'TLS-RSA-WITH-SEED-CBC-SHA',
+                        'TLS-RSA-WITH-ARIA-128-CBC-SHA256', 'TLS-RSA-WITH-ARIA-256-CBC-SHA384', 'TLS-DHE-RSA-WITH-DES-CBC-SHA',
+                        'TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA', 'TLS-DHE-RSA-WITH-AES-128-CBC-SHA', 'TLS-DHE-RSA-WITH-AES-256-CBC-SHA',
+                        'TLS-DHE-RSA-WITH-AES-128-CBC-SHA256', 'TLS-DHE-RSA-WITH-AES-256-CBC-SHA256', 'TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA',
+                        'TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA', 'TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256', 'TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256',
+                        'TLS-DHE-RSA-WITH-SEED-CBC-SHA', 'TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256', 'TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384',
+                        'TLS-ECDHE-RSA-WITH-RC4-128-SHA', 'TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA', 'TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA',
+                        'TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA', 'TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256',
+                        'TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256', 'TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256',
+                        'TLS-DHE-RSA-WITH-AES-128-GCM-SHA256', 'TLS-DHE-RSA-WITH-AES-256-GCM-SHA384', 'TLS-DHE-DSS-WITH-AES-128-CBC-SHA',
+                        'TLS-DHE-DSS-WITH-AES-256-CBC-SHA', 'TLS-DHE-DSS-WITH-AES-128-CBC-SHA256', 'TLS-DHE-DSS-WITH-AES-128-GCM-SHA256',
+                        'TLS-DHE-DSS-WITH-AES-256-CBC-SHA256', 'TLS-DHE-DSS-WITH-AES-256-GCM-SHA384', 'TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256',
+                        'TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256', 'TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384', 'TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384',
+                        'TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA', 'TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256', 'TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256',
+                        'TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384', 'TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384', 'TLS-RSA-WITH-AES-128-GCM-SHA256',
+                        'TLS-RSA-WITH-AES-256-GCM-SHA384', 'TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA', 'TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA',
+                        'TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256', 'TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256', 'TLS-DHE-DSS-WITH-SEED-CBC-SHA',
+                        'TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256', 'TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384', 'TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256',
+                        'TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384', 'TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256', 'TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384',
+                        'TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA', 'TLS-DHE-DSS-WITH-DES-CBC-SHA', 'TLS-AES-128-GCM-SHA256', 'TLS-AES-256-GCM-SHA384',
+                        'TLS-CHACHA20-POLY1305-SHA256', 'TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA'
                     ],
                     'type': 'str'
                 },
-                'priority': {
-                    'required': False,
-                    'revision': {
-                        '7.2.1': True,
-                        '7.2.2': True,
-                        '7.4.0': True
-                    },
-                    'type': 'int'
-                },
-                'versions': {
-                    'required': False,
-                    'revision': {
-                        '7.2.1': True,
-                        '7.2.2': True,
-                        '7.4.0': True
-                    },
-                    'type': 'list',
-                    'choices': [
-                        'tls-1.0',
-                        'tls-1.1',
-                        'tls-1.2',
-                        'tls-1.3'
-                    ],
-                    'elements': 'str'
-                }
+                'priority': {'v_range': [['7.2.1', '']], 'type': 'int'},
+                'versions': {'v_range': [['7.2.1', '']], 'type': 'list', 'choices': ['tls-1.0', 'tls-1.1', 'tls-1.2', 'tls-1.3'], 'elements': 'str'}
             }
 
         }
     }
 
+    module_option_spec = get_module_arg_spec('full crud')
+    module_arg_spec.update(module_option_spec)
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'firewall_accessproxy6_apigateway_sslciphersuites'),
                            supports_check_mode=False)
 
-    fmgr = None
-    if module._socket_path:
-        connection = Connection(module._socket_path)
-        connection.set_option('access_token', module.params['access_token'] if 'access_token' in module.params else None)
-        connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
-        connection.set_option('forticloud_access_token',
-                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
-        fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
-        fmgr.validate_parameters(params_validation_blob)
-        fmgr.process_curd(argument_specs=module_arg_spec)
-    else:
+    if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
+    connection = Connection(module._socket_path)
+    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr.validate_parameters(params_validation_blob)
+    fmgr.process_curd(argument_specs=module_arg_spec)
+
     module.exit_json(meta=module.params)
 
 
