@@ -153,7 +153,7 @@ options:
                 description: Deprecated, please rename it to ssh_client_cert. Set access-proxy SSH client certificate profile.
             ssh-host-key:
                 type: raw
-                description: (list or str) Deprecated, please rename it to ssh_host_key.
+                description: (list or str) Deprecated, please rename it to ssh_host_key. One or more server host key.
             ssh-host-key-validation:
                 type: str
                 description: Deprecated, please rename it to ssh_host_key_validation. Enable/disable SSH real server host key validation.
@@ -344,9 +344,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
