@@ -101,7 +101,7 @@ options:
                 description: Deprecated, please rename it to ip_range_number. Total number of IP ranges.
             port:
                 type: raw
-                description: (list) No description.
+                description: (list) Integer value for the TCP/IP port
             protocol:
                 type: int
                 description: Integer value for the protocol type as defined by IANA
@@ -219,9 +219,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
