@@ -96,38 +96,38 @@ options:
             _scope:
                 type: list
                 elements: dict
-                description: No description.
+                description: Scope.
                 suboptions:
                     name:
                         type: str
-                        description: No description.
+                        description: Name.
                     vdom:
                         type: str
-                        description: No description.
+                        description: Vdom.
             arp-reply:
                 type: str
-                description: Deprecated, please rename it to arp_reply.
+                description: Deprecated, please rename it to arp_reply. Arp reply.
                 choices:
                     - 'disable'
                     - 'enable'
             color:
                 type: int
-                description: No description.
+                description: Color.
             comment:
                 type: str
-                description: No description.
+                description: Comment.
             extip:
                 type: str
-                description: No description.
+                description: Extip.
             extport:
                 type: str
-                description: No description.
+                description: Extport.
             id:
                 type: int
-                description: No description.
+                description: Id.
             ldb-method:
                 type: str
-                description: Deprecated, please rename it to ldb_method.
+                description: Deprecated, please rename it to ldb_method. Ldb method.
                 choices:
                     - 'static'
                     - 'round-robin'
@@ -137,28 +137,28 @@ options:
                     - 'first-alive'
             mappedip:
                 type: str
-                description: No description.
+                description: Mappedip.
             mappedport:
                 type: str
-                description: No description.
+                description: Mappedport.
             monitor:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Monitor.
             portforward:
                 type: str
-                description: No description.
+                description: Portforward.
                 choices:
                     - 'disable'
                     - 'enable'
             protocol:
                 type: str
-                description: No description.
+                description: Protocol.
                 choices:
                     - 'tcp'
                     - 'udp'
             server-type:
                 type: str
-                description: Deprecated, please rename it to server_type.
+                description: Deprecated, please rename it to server_type. Server type.
                 choices:
                     - 'http'
                     - 'tcp'
@@ -166,16 +166,16 @@ options:
                     - 'ip'
             src-filter:
                 type: raw
-                description: (list) Deprecated, please rename it to src_filter.
+                description: (list) Deprecated, please rename it to src_filter. Src filter.
             type:
                 type: str
-                description: No description.
+                description: Type.
                 choices:
                     - 'static-nat'
                     - 'server-load-balance'
             uuid:
                 type: str
-                description: No description.
+                description: Uuid.
             srcintf-filter:
                 type: raw
                 description: (list or str) Deprecated, please rename it to srcintf_filter. Interfaces to which the VIP46 applies.
@@ -325,9 +325,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
