@@ -96,83 +96,83 @@ options:
             _scope:
                 type: list
                 elements: dict
-                description: No description.
+                description: Scope.
                 suboptions:
                     name:
                         type: str
-                        description: No description.
+                        description: Name.
                     vdom:
                         type: str
-                        description: No description.
+                        description: Vdom.
             arp-reply:
                 type: str
-                description: Deprecated, please rename it to arp_reply.
+                description: Deprecated, please rename it to arp_reply. Arp reply.
                 choices:
                     - 'disable'
                     - 'enable'
             color:
                 type: int
-                description: No description.
+                description: Color.
             comment:
                 type: str
-                description: No description.
+                description: Comment.
             extip:
                 type: str
-                description: No description.
+                description: Extip.
             extport:
                 type: str
-                description: No description.
+                description: Extport.
             http-cookie-age:
                 type: int
-                description: Deprecated, please rename it to http_cookie_age.
+                description: Deprecated, please rename it to http_cookie_age. Http cookie age.
             http-cookie-domain:
                 type: str
-                description: Deprecated, please rename it to http_cookie_domain.
+                description: Deprecated, please rename it to http_cookie_domain. Http cookie domain.
             http-cookie-domain-from-host:
                 type: str
-                description: Deprecated, please rename it to http_cookie_domain_from_host.
+                description: Deprecated, please rename it to http_cookie_domain_from_host. Http cookie domain from host.
                 choices:
                     - 'disable'
                     - 'enable'
             http-cookie-generation:
                 type: int
-                description: Deprecated, please rename it to http_cookie_generation.
+                description: Deprecated, please rename it to http_cookie_generation. Http cookie generation.
             http-cookie-path:
                 type: str
-                description: Deprecated, please rename it to http_cookie_path.
+                description: Deprecated, please rename it to http_cookie_path. Http cookie path.
             http-cookie-share:
                 type: str
-                description: Deprecated, please rename it to http_cookie_share.
+                description: Deprecated, please rename it to http_cookie_share. Http cookie share.
                 choices:
                     - 'disable'
                     - 'same-ip'
             http-ip-header:
                 type: str
-                description: Deprecated, please rename it to http_ip_header.
+                description: Deprecated, please rename it to http_ip_header. Http ip header.
                 choices:
                     - 'disable'
                     - 'enable'
             http-ip-header-name:
                 type: str
-                description: Deprecated, please rename it to http_ip_header_name.
+                description: Deprecated, please rename it to http_ip_header_name. Http ip header name.
             http-multiplex:
                 type: str
-                description: Deprecated, please rename it to http_multiplex.
+                description: Deprecated, please rename it to http_multiplex. Http multiplex.
                 choices:
                     - 'disable'
                     - 'enable'
             https-cookie-secure:
                 type: str
-                description: Deprecated, please rename it to https_cookie_secure.
+                description: Deprecated, please rename it to https_cookie_secure. Https cookie secure.
                 choices:
                     - 'disable'
                     - 'enable'
             id:
                 type: int
-                description: No description.
+                description: Id.
             ldb-method:
                 type: str
-                description: Deprecated, please rename it to ldb_method.
+                description: Deprecated, please rename it to ldb_method. Ldb method.
                 choices:
                     - 'static'
                     - 'round-robin'
@@ -183,45 +183,45 @@ options:
                     - 'http-host'
             mappedip:
                 type: str
-                description: No description.
+                description: Mappedip.
             mappedport:
                 type: str
-                description: No description.
+                description: Mappedport.
             max-embryonic-connections:
                 type: int
-                description: Deprecated, please rename it to max_embryonic_connections.
+                description: Deprecated, please rename it to max_embryonic_connections. Max embryonic connections.
             monitor:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Monitor.
             outlook-web-access:
                 type: str
-                description: Deprecated, please rename it to outlook_web_access.
+                description: Deprecated, please rename it to outlook_web_access. Outlook web access.
                 choices:
                     - 'disable'
                     - 'enable'
             persistence:
                 type: str
-                description: No description.
+                description: Persistence.
                 choices:
                     - 'none'
                     - 'http-cookie'
                     - 'ssl-session-id'
             portforward:
                 type: str
-                description: No description.
+                description: Portforward.
                 choices:
                     - 'disable'
                     - 'enable'
             protocol:
                 type: str
-                description: No description.
+                description: Protocol.
                 choices:
                     - 'tcp'
                     - 'udp'
                     - 'sctp'
             server-type:
                 type: str
-                description: Deprecated, please rename it to server_type.
+                description: Deprecated, please rename it to server_type. Server type.
                 choices:
                     - 'http'
                     - 'https'
@@ -234,10 +234,10 @@ options:
                     - 'smtps'
             src-filter:
                 type: raw
-                description: (list) Deprecated, please rename it to src_filter.
+                description: (list) Deprecated, please rename it to src_filter. Src filter.
             ssl-algorithm:
                 type: str
-                description: Deprecated, please rename it to ssl_algorithm.
+                description: Deprecated, please rename it to ssl_algorithm. Ssl algorithm.
                 choices:
                     - 'high'
                     - 'low'
@@ -245,29 +245,29 @@ options:
                     - 'custom'
             ssl-certificate:
                 type: str
-                description: Deprecated, please rename it to ssl_certificate.
+                description: Deprecated, please rename it to ssl_certificate. Ssl certificate.
             ssl-client-fallback:
                 type: str
-                description: Deprecated, please rename it to ssl_client_fallback.
+                description: Deprecated, please rename it to ssl_client_fallback. Ssl client fallback.
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-client-renegotiation:
                 type: str
-                description: Deprecated, please rename it to ssl_client_renegotiation.
+                description: Deprecated, please rename it to ssl_client_renegotiation. Ssl client renegotiation.
                 choices:
                     - 'deny'
                     - 'allow'
                     - 'secure'
             ssl-client-session-state-max:
                 type: int
-                description: Deprecated, please rename it to ssl_client_session_state_max.
+                description: Deprecated, please rename it to ssl_client_session_state_max. Ssl client session state max.
             ssl-client-session-state-timeout:
                 type: int
-                description: Deprecated, please rename it to ssl_client_session_state_timeout.
+                description: Deprecated, please rename it to ssl_client_session_state_timeout. Ssl client session state timeout.
             ssl-client-session-state-type:
                 type: str
-                description: Deprecated, please rename it to ssl_client_session_state_type.
+                description: Deprecated, please rename it to ssl_client_session_state_type. Ssl client session state type.
                 choices:
                     - 'disable'
                     - 'time'
@@ -275,7 +275,7 @@ options:
                     - 'both'
             ssl-dh-bits:
                 type: str
-                description: Deprecated, please rename it to ssl_dh_bits.
+                description: Deprecated, please rename it to ssl_dh_bits. Ssl dh bits.
                 choices:
                     - '768'
                     - '1024'
@@ -285,59 +285,59 @@ options:
                     - '4096'
             ssl-hpkp:
                 type: str
-                description: Deprecated, please rename it to ssl_hpkp.
+                description: Deprecated, please rename it to ssl_hpkp. Ssl hpkp.
                 choices:
                     - 'disable'
                     - 'enable'
                     - 'report-only'
             ssl-hpkp-age:
                 type: int
-                description: Deprecated, please rename it to ssl_hpkp_age.
+                description: Deprecated, please rename it to ssl_hpkp_age. Ssl hpkp age.
             ssl-hpkp-backup:
                 type: str
-                description: Deprecated, please rename it to ssl_hpkp_backup.
+                description: Deprecated, please rename it to ssl_hpkp_backup. Ssl hpkp backup.
             ssl-hpkp-include-subdomains:
                 type: str
-                description: Deprecated, please rename it to ssl_hpkp_include_subdomains.
+                description: Deprecated, please rename it to ssl_hpkp_include_subdomains. Ssl hpkp include subdomains.
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-hpkp-primary:
                 type: str
-                description: Deprecated, please rename it to ssl_hpkp_primary.
+                description: Deprecated, please rename it to ssl_hpkp_primary. Ssl hpkp primary.
             ssl-hpkp-report-uri:
                 type: str
-                description: Deprecated, please rename it to ssl_hpkp_report_uri.
+                description: Deprecated, please rename it to ssl_hpkp_report_uri. Ssl hpkp report uri.
             ssl-hsts:
                 type: str
-                description: Deprecated, please rename it to ssl_hsts.
+                description: Deprecated, please rename it to ssl_hsts. Ssl hsts.
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-hsts-age:
                 type: int
-                description: Deprecated, please rename it to ssl_hsts_age.
+                description: Deprecated, please rename it to ssl_hsts_age. Ssl hsts age.
             ssl-hsts-include-subdomains:
                 type: str
-                description: Deprecated, please rename it to ssl_hsts_include_subdomains.
+                description: Deprecated, please rename it to ssl_hsts_include_subdomains. Ssl hsts include subdomains.
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-http-location-conversion:
                 type: str
-                description: Deprecated, please rename it to ssl_http_location_conversion.
+                description: Deprecated, please rename it to ssl_http_location_conversion. Ssl http location conversion.
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-http-match-host:
                 type: str
-                description: Deprecated, please rename it to ssl_http_match_host.
+                description: Deprecated, please rename it to ssl_http_match_host. Ssl http match host.
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-max-version:
                 type: str
-                description: Deprecated, please rename it to ssl_max_version.
+                description: Deprecated, please rename it to ssl_max_version. Ssl max version.
                 choices:
                     - 'ssl-3.0'
                     - 'tls-1.0'
@@ -346,7 +346,7 @@ options:
                     - 'tls-1.3'
             ssl-min-version:
                 type: str
-                description: Deprecated, please rename it to ssl_min_version.
+                description: Deprecated, please rename it to ssl_min_version. Ssl min version.
                 choices:
                     - 'ssl-3.0'
                     - 'tls-1.0'
@@ -355,26 +355,26 @@ options:
                     - 'tls-1.3'
             ssl-mode:
                 type: str
-                description: Deprecated, please rename it to ssl_mode.
+                description: Deprecated, please rename it to ssl_mode. Ssl mode.
                 choices:
                     - 'half'
                     - 'full'
             ssl-pfs:
                 type: str
-                description: Deprecated, please rename it to ssl_pfs.
+                description: Deprecated, please rename it to ssl_pfs. Ssl pfs.
                 choices:
                     - 'require'
                     - 'deny'
                     - 'allow'
             ssl-send-empty-frags:
                 type: str
-                description: Deprecated, please rename it to ssl_send_empty_frags.
+                description: Deprecated, please rename it to ssl_send_empty_frags. Ssl send empty frags.
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-server-algorithm:
                 type: str
-                description: Deprecated, please rename it to ssl_server_algorithm.
+                description: Deprecated, please rename it to ssl_server_algorithm. Ssl server algorithm.
                 choices:
                     - 'high'
                     - 'low'
@@ -383,7 +383,7 @@ options:
                     - 'client'
             ssl-server-max-version:
                 type: str
-                description: Deprecated, please rename it to ssl_server_max_version.
+                description: Deprecated, please rename it to ssl_server_max_version. Ssl server max version.
                 choices:
                     - 'ssl-3.0'
                     - 'tls-1.0'
@@ -393,7 +393,7 @@ options:
                     - 'tls-1.3'
             ssl-server-min-version:
                 type: str
-                description: Deprecated, please rename it to ssl_server_min_version.
+                description: Deprecated, please rename it to ssl_server_min_version. Ssl server min version.
                 choices:
                     - 'ssl-3.0'
                     - 'tls-1.0'
@@ -403,13 +403,13 @@ options:
                     - 'tls-1.3'
             ssl-server-session-state-max:
                 type: int
-                description: Deprecated, please rename it to ssl_server_session_state_max.
+                description: Deprecated, please rename it to ssl_server_session_state_max. Ssl server session state max.
             ssl-server-session-state-timeout:
                 type: int
-                description: Deprecated, please rename it to ssl_server_session_state_timeout.
+                description: Deprecated, please rename it to ssl_server_session_state_timeout. Ssl server session state timeout.
             ssl-server-session-state-type:
                 type: str
-                description: Deprecated, please rename it to ssl_server_session_state_type.
+                description: Deprecated, please rename it to ssl_server_session_state_type. Ssl server session state type.
                 choices:
                     - 'disable'
                     - 'time'
@@ -417,38 +417,38 @@ options:
                     - 'both'
             type:
                 type: str
-                description: No description.
+                description: Type.
                 choices:
                     - 'static-nat'
                     - 'server-load-balance'
                     - 'access-proxy'
             uuid:
                 type: str
-                description: No description.
+                description: Uuid.
             weblogic-server:
                 type: str
-                description: Deprecated, please rename it to weblogic_server.
+                description: Deprecated, please rename it to weblogic_server. Weblogic server.
                 choices:
                     - 'disable'
                     - 'enable'
             websphere-server:
                 type: str
-                description: Deprecated, please rename it to websphere_server.
+                description: Deprecated, please rename it to websphere_server. Websphere server.
                 choices:
                     - 'disable'
                     - 'enable'
             http-redirect:
                 type: str
-                description: Deprecated, please rename it to http_redirect.
+                description: Deprecated, please rename it to http_redirect. Http redirect.
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-client-rekey-count:
                 type: int
-                description: Deprecated, please rename it to ssl_client_rekey_count.
+                description: Deprecated, please rename it to ssl_client_rekey_count. Ssl client rekey count.
             nat-source-vip:
                 type: str
-                description: Deprecated, please rename it to nat_source_vip.
+                description: Deprecated, please rename it to nat_source_vip. Nat source vip.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -485,7 +485,7 @@ options:
             realservers:
                 type: list
                 elements: dict
-                description: No description.
+                description: Realservers.
                 suboptions:
                     client-ip:
                         type: str
@@ -514,7 +514,7 @@ options:
                         description: Deprecated, please rename it to max_connections. Max number of active connections that can directed to the real se...
                     monitor:
                         type: raw
-                        description: (list or str) No description.
+                        description: (list or str) Name of the health check monitor to use when polling to determine a virtual servers connectivity status.
                     port:
                         type: int
                         description: Port for communicating with the real server.
@@ -543,7 +543,7 @@ options:
             ssl-cipher-suites:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to ssl_cipher_suites.
+                description: Deprecated, please rename it to ssl_cipher_suites. Ssl cipher suites.
                 suboptions:
                     cipher:
                         type: str
@@ -626,7 +626,7 @@ options:
                     versions:
                         type: list
                         elements: str
-                        description: No description.
+                        description: SSL/TLS versions that the cipher suite can be used with.
                         choices:
                             - 'ssl-3.0'
                             - 'tls-1.0'
@@ -657,6 +657,12 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
+            src-vip-filter:
+                type: str
+                description: Deprecated, please rename it to src_vip_filter. Enable/disable use of src-filter to match destinations for the reverse SNA...
+                choices:
+                    - 'disable'
+                    - 'enable'
 '''
 
 EXAMPLES = '''
@@ -906,10 +912,11 @@ def main():
                     },
                     'elements': 'dict'
                 },
-                'ndp-reply': {'v_range': [['7.0.5', '7.0.10'], ['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'ndp-reply': {'v_range': [['7.0.5', '7.0.12'], ['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'ssl-server-renegotiation': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'h2-support': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'h3-support': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'h3-support': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'src-vip-filter': {'v_range': [['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
 
         }
@@ -925,9 +932,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
