@@ -12,7 +12,7 @@ ANSIBLE_METADATA = {'status': ['preview'],
 DOCUMENTATION = '''
 ---
 module: fmgr_fmg_fabric_authorization_template
-short_description: no description
+short_description: Fmg fabric authorization template
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
@@ -91,53 +91,53 @@ options:
         suboptions:
             description:
                 type: str
-                description: No description.
+                description: Description.
             extender-controller:
                 type: str
-                description: Deprecated, please rename it to extender_controller.
+                description: Deprecated, please rename it to extender_controller. Extender controller.
                 choices:
                     - 'disable'
                     - 'enable'
             name:
                 type: str
-                description: No description.
+                description: Name.
                 required: true
             platforms:
                 type: list
                 elements: dict
-                description: No description.
+                description: Platforms.
                 suboptions:
                     count:
                         type: int
-                        description: No description.
+                        description: Count.
                     extension-type:
                         type: str
-                        description: Deprecated, please rename it to extension_type.
+                        description: Deprecated, please rename it to extension_type. Extension type.
                         choices:
                             - 'wan-extension'
                             - 'lan-extension'
                     fortilink:
                         type: str
-                        description: No description.
+                        description: Fortilink.
                     prefix:
                         type: str
-                        description: No description.
+                        description: Prefix.
                     type:
                         type: str
-                        description: No description.
+                        description: Type.
                         choices:
                             - 'ap'
                             - 'extender'
                             - 'switch'
             switch-controller:
                 type: str
-                description: Deprecated, please rename it to switch_controller.
+                description: Deprecated, please rename it to switch_controller. Switch controller.
                 choices:
                     - 'disable'
                     - 'enable'
             wireless-controller:
                 type: str
-                description: Deprecated, please rename it to wireless_controller.
+                description: Deprecated, please rename it to wireless_controller. Wireless controller.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -152,7 +152,7 @@ EXAMPLES = '''
     ansible_httpapi_validate_certs: false
     ansible_httpapi_port: 443
   tasks:
-    - name: No description
+    - name: Fmg fabric authorization template
       fortinet.fortimanager.fmgr_fmg_fabric_authorization_template:
         # bypass_validation: false
         workspace_locking_adom: <value in [global, custom adom including root]>
@@ -274,9 +274,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
