@@ -92,7 +92,7 @@ options:
             friendly-name:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to friendly_name. Friendly-Name.
+                description: Deprecated, please rename it to friendly_name. Friendly name.
                 suboptions:
                     friendly-name:
                         type: str
@@ -127,7 +127,7 @@ options:
             service-description:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to service_description. Service-Description.
+                description: Deprecated, please rename it to service_description. Service description.
                 suboptions:
                     lang:
                         type: str
@@ -275,9 +275,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
