@@ -101,7 +101,7 @@ options:
             server-group:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to server_group.
+                description: Deprecated, please rename it to server_group. Server group.
                 suboptions:
                     group-name:
                         type: str
@@ -149,7 +149,7 @@ options:
             server-info:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to server_info.
+                description: Deprecated, please rename it to server_info. Server info.
                 suboptions:
                     dest-port:
                         type: int
@@ -369,9 +369,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_partial_curd(argument_specs=module_arg_spec)
