@@ -91,7 +91,7 @@ options:
         suboptions:
             action:
                 type: str
-                description: No description.
+                description: Action.
                 choices:
                     - 'deny'
                     - 'accept'
@@ -99,130 +99,130 @@ options:
                     - 'ssl-vpn'
             anti-replay:
                 type: str
-                description: Deprecated, please rename it to anti_replay.
+                description: Deprecated, please rename it to anti_replay. Anti replay.
                 choices:
                     - 'disable'
                     - 'enable'
             app-category:
                 type: raw
-                description: (list or str) Deprecated, please rename it to app_category.
+                description: (list or str) Deprecated, please rename it to app_category. App category.
             app-group:
                 type: raw
-                description: (list or str) Deprecated, please rename it to app_group.
+                description: (list or str) Deprecated, please rename it to app_group. App group.
             application:
                 type: raw
-                description: (list) No description.
+                description: (list) Application.
             application-charts:
                 type: list
                 elements: str
-                description: Deprecated, please rename it to application_charts.
+                description: Deprecated, please rename it to application_charts. Application charts.
                 choices:
                     - 'top10-app'
                     - 'top10-p2p-user'
                     - 'top10-media-user'
             application-list:
                 type: raw
-                description: (list or str) Deprecated, please rename it to application_list.
+                description: (list or str) Deprecated, please rename it to application_list. Application list.
             auto-asic-offload:
                 type: str
-                description: Deprecated, please rename it to auto_asic_offload.
+                description: Deprecated, please rename it to auto_asic_offload. Auto asic offload.
                 choices:
                     - 'disable'
                     - 'enable'
             av-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to av_profile.
+                description: (list or str) Deprecated, please rename it to av_profile. Av profile.
             casi-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to casi_profile.
+                description: (list or str) Deprecated, please rename it to casi_profile. Casi profile.
             cifs-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to cifs_profile.
+                description: (list or str) Deprecated, please rename it to cifs_profile. Cifs profile.
             comments:
                 type: str
-                description: No description.
+                description: Comments.
             custom-log-fields:
                 type: raw
-                description: (list or str) Deprecated, please rename it to custom_log_fields.
+                description: (list or str) Deprecated, please rename it to custom_log_fields. Custom log fields.
             deep-inspection-options:
                 type: raw
-                description: (list or str) Deprecated, please rename it to deep_inspection_options.
+                description: (list or str) Deprecated, please rename it to deep_inspection_options. Deep inspection options.
             device-detection-portal:
                 type: str
-                description: Deprecated, please rename it to device_detection_portal.
+                description: Deprecated, please rename it to device_detection_portal. Device detection portal.
                 choices:
                     - 'disable'
                     - 'enable'
             devices:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Devices.
             diffserv-forward:
                 type: str
-                description: Deprecated, please rename it to diffserv_forward.
+                description: Deprecated, please rename it to diffserv_forward. Diffserv forward.
                 choices:
                     - 'disable'
                     - 'enable'
             diffserv-reverse:
                 type: str
-                description: Deprecated, please rename it to diffserv_reverse.
+                description: Deprecated, please rename it to diffserv_reverse. Diffserv reverse.
                 choices:
                     - 'disable'
                     - 'enable'
             diffservcode-forward:
                 type: str
-                description: Deprecated, please rename it to diffservcode_forward.
+                description: Deprecated, please rename it to diffservcode_forward. Diffservcode forward.
             diffservcode-rev:
                 type: str
-                description: Deprecated, please rename it to diffservcode_rev.
+                description: Deprecated, please rename it to diffservcode_rev. Diffservcode rev.
             dlp-sensor:
                 type: raw
-                description: (list or str) Deprecated, please rename it to dlp_sensor.
+                description: (list or str) Deprecated, please rename it to dlp_sensor. Dlp sensor.
             dnsfilter-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to dnsfilter_profile.
+                description: (list or str) Deprecated, please rename it to dnsfilter_profile. Dnsfilter profile.
             dscp-match:
                 type: str
-                description: Deprecated, please rename it to dscp_match.
+                description: Deprecated, please rename it to dscp_match. Dscp match.
                 choices:
                     - 'disable'
                     - 'enable'
             dscp-negate:
                 type: str
-                description: Deprecated, please rename it to dscp_negate.
+                description: Deprecated, please rename it to dscp_negate. Dscp negate.
                 choices:
                     - 'disable'
                     - 'enable'
             dscp-value:
                 type: str
-                description: Deprecated, please rename it to dscp_value.
+                description: Deprecated, please rename it to dscp_value. Dscp value.
             dsri:
                 type: str
-                description: No description.
+                description: Dsri.
                 choices:
                     - 'disable'
                     - 'enable'
             dstaddr:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Dstaddr.
             dstaddr-negate:
                 type: str
-                description: Deprecated, please rename it to dstaddr_negate.
+                description: Deprecated, please rename it to dstaddr_negate. Dstaddr negate.
                 choices:
                     - 'disable'
                     - 'enable'
             dstintf:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Dstintf.
             dynamic-profile:
                 type: str
-                description: Deprecated, please rename it to dynamic_profile.
+                description: Deprecated, please rename it to dynamic_profile. Dynamic profile.
                 choices:
                     - 'disable'
                     - 'enable'
             dynamic-profile-access:
                 type: list
                 elements: str
-                description: Deprecated, please rename it to dynamic_profile_access.
+                description: Deprecated, please rename it to dynamic_profile_access. Dynamic profile access.
                 choices:
                     - 'imap'
                     - 'smtp'
@@ -238,102 +238,102 @@ options:
                     - 'ftps'
             dynamic-profile-group:
                 type: raw
-                description: (list or str) Deprecated, please rename it to dynamic_profile_group.
+                description: (list or str) Deprecated, please rename it to dynamic_profile_group. Dynamic profile group.
             email-collection-portal:
                 type: str
-                description: Deprecated, please rename it to email_collection_portal.
+                description: Deprecated, please rename it to email_collection_portal. Email collection portal.
                 choices:
                     - 'disable'
                     - 'enable'
             emailfilter-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to emailfilter_profile.
+                description: (list or str) Deprecated, please rename it to emailfilter_profile. Emailfilter profile.
             firewall-session-dirty:
                 type: str
-                description: Deprecated, please rename it to firewall_session_dirty.
+                description: Deprecated, please rename it to firewall_session_dirty. Firewall session dirty.
                 choices:
                     - 'check-all'
                     - 'check-new'
             fixedport:
                 type: str
-                description: No description.
+                description: Fixedport.
                 choices:
                     - 'disable'
                     - 'enable'
             fsae:
                 type: str
-                description: No description.
+                description: Fsae.
                 choices:
                     - 'disable'
                     - 'enable'
             global-label:
                 type: str
-                description: Deprecated, please rename it to global_label.
+                description: Deprecated, please rename it to global_label. Global label.
             groups:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Groups.
             http-policy-redirect:
                 type: str
-                description: Deprecated, please rename it to http_policy_redirect.
+                description: Deprecated, please rename it to http_policy_redirect. Http policy redirect.
                 choices:
                     - 'disable'
                     - 'enable'
             icap-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to icap_profile.
+                description: (list or str) Deprecated, please rename it to icap_profile. Icap profile.
             identity-based:
                 type: str
-                description: Deprecated, please rename it to identity_based.
+                description: Deprecated, please rename it to identity_based. Identity based.
                 choices:
                     - 'disable'
                     - 'enable'
             identity-based-policy6:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to identity_based_policy6.
+                description: Deprecated, please rename it to identity_based_policy6. Identity based policy6.
                 suboptions:
                     action:
                         type: str
-                        description: No description.
+                        description: Action.
                         choices:
                             - 'deny'
                             - 'accept'
                     application-list:
                         type: str
-                        description: Deprecated, please rename it to application_list.
+                        description: Deprecated, please rename it to application_list. Application list.
                     av-profile:
                         type: str
-                        description: Deprecated, please rename it to av_profile.
+                        description: Deprecated, please rename it to av_profile. Av profile.
                     deep-inspection-options:
                         type: str
-                        description: Deprecated, please rename it to deep_inspection_options.
+                        description: Deprecated, please rename it to deep_inspection_options. Deep inspection options.
                     devices:
                         type: str
-                        description: No description.
+                        description: Devices.
                     dlp-sensor:
                         type: str
-                        description: Deprecated, please rename it to dlp_sensor.
+                        description: Deprecated, please rename it to dlp_sensor. Dlp sensor.
                     endpoint-compliance:
                         type: str
-                        description: Deprecated, please rename it to endpoint_compliance.
+                        description: Deprecated, please rename it to endpoint_compliance. Endpoint compliance.
                         choices:
                             - 'disable'
                             - 'enable'
                     groups:
                         type: str
-                        description: No description.
+                        description: Groups.
                     icap-profile:
                         type: str
-                        description: Deprecated, please rename it to icap_profile.
+                        description: Deprecated, please rename it to icap_profile. Icap profile.
                     id:
                         type: int
-                        description: No description.
+                        description: Id.
                     ips-sensor:
                         type: str
-                        description: Deprecated, please rename it to ips_sensor.
+                        description: Deprecated, please rename it to ips_sensor. Ips sensor.
                     logtraffic:
                         type: str
-                        description: No description.
+                        description: Logtraffic.
                         choices:
                             - 'disable'
                             - 'enable'
@@ -341,103 +341,103 @@ options:
                             - 'utm'
                     mms-profile:
                         type: str
-                        description: Deprecated, please rename it to mms_profile.
+                        description: Deprecated, please rename it to mms_profile. Mms profile.
                     per-ip-shaper:
                         type: str
-                        description: Deprecated, please rename it to per_ip_shaper.
+                        description: Deprecated, please rename it to per_ip_shaper. Per ip shaper.
                     profile-group:
                         type: str
-                        description: Deprecated, please rename it to profile_group.
+                        description: Deprecated, please rename it to profile_group. Profile group.
                     profile-protocol-options:
                         type: str
-                        description: Deprecated, please rename it to profile_protocol_options.
+                        description: Deprecated, please rename it to profile_protocol_options. Profile protocol options.
                     profile-type:
                         type: str
-                        description: Deprecated, please rename it to profile_type.
+                        description: Deprecated, please rename it to profile_type. Profile type.
                         choices:
                             - 'single'
                             - 'group'
                     replacemsg-group:
                         type: str
-                        description: Deprecated, please rename it to replacemsg_group.
+                        description: Deprecated, please rename it to replacemsg_group. Replacemsg group.
                     schedule:
                         type: str
-                        description: No description.
+                        description: Schedule.
                     send-deny-packet:
                         type: str
-                        description: Deprecated, please rename it to send_deny_packet.
+                        description: Deprecated, please rename it to send_deny_packet. Send deny packet.
                         choices:
                             - 'disable'
                             - 'enable'
                     service:
                         type: str
-                        description: No description.
+                        description: Service.
                     service-negate:
                         type: str
-                        description: Deprecated, please rename it to service_negate.
+                        description: Deprecated, please rename it to service_negate. Service negate.
                         choices:
                             - 'disable'
                             - 'enable'
                     spamfilter-profile:
                         type: str
-                        description: Deprecated, please rename it to spamfilter_profile.
+                        description: Deprecated, please rename it to spamfilter_profile. Spamfilter profile.
                     sslvpn-portal:
                         type: str
-                        description: Deprecated, please rename it to sslvpn_portal.
+                        description: Deprecated, please rename it to sslvpn_portal. Sslvpn portal.
                     sslvpn-realm:
                         type: str
-                        description: Deprecated, please rename it to sslvpn_realm.
+                        description: Deprecated, please rename it to sslvpn_realm. Sslvpn realm.
                     traffic-shaper:
                         type: str
-                        description: Deprecated, please rename it to traffic_shaper.
+                        description: Deprecated, please rename it to traffic_shaper. Traffic shaper.
                     traffic-shaper-reverse:
                         type: str
-                        description: Deprecated, please rename it to traffic_shaper_reverse.
+                        description: Deprecated, please rename it to traffic_shaper_reverse. Traffic shaper reverse.
                     utm-status:
                         type: str
-                        description: Deprecated, please rename it to utm_status.
+                        description: Deprecated, please rename it to utm_status. Utm status.
                         choices:
                             - 'disable'
                             - 'enable'
                     voip-profile:
                         type: str
-                        description: Deprecated, please rename it to voip_profile.
+                        description: Deprecated, please rename it to voip_profile. Voip profile.
                     webfilter-profile:
                         type: str
-                        description: Deprecated, please rename it to webfilter_profile.
+                        description: Deprecated, please rename it to webfilter_profile. Webfilter profile.
             identity-from:
                 type: str
-                description: Deprecated, please rename it to identity_from.
+                description: Deprecated, please rename it to identity_from. Identity from.
                 choices:
                     - 'auth'
                     - 'device'
             inbound:
                 type: str
-                description: No description.
+                description: Inbound.
                 choices:
                     - 'disable'
                     - 'enable'
             inspection-mode:
                 type: str
-                description: Deprecated, please rename it to inspection_mode.
+                description: Deprecated, please rename it to inspection_mode. Inspection mode.
                 choices:
                     - 'proxy'
                     - 'flow'
             ippool:
                 type: str
-                description: No description.
+                description: Ippool.
                 choices:
                     - 'disable'
                     - 'enable'
             ips-sensor:
                 type: raw
-                description: (list or str) Deprecated, please rename it to ips_sensor.
+                description: (list or str) Deprecated, please rename it to ips_sensor. Ips sensor.
             label:
                 type: str
-                description: No description.
+                description: Label.
             logtraffic:
                 type: str
-                description: No description.
+                description: Logtraffic.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -445,146 +445,146 @@ options:
                     - 'utm'
             logtraffic-start:
                 type: str
-                description: Deprecated, please rename it to logtraffic_start.
+                description: Deprecated, please rename it to logtraffic_start. Logtraffic start.
                 choices:
                     - 'disable'
                     - 'enable'
             mms-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to mms_profile.
+                description: (list or str) Deprecated, please rename it to mms_profile. Mms profile.
             name:
                 type: str
-                description: No description.
+                description: Name.
             nat:
                 type: str
-                description: No description.
+                description: Nat.
                 choices:
                     - 'disable'
                     - 'enable'
             natinbound:
                 type: str
-                description: No description.
+                description: Natinbound.
                 choices:
                     - 'disable'
                     - 'enable'
             natoutbound:
                 type: str
-                description: No description.
+                description: Natoutbound.
                 choices:
                     - 'disable'
                     - 'enable'
             np-accelation:
                 type: str
-                description: Deprecated, please rename it to np_accelation.
+                description: Deprecated, please rename it to np_accelation. Np accelation.
                 choices:
                     - 'disable'
                     - 'enable'
             np-acceleration:
                 type: str
-                description: Deprecated, please rename it to np_acceleration.
+                description: Deprecated, please rename it to np_acceleration. Np acceleration.
                 choices:
                     - 'disable'
                     - 'enable'
             outbound:
                 type: str
-                description: No description.
+                description: Outbound.
                 choices:
                     - 'disable'
                     - 'enable'
             per-ip-shaper:
                 type: raw
-                description: (list or str) Deprecated, please rename it to per_ip_shaper.
+                description: (list or str) Deprecated, please rename it to per_ip_shaper. Per ip shaper.
             policyid:
                 type: int
-                description: No description.
+                description: Policyid.
                 required: true
             poolname:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Poolname.
             profile-group:
                 type: raw
-                description: (list or str) Deprecated, please rename it to profile_group.
+                description: (list or str) Deprecated, please rename it to profile_group. Profile group.
             profile-protocol-options:
                 type: raw
-                description: (list or str) Deprecated, please rename it to profile_protocol_options.
+                description: (list or str) Deprecated, please rename it to profile_protocol_options. Profile protocol options.
             profile-type:
                 type: str
-                description: Deprecated, please rename it to profile_type.
+                description: Deprecated, please rename it to profile_type. Profile type.
                 choices:
                     - 'single'
                     - 'group'
             replacemsg-group:
                 type: raw
-                description: (list or str) Deprecated, please rename it to replacemsg_group.
+                description: (list or str) Deprecated, please rename it to replacemsg_group. Replacemsg group.
             replacemsg-override-group:
                 type: raw
-                description: (list or str) Deprecated, please rename it to replacemsg_override_group.
+                description: (list or str) Deprecated, please rename it to replacemsg_override_group. Replacemsg override group.
             rsso:
                 type: str
-                description: No description.
+                description: Rsso.
                 choices:
                     - 'disable'
                     - 'enable'
             schedule:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Schedule.
             send-deny-packet:
                 type: str
-                description: Deprecated, please rename it to send_deny_packet.
+                description: Deprecated, please rename it to send_deny_packet. Send deny packet.
                 choices:
                     - 'disable'
                     - 'enable'
             service:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Service.
             service-negate:
                 type: str
-                description: Deprecated, please rename it to service_negate.
+                description: Deprecated, please rename it to service_negate. Service negate.
                 choices:
                     - 'disable'
                     - 'enable'
             session-ttl:
                 type: raw
-                description: (int or str) Deprecated, please rename it to session_ttl.
+                description: (int or str) Deprecated, please rename it to session_ttl. Session ttl.
             spamfilter-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to spamfilter_profile.
+                description: (list or str) Deprecated, please rename it to spamfilter_profile. Spamfilter profile.
             srcaddr:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Srcaddr.
             srcaddr-negate:
                 type: str
-                description: Deprecated, please rename it to srcaddr_negate.
+                description: Deprecated, please rename it to srcaddr_negate. Srcaddr negate.
                 choices:
                     - 'disable'
                     - 'enable'
             srcintf:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Srcintf.
             ssh-filter-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to ssh_filter_profile.
+                description: (list or str) Deprecated, please rename it to ssh_filter_profile. Ssh filter profile.
             ssh-policy-redirect:
                 type: str
-                description: Deprecated, please rename it to ssh_policy_redirect.
+                description: Deprecated, please rename it to ssh_policy_redirect. Ssh policy redirect.
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-mirror:
                 type: str
-                description: Deprecated, please rename it to ssl_mirror.
+                description: Deprecated, please rename it to ssl_mirror. Ssl mirror.
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-mirror-intf:
                 type: raw
-                description: (list or str) Deprecated, please rename it to ssl_mirror_intf.
+                description: (list or str) Deprecated, please rename it to ssl_mirror_intf. Ssl mirror intf.
             ssl-ssh-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to ssl_ssh_profile.
+                description: (list or str) Deprecated, please rename it to ssl_ssh_profile. Ssl ssh profile.
             sslvpn-auth:
                 type: str
-                description: Deprecated, please rename it to sslvpn_auth.
+                description: Deprecated, please rename it to sslvpn_auth. Sslvpn auth.
                 choices:
                     - 'any'
                     - 'local'
@@ -593,132 +593,132 @@ options:
                     - 'tacacs+'
             sslvpn-ccert:
                 type: str
-                description: Deprecated, please rename it to sslvpn_ccert.
+                description: Deprecated, please rename it to sslvpn_ccert. Sslvpn ccert.
                 choices:
                     - 'disable'
                     - 'enable'
             sslvpn-cipher:
                 type: str
-                description: Deprecated, please rename it to sslvpn_cipher.
+                description: Deprecated, please rename it to sslvpn_cipher. Sslvpn cipher.
                 choices:
                     - 'any'
                     - 'high'
                     - 'medium'
             status:
                 type: str
-                description: No description.
+                description: Status.
                 choices:
                     - 'disable'
                     - 'enable'
             tags:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Tags.
             tcp-mss-receiver:
                 type: int
-                description: Deprecated, please rename it to tcp_mss_receiver.
+                description: Deprecated, please rename it to tcp_mss_receiver. Tcp mss receiver.
             tcp-mss-sender:
                 type: int
-                description: Deprecated, please rename it to tcp_mss_sender.
+                description: Deprecated, please rename it to tcp_mss_sender. Tcp mss sender.
             tcp-session-without-syn:
                 type: str
-                description: Deprecated, please rename it to tcp_session_without_syn.
+                description: Deprecated, please rename it to tcp_session_without_syn. Tcp session without syn.
                 choices:
                     - 'all'
                     - 'data-only'
                     - 'disable'
             timeout-send-rst:
                 type: str
-                description: Deprecated, please rename it to timeout_send_rst.
+                description: Deprecated, please rename it to timeout_send_rst. Timeout send rst.
                 choices:
                     - 'disable'
                     - 'enable'
             tos:
                 type: str
-                description: No description.
+                description: Tos.
             tos-mask:
                 type: str
-                description: Deprecated, please rename it to tos_mask.
+                description: Deprecated, please rename it to tos_mask. Tos mask.
             tos-negate:
                 type: str
-                description: Deprecated, please rename it to tos_negate.
+                description: Deprecated, please rename it to tos_negate. Tos negate.
                 choices:
                     - 'disable'
                     - 'enable'
             traffic-shaper:
                 type: raw
-                description: (list or str) Deprecated, please rename it to traffic_shaper.
+                description: (list or str) Deprecated, please rename it to traffic_shaper. Traffic shaper.
             traffic-shaper-reverse:
                 type: raw
-                description: (list or str) Deprecated, please rename it to traffic_shaper_reverse.
+                description: (list or str) Deprecated, please rename it to traffic_shaper_reverse. Traffic shaper reverse.
             url-category:
                 type: raw
-                description: (list or str) Deprecated, please rename it to url_category.
+                description: (list or str) Deprecated, please rename it to url_category. Url category.
             users:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Users.
             utm-inspection-mode:
                 type: str
-                description: Deprecated, please rename it to utm_inspection_mode.
+                description: Deprecated, please rename it to utm_inspection_mode. Utm inspection mode.
                 choices:
                     - 'proxy'
                     - 'flow'
             utm-status:
                 type: str
-                description: Deprecated, please rename it to utm_status.
+                description: Deprecated, please rename it to utm_status. Utm status.
                 choices:
                     - 'disable'
                     - 'enable'
             uuid:
                 type: str
-                description: No description.
+                description: Uuid.
             vlan-cos-fwd:
                 type: int
-                description: Deprecated, please rename it to vlan_cos_fwd.
+                description: Deprecated, please rename it to vlan_cos_fwd. Vlan cos fwd.
             vlan-cos-rev:
                 type: int
-                description: Deprecated, please rename it to vlan_cos_rev.
+                description: Deprecated, please rename it to vlan_cos_rev. Vlan cos rev.
             vlan-filter:
                 type: str
-                description: Deprecated, please rename it to vlan_filter.
+                description: Deprecated, please rename it to vlan_filter. Vlan filter.
             voip-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to voip_profile.
+                description: (list or str) Deprecated, please rename it to voip_profile. Voip profile.
             vpntunnel:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Vpntunnel.
             webfilter-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to webfilter_profile.
+                description: (list or str) Deprecated, please rename it to webfilter_profile. Webfilter profile.
             waf-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to waf_profile.
+                description: (list or str) Deprecated, please rename it to waf_profile. Waf profile.
             webcache:
                 type: str
-                description: No description.
+                description: Webcache.
                 choices:
                     - 'disable'
                     - 'enable'
             webcache-https:
                 type: str
-                description: Deprecated, please rename it to webcache_https.
+                description: Deprecated, please rename it to webcache_https. Webcache https.
                 choices:
                     - 'disable'
                     - 'enable'
             webproxy-forward-server:
                 type: raw
-                description: (list or str) Deprecated, please rename it to webproxy_forward_server.
+                description: (list or str) Deprecated, please rename it to webproxy_forward_server. Webproxy forward server.
             webproxy-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to webproxy_profile.
+                description: (list or str) Deprecated, please rename it to webproxy_profile. Webproxy profile.
             fsso-groups:
                 type: raw
-                description: (list or str) Deprecated, please rename it to fsso_groups.
+                description: (list or str) Deprecated, please rename it to fsso_groups. Fsso groups.
             decrypted-traffic-mirror:
                 type: raw
-                description: (list or str) Deprecated, please rename it to decrypted_traffic_mirror.
+                description: (list or str) Deprecated, please rename it to decrypted_traffic_mirror. Decrypted traffic mirror.
             file-filter-profile:
                 type: raw
-                description: (list or str) Deprecated, please rename it to file_filter_profile.
+                description: (list or str) Deprecated, please rename it to file_filter_profile. File filter profile.
             cgn-log-server-grp:
                 type: str
                 description: Deprecated, please rename it to cgn_log_server_grp. NP log server group name
@@ -1023,9 +1023,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
