@@ -82,11 +82,11 @@ options:
         suboptions:
             description:
                 type: str
-                description: No description.
+                description: Description.
             enabled options:
                 type: list
                 elements: str
-                description: Deprecated, please rename it to enabled_options.
+                description: Deprecated, please rename it to enabled_options. Enabled options.
                 choices:
                     - 'none'
                     - 'dns'
@@ -99,24 +99,24 @@ options:
                     - 'log'
             name:
                 type: str
-                description: No description.
+                description: Name.
             oid:
                 type: int
-                description: No description.
+                description: Oid.
             scope member:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to scope_member.
+                description: Deprecated, please rename it to scope_member. Scope member.
                 suboptions:
                     name:
                         type: str
-                        description: No description.
+                        description: Name.
                     vdom:
                         type: str
-                        description: No description.
+                        description: Vdom.
             type:
                 type: str
-                description: No description.
+                description: Type.
                 choices:
                     - 'devprof'
 '''
@@ -255,9 +255,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_partial_curd(argument_specs=module_arg_spec)
