@@ -95,77 +95,77 @@ options:
         suboptions:
             name:
                 type: str
-                description: No description.
+                description: Name.
                 required: true
             obj ver:
                 type: int
-                description: Deprecated, please rename it to obj_ver.
+                description: Deprecated, please rename it to obj_ver. Obj ver.
             oid:
                 type: int
-                description: No description.
+                description: Oid.
             package setting:
                 type: dict
-                description: Deprecated, please rename it to package_setting.
+                description: Deprecated, please rename it to package_setting. Package setting.
                 suboptions:
                     central-nat:
                         type: str
-                        description: Deprecated, please rename it to central_nat.
+                        description: Deprecated, please rename it to central_nat. Central nat.
                         choices:
                             - 'disable'
                             - 'enable'
                     consolidated-firewall-mode:
                         type: str
-                        description: Deprecated, please rename it to consolidated_firewall_mode.
+                        description: Deprecated, please rename it to consolidated_firewall_mode. Consolidated firewall mode.
                         choices:
                             - 'disable'
                             - 'enable'
                     fwpolicy-implicit-log:
                         type: str
-                        description: Deprecated, please rename it to fwpolicy_implicit_log.
+                        description: Deprecated, please rename it to fwpolicy_implicit_log. Fwpolicy implicit log.
                         choices:
                             - 'disable'
                             - 'enable'
                     fwpolicy6-implicit-log:
                         type: str
-                        description: Deprecated, please rename it to fwpolicy6_implicit_log.
+                        description: Deprecated, please rename it to fwpolicy6_implicit_log. Fwpolicy6 implicit log.
                         choices:
                             - 'disable'
                             - 'enable'
                     inspection-mode:
                         type: str
-                        description: Deprecated, please rename it to inspection_mode.
+                        description: Deprecated, please rename it to inspection_mode. Inspection mode.
                         choices:
                             - 'proxy'
                             - 'flow'
                     ngfw-mode:
                         type: str
-                        description: Deprecated, please rename it to ngfw_mode.
+                        description: Deprecated, please rename it to ngfw_mode. Ngfw mode.
                         choices:
                             - 'profile-based'
                             - 'policy-based'
                     ssl-ssh-profile:
                         type: str
-                        description: Deprecated, please rename it to ssl_ssh_profile.
+                        description: Deprecated, please rename it to ssl_ssh_profile. Ssl ssh profile.
             scope member:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to scope_member.
+                description: Deprecated, please rename it to scope_member. Scope member.
                 suboptions:
                     name:
                         type: str
-                        description: No description.
+                        description: Name.
                     vdom:
                         type: str
-                        description: No description.
+                        description: Vdom.
             type:
                 type: str
-                description: No description.
+                description: Type.
                 choices:
                     - 'pkg'
                     - 'folder'
             package settings:
                 type: dict
-                description: Deprecated, please rename it to package_settings.
+                description: Deprecated, please rename it to package_settings. Package settings.
                 suboptions:
                     central-nat:
                         type: str
@@ -359,6 +359,7 @@ def main():
                 'obj ver': {'type': 'int'},
                 'oid': {'type': 'int'},
                 'package setting': {
+                    'v_range': [['6.0.0', '6.4.6'], ['7.0.0', '7.0.0']],
                     'type': 'dict',
                     'options': {
                         'central-nat': {'v_range': [['6.0.0', '6.4.6'], ['7.0.0', '7.0.0']], 'choices': ['disable', 'enable'], 'type': 'str'},
@@ -377,6 +378,7 @@ def main():
                 'scope member': {'type': 'list', 'options': {'name': {'type': 'str'}, 'vdom': {'type': 'str'}}, 'elements': 'dict'},
                 'type': {'choices': ['pkg', 'folder'], 'type': 'str'},
                 'package settings': {
+                    'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']],
                     'type': 'dict',
                     'options': {
                         'central-nat': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
@@ -408,9 +410,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
