@@ -12,7 +12,7 @@ ANSIBLE_METADATA = {'status': ['preview'],
 DOCUMENTATION = '''
 ---
 module: fmgr_pm_wanprof_scopemember
-short_description: no description
+short_description: Sd wan template scope member
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
@@ -95,10 +95,10 @@ options:
         suboptions:
             name:
                 type: str
-                description: No description.
+                description: Name.
             vdom:
                 type: str
-                description: No description.
+                description: Vdom.
 '''
 
 EXAMPLES = '''
@@ -110,7 +110,7 @@ EXAMPLES = '''
     ansible_httpapi_validate_certs: false
     ansible_httpapi_port: 443
   tasks:
-    - name: No description
+    - name: Sd wan template scope member
       fortinet.fortimanager.fmgr_pm_wanprof_scopemember:
         # bypass_validation: false
         workspace_locking_adom: <value in [global, custom adom including root]>
@@ -204,12 +204,9 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_object_member(argument_specs=module_arg_spec)
 
     module.exit_json(meta=module.params)
 
