@@ -84,7 +84,17 @@ options:
             flags:
                 type: list
                 elements: str
-                description: No description.
+                description:
+                    - cp_all_objs - Assign all objects during global policy assignment.
+                    - preview - Generate preview cache only.
+                    - generate_rev - Generate new ADOM revision before install.
+                    - copy_assigned_pkg - For global policy assignment - copy assigned package from ADOM to device.
+                    - unassign - Remove global policy from ADOM.
+                    - ifpolicy_only - Only install interface policies.
+                    - no_ifpolicy - Install regular policies only - do not install interface policies.
+                    - objs_only - Install object
+                    - auto_lock_ws - Automatically lock and unlock workspace when performing security console task.
+                    - copy_only - Only copy to device db.
                 choices:
                     - 'none'
                     - 'cp_all_objs'
@@ -104,14 +114,14 @@ options:
             scope:
                 type: list
                 elements: dict
-                description: No description.
+                description: Scope.
                 suboptions:
                     name:
                         type: str
-                        description: No description.
+                        description: Name.
                     vdom:
                         type: str
-                        description: No description.
+                        description: Vdom.
 '''
 
 EXAMPLES = '''
@@ -304,9 +314,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_exec(argument_specs=module_arg_spec)
