@@ -69,9 +69,9 @@ options:
         required: false
         type: dict
         suboptions:
-            message:
+            fmgr_message:
                 type: str
-                description: Deprecated, please rename it to fmgr_message. Optional message to be stored in event log.
+                description: Optional message to be stored in event log.
 '''
 
 EXAMPLES = '''
@@ -156,7 +156,7 @@ def main():
         'sys_reboot': {
             'type': 'dict',
             'v_range': [['6.2.5', '']],
-            'options': {'message': {'v_range': [['6.2.5', '']], 'type': 'str'}}
+            'options': {'fmgr_message': {'v_range': [['6.2.5', '']], 'type': 'str'}}
 
         }
     }
@@ -171,9 +171,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_exec(argument_specs=module_arg_spec)
