@@ -296,9 +296,9 @@ def main():
                 'severity': {'choices': ['emergency', 'alert', 'critical', 'error', 'warning', 'notification', 'information', 'debug'], 'type': 'str'},
                 'status': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'syslog-name': {'type': 'str'},
-                'cert': {'v_range': [['6.4.6', '6.4.14'], ['7.0.1', '']], 'type': 'str'},
-                'reliable': {'v_range': [['6.4.6', '6.4.14'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'secure-connection': {'v_range': [['6.4.6', '6.4.14'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'cert': {'v_range': [['6.4.6', '6.4.14'], ['7.0.1', '7.4.2']], 'type': 'str'},
+                'reliable': {'v_range': [['6.4.6', '6.4.14'], ['7.0.1', '7.4.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'secure-connection': {'v_range': [['6.4.6', '6.4.14'], ['7.0.1', '7.4.2']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
 
         }
@@ -314,9 +314,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_partial_curd(argument_specs=module_arg_spec)
