@@ -123,7 +123,7 @@ options:
             service-providers:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to service_providers. Service-Providers.
+                description: Deprecated, please rename it to service_providers. Service providers.
                 suboptions:
                     idp-entity-id:
                         type: str
@@ -176,7 +176,7 @@ options:
             fabric-idp:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to fabric_idp. Fabric-Idp.
+                description: Deprecated, please rename it to fabric_idp. Fabric idp.
                 suboptions:
                     dev-id:
                         type: str
@@ -427,9 +427,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_partial_curd(argument_specs=module_arg_spec)
