@@ -71,21 +71,21 @@ options:
         suboptions:
             create_task:
                 type: str
-                description: No description.
+                description: Create task.
             device:
                 type: list
                 elements: dict
-                description: No description.
+                description: Device.
                 suboptions:
                     name:
                         type: str
-                        description: No description.
+                        description: Name.
                     vdom:
                         type: str
-                        description: No description.
+                        description: Vdom.
             flags:
                 type: str
-                description: No description.
+                description: Flags.
                 choices:
                     - 'f_boot_alt_partition'
                     - 'f_skip_retrieve'
@@ -97,7 +97,7 @@ options:
                 description: Support version with a build number.
             schedule_time:
                 type: str
-                description: No description.
+                description: Schedule time.
 '''
 
 EXAMPLES = '''
@@ -219,9 +219,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_exec(argument_specs=module_arg_spec)
