@@ -94,7 +94,7 @@ options:
                 description: Deprecated, please rename it to common_name. Certificate common name.
             id:
                 type: int
-                description: No description.
+                description: Id.
                 required: true
             issuer:
                 type: str
@@ -207,14 +207,14 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'user_certificate': {
             'type': 'dict',
-            'v_range': [['7.0.8', '7.0.10'], ['7.2.3', '']],
+            'v_range': [['7.0.8', '7.0.12'], ['7.2.3', '']],
             'options': {
-                'common-name': {'v_range': [['7.0.8', '7.0.10'], ['7.2.3', '']], 'type': 'str'},
-                'id': {'v_range': [['7.0.8', '7.0.10'], ['7.2.3', '']], 'required': True, 'type': 'int'},
-                'issuer': {'v_range': [['7.0.8', '7.0.10'], ['7.2.3', '']], 'type': 'str'},
-                'name': {'v_range': [['7.0.8', '7.0.10'], ['7.2.3', '']], 'type': 'str'},
-                'status': {'v_range': [['7.0.8', '7.0.10'], ['7.2.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'type': {'v_range': [['7.0.8', '7.0.10'], ['7.2.3', '']], 'choices': ['single-certificate', 'trusted-issuer'], 'type': 'str'}
+                'common-name': {'v_range': [['7.0.8', '7.0.12'], ['7.2.3', '']], 'type': 'str'},
+                'id': {'v_range': [['7.0.8', '7.0.12'], ['7.2.3', '']], 'required': True, 'type': 'int'},
+                'issuer': {'v_range': [['7.0.8', '7.0.12'], ['7.2.3', '']], 'type': 'str'},
+                'name': {'v_range': [['7.0.8', '7.0.12'], ['7.2.3', '']], 'type': 'str'},
+                'status': {'v_range': [['7.0.8', '7.0.12'], ['7.2.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'type': {'v_range': [['7.0.8', '7.0.12'], ['7.2.3', '']], 'choices': ['single-certificate', 'trusted-issuer'], 'type': 'str'}
             }
 
         }
@@ -230,9 +230,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
