@@ -95,20 +95,20 @@ options:
         suboptions:
             id:
                 type: str
-                description: No description.
+                description: Id.
                 required: true
             integration:
                 type: str
-                description: No description.
+                description: Integration.
                 choices:
                     - 'east-west'
                     - 'north-south'
             name:
                 type: str
-                description: No description.
+                description: Name.
             ref-id:
                 type: str
-                description: Deprecated, please rename it to ref_id.
+                description: Deprecated, please rename it to ref_id. Ref id.
 '''
 
 EXAMPLES = '''
@@ -223,9 +223,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
