@@ -12,7 +12,7 @@ ANSIBLE_METADATA = {'status': ['preview'],
 DOCUMENTATION = '''
 ---
 module: fmgr_vpnmgr_node_summaryaddr
-short_description: no description
+short_description: Vpnmgr node summary addr
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
@@ -95,13 +95,13 @@ options:
         suboptions:
             addr:
                 type: str
-                description: No description.
+                description: Addr.
             priority:
                 type: int
-                description: No description.
+                description: Priority.
             seq:
                 type: int
-                description: No description.
+                description: Seq.
                 required: true
 '''
 
@@ -114,7 +114,7 @@ EXAMPLES = '''
     ansible_httpapi_validate_certs: false
     ansible_httpapi_port: 443
   tasks:
-    - name: No description
+    - name: Vpnmgr node summary addr
       fortinet.fortimanager.fmgr_vpnmgr_node_summaryaddr:
         # bypass_validation: false
         workspace_locking_adom: <value in [global, custom adom including root]>
@@ -211,9 +211,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
