@@ -96,7 +96,7 @@ options:
             bookmarks:
                 type: list
                 elements: dict
-                description: No description.
+                description: Bookmarks.
                 suboptions:
                     additional-params:
                         type: str
@@ -125,7 +125,7 @@ options:
                     form-data:
                         type: list
                         elements: dict
-                        description: Deprecated, please rename it to form_data.
+                        description: Deprecated, please rename it to form_data. Form data.
                         suboptions:
                             name:
                                 type: str
@@ -144,7 +144,7 @@ options:
                         description: Deprecated, please rename it to load_balancing_info. The load balancing information or cookie which should be prov...
                     logon-password:
                         type: raw
-                        description: (list) Deprecated, please rename it to logon_password.
+                        description: (list) Deprecated, please rename it to logon_password. Logon password.
                     logon-user:
                         type: str
                         description: Deprecated, please rename it to logon_user. Logon user.
@@ -215,7 +215,7 @@ options:
                             - 'enable'
                     sso-password:
                         type: raw
-                        description: (list) Deprecated, please rename it to sso_password.
+                        description: (list) Deprecated, please rename it to sso_password. SSO password.
                     sso-username:
                         type: str
                         description: Deprecated, please rename it to sso_username. SSO user name.
@@ -562,9 +562,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
