@@ -87,7 +87,7 @@ options:
             duplication:
                 type: list
                 elements: dict
-                description: No description.
+                description: Duplication.
                 suboptions:
                     dstaddr:
                         type: raw
@@ -147,11 +147,11 @@ options:
             health-check:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to health_check.
+                description: Deprecated, please rename it to health_check. Health check.
                 suboptions:
                     _dynamic-server:
                         type: str
-                        description: Deprecated, please rename it to _dynamic_server.
+                        description: Deprecated, please rename it to _dynamic_server. Dynamic server.
                     addr-mode:
                         type: str
                         description: Deprecated, please rename it to addr_mode. Address mode
@@ -205,7 +205,7 @@ options:
                         description: Deprecated, please rename it to packet_size. Packet size of a twamp test session,
                     password:
                         type: raw
-                        description: (list) No description.
+                        description: (list) Twamp controller password in authentication mode
                     port:
                         type: int
                         description: Port number used to communicate with the server over the selected protocol
@@ -252,11 +252,11 @@ options:
                             - 'authentication'
                     server:
                         type: raw
-                        description: (list) No description.
+                        description: (list) IP address or FQDN name of the server.
                     sla:
                         type: list
                         elements: dict
-                        description: No description.
+                        description: Sla.
                         suboptions:
                             id:
                                 type: int
@@ -270,7 +270,7 @@ options:
                             link-cost-factor:
                                 type: list
                                 elements: str
-                                description: Deprecated, please rename it to link_cost_factor.
+                                description: Deprecated, please rename it to link_cost_factor. Criteria on which to base link selection.
                                 choices:
                                     - 'latency'
                                     - 'jitter'
@@ -382,11 +382,11 @@ options:
             members:
                 type: list
                 elements: dict
-                description: No description.
+                description: Members.
                 suboptions:
                     _dynamic-member:
                         type: str
-                        description: Deprecated, please rename it to _dynamic_member.
+                        description: Deprecated, please rename it to _dynamic_member. Dynamic member.
                     comment:
                         type: str
                         description: Comments.
@@ -447,7 +447,7 @@ options:
             neighbor:
                 type: list
                 elements: dict
-                description: No description.
+                description: Neighbor.
                 suboptions:
                     health-check:
                         type: str
@@ -495,7 +495,7 @@ options:
             service:
                 type: list
                 elements: dict
-                description: No description.
+                description: Service.
                 suboptions:
                     addr-mode:
                         type: str
@@ -590,7 +590,7 @@ options:
                             - 'enable'
                     internet-service-app-ctrl:
                         type: raw
-                        description: (list) Deprecated, please rename it to internet_service_app_ctrl.
+                        description: (list) Deprecated, please rename it to internet_service_app_ctrl. Application control based Internet Service ID list.
                     internet-service-app-ctrl-group:
                         type: raw
                         description: (list or str) Deprecated, please rename it to internet_service_app_ctrl_group. Application control based Internet ...
@@ -666,7 +666,7 @@ options:
                     sla:
                         type: list
                         elements: dict
-                        description: No description.
+                        description: Sla.
                         suboptions:
                             health-check:
                                 type: str
@@ -732,10 +732,10 @@ options:
                             - 'enable'
                     input-zone:
                         type: raw
-                        description: (list) Deprecated, please rename it to input_zone.
+                        description: (list) Deprecated, please rename it to input_zone. Source input-zone name.
                     internet-service-app-ctrl-category:
                         type: raw
-                        description: (list) Deprecated, please rename it to internet_service_app_ctrl_category.
+                        description: (list) Deprecated, please rename it to internet_service_app_ctrl_category. IDs of one or more application control ...
                     passive-measurement:
                         type: str
                         description: Deprecated, please rename it to passive_measurement. Enable/disable passive measurement based on the service criteria.
@@ -744,7 +744,7 @@ options:
                             - 'enable'
                     priority-zone:
                         type: raw
-                        description: (list or str) Deprecated, please rename it to priority_zone.
+                        description: (list or str) Deprecated, please rename it to priority_zone. Priority zone name list.
                     agent-exclusive:
                         type: str
                         description: Deprecated, please rename it to agent_exclusive. Set/unset the service as agent use exclusively.
@@ -803,7 +803,7 @@ options:
             zone:
                 type: list
                 elements: dict
-                description: No description.
+                description: Zone.
                 suboptions:
                     name:
                         type: str
@@ -835,7 +835,7 @@ options:
                     - 'enable'
             fail-alert-interfaces:
                 type: raw
-                description: (list) Deprecated, please rename it to fail_alert_interfaces.
+                description: (list) Deprecated, please rename it to fail_alert_interfaces. Physical interfaces that will be alerted.
             app-perf-log-period:
                 type: int
                 description: Deprecated, please rename it to app_perf_log_period. Time interval in seconds that applicationperformance logs are generated
@@ -1388,9 +1388,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_partial_curd(argument_specs=module_arg_spec)
