@@ -95,7 +95,7 @@ options:
         suboptions:
             _dynamic-server:
                 type: str
-                description: Deprecated, please rename it to _dynamic_server.
+                description: Deprecated, please rename it to _dynamic_server. Dynamic server.
             addr-mode:
                 type: str
                 description: Deprecated, please rename it to addr_mode. Address mode
@@ -129,7 +129,7 @@ options:
                 description: Deprecated, please rename it to packet_size. Packet size of a twamp test session,
             password:
                 type: raw
-                description: (list) No description.
+                description: (list) Twamp controller password in authentication mode
             port:
                 type: int
                 description: Port number used to communicate with the server over the selected protocol.
@@ -155,11 +155,11 @@ options:
                     - 'authentication'
             server:
                 type: raw
-                description: (list) No description.
+                description: (list) IP address or FQDN name of the server.
             sla:
                 type: list
                 elements: dict
-                description: No description.
+                description: Sla.
                 suboptions:
                     id:
                         type: int
@@ -173,7 +173,7 @@ options:
                     link-cost-factor:
                         type: list
                         elements: str
-                        description: Deprecated, please rename it to link_cost_factor.
+                        description: Deprecated, please rename it to link_cost_factor. Criteria on which to base link selection.
                         choices:
                             - 'latency'
                             - 'jitter'
@@ -445,9 +445,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
