@@ -90,7 +90,7 @@ options:
             filters:
                 type: list
                 elements: dict
-                description: No description.
+                description: Filters.
                 suboptions:
                     action:
                         type: str
@@ -139,7 +139,7 @@ options:
             options:
                 type: list
                 elements: str
-                description: No description.
+                description: Options for FortiGuard Web Filter.
                 choices:
                     - 'error-allow'
                     - 'http-err-detail'
@@ -156,7 +156,7 @@ options:
             quota:
                 type: list
                 elements: dict
-                description: No description.
+                description: Quota.
                 suboptions:
                     category:
                         type: raw
@@ -385,7 +385,7 @@ def main():
                 'rate-css-urls': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'rate-image-urls': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'rate-javascript-urls': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'category-override': {'v_range': [['6.2.0', '6.4.13']], 'type': 'str'}
+                'category-override': {'v_range': [['6.2.0', '6.4.14']], 'type': 'str'}
             }
 
         }
@@ -401,9 +401,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_partial_curd(argument_specs=module_arg_spec)
