@@ -104,7 +104,18 @@ options:
     default: false
     type: bool
     version_added: '1.18.0'
-
+  throttle:
+    description:
+    - Allows pod creation to fail if array health is not optimal
+    type: bool
+    default: false
+    version_added: '1.29.0'
+  delete_contents:
+    description:
+    - This enables you to eradicate pods with contents.
+    type: bool
+    default: False
+    version_added: '1.29.0'
 extends_documentation_fragment:
 - purestorage.flasharray.purestorage.fa
 """
@@ -169,29 +180,34 @@ RETURN = r"""
 
 HAS_PURESTORAGE = True
 try:
-    from pypureclient import flasharray
+    from pypureclient.flasharray import PodPost, PodPatch, Reference
 except ImportError:
     HAS_PURESTORAGE = False
 
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.purestorage.flasharray.plugins.module_utils.purefa import (
-    get_system,
     get_array,
     purefa_argument_spec,
 )
 from ansible_collections.purestorage.flasharray.plugins.module_utils.common import (
     human_to_bytes,
 )
+from ansible_collections.purestorage.flasharray.plugins.module_utils.version import (
+    LooseVersion,
+)
 
-
-POD_API_VERSION = "1.13"
 POD_QUOTA_VERSION = "2.23"
+THROTTLE_VERSION = "2.31"
 
 
 def get_pod(module, array):
     """Return Pod or None"""
     try:
-        return array.get_pod(module.params["name"])
+        return list(
+            array.get_pods(
+                names=[module.params["name"]], filter="destroyed='False'"
+            ).items
+        )[0]
     except Exception:
         return None
 
@@ -199,15 +215,20 @@ def get_pod(module, array):
 def get_undo_pod(module, array):
     """Return Undo Pod or None"""
     try:
-        return array.get_pod(module.params["name"] + ".undo-demote", pending_only=True)
+        return list(
+            array.get_pods(names=[module.params["name"] + ".undo-demote.*"]).items
+        )
     except Exception:
         return None
 
 
 def get_target(module, array):
-    """Return Pod or None"""
     try:
-        return array.get_pod(module.params["target"])
+        return list(
+            array.get_pods(
+                names=[module.params["target"]], filter="destroyed='False'"
+            ).items
+        )[0]
     except Exception:
         return None
 
@@ -216,7 +237,11 @@ def get_destroyed_pod(module, array):
     """Return Destroyed Volume or None"""
     try:
         return bool(
-            array.get_pod(module.params["name"], pending=True)["time_remaining"] != ""
+            list(
+                array.get_pods(
+                    names=[module.params["name"]], filter="destroyed='True'"
+                ).items
+            )[0]
         )
     except Exception:
         return False
@@ -226,7 +251,11 @@ def get_destroyed_target(module, array):
     """Return Destroyed Volume or None"""
     try:
         return bool(
-            array.get_pod(module.params["target"], pending=True)["time_remaining"] != ""
+            list(
+                array.get_pods(
+                    names=[module.params["target"]], filter="destroyed='False'"
+                ).items
+            )[0]
         )
     except Exception:
         return False
@@ -235,11 +264,11 @@ def get_destroyed_target(module, array):
 def check_arrays(module, array):
     """Check if array name provided are sync-replicated"""
     good_arrays = []
-    good_arrays.append(array.get()["array_name"])
-    connected_arrays = array.list_array_connections()
+    good_arrays.append(list(array.get_arrays().items)[0].name)
+    connected_arrays = list(array.get_array_connections().items)
     for arr in range(0, len(connected_arrays)):
-        if connected_arrays[arr]["type"] == "sync-replication":
-            good_arrays.append(connected_arrays[arr]["array_name"])
+        if connected_arrays[arr].type == "sync-replication":
+            good_arrays.append(connected_arrays[arr].name)
     if module.params["failover"] is not None:
         if module.params["failover"] == ["auto"]:
             failover_array = []
@@ -265,48 +294,72 @@ def check_arrays(module, array):
 
 def create_pod(module, array):
     """Create Pod"""
+    api_version = array.get_rest_version()
     changed = True
     if module.params["target"]:
         module.fail_json(msg="Cannot clone non-existant pod.")
     if not module.check_mode:
-        try:
-            if module.params["failover"]:
-                array.create_pod(
-                    module.params["name"], failover_list=module.params["failover"]
+        if module.params["failover"]:
+            failovers = []
+            for fo_array in range(0, len(module.params["failover"])):
+                failovers.append(Reference(name=module.params["failover"][fo_array]))
+            if LooseVersion(THROTTLE_VERSION) > LooseVersion(api_version):
+                res = array.post_pods(
+                    names=[module.params["name"]],
+                    pod=PodPost(failover_preferences=failovers),
                 )
             else:
-                array.create_pod(module.params["name"])
-        except Exception:
+                res = array.post_pods(
+                    names=[module.params["name"]],
+                    pod=PodPost(failover_preferences=failovers),
+                    allow_throttle=module.params["throttle"],
+                )
+        else:
+            if LooseVersion(THROTTLE_VERSION) > LooseVersion(api_version):
+                res = array.post_pods(names=[module.params["name"]])
+            else:
+                res = array.post_pods(
+                    names=[module.params["name"]],
+                    allow_throttle=module.params["throttle"],
+                )
+        if res.status_code != 200:
             module.fail_json(
-                msg="Pod {0} creation failed.".format(module.params["name"])
+                msg="Pod {0} creation failed. Error: {1}".format(
+                    module.params["name"], res.errors[0].message
+                )
             )
         if module.params["mediator"] != "purestorage":
-            try:
-                array.set_pod(module.params["name"], mediator=module.params["mediator"])
-            except Exception:
+            res = array.patch_pods(
+                names=[module.params["name"]],
+                pod=PodPatch(mediator=module.params["mediator"]),
+            )
+            if res.status_code != 200:
                 module.warn(
-                    "Failed to communicate with mediator {0}, using default value".format(
+                    "Failed to communicate with mediator {0}, using default value.".format(
                         module.params["mediator"]
                     )
                 )
         if module.params["stretch"]:
-            current_array = array.get()["array_name"]
+            current_array = list(array.get_arrays().items)[0].name
             if module.params["stretch"] != current_array:
-                try:
-                    array.add_pod(module.params["name"], module.params["rrays"])
-                except Exception:
+                res = array.post_pods_arrays(
+                    group_names=[module.params["name"]],
+                    member_names=[module.params["stretch"]],
+                )
+                if res.status_code != 200:
                     module.fail_json(
-                        msg="Failed to stretch pod {0} to array {1}.".format(
-                            module.params["name"], module.params["stretch"]
+                        msg="Failed to stretch pod {0} to array {1}. Error: {2}".format(
+                            module.params["name"],
+                            module.params["stretch"],
+                            res.errors[0].message,
                         )
                     )
-        if module.params["quota"]:
-            arrayv6 = get_array(module)
-            res = arrayv6.patch_pods(
+        if module.params["quota"] and LooseVersion(POD_QUOTA_VERSION) <= LooseVersion(
+            api_version
+        ):
+            res = array.patch_pods(
                 names=[module.params["name"]],
-                pod=flasharray.PodPatch(
-                    quota_limit=human_to_bytes(module.params["quota"])
-                ),
+                pod=PodPatch(quota_limit=human_to_bytes(module.params["quota"])),
             )
             if res.status_code != 200:
                 module.fail_json(
@@ -319,19 +372,31 @@ def create_pod(module, array):
 
 def clone_pod(module, array):
     """Create Pod Clone"""
+    api_version = array.get_rest_version()
     changed = False
     if get_target(module, array) is None:
         if not get_destroyed_target(module, array):
             changed = True
             if not module.check_mode:
-                try:
-                    array.clone_pod(module.params["name"], module.params["target"])
-                except Exception:
-                    module.fail_json(
-                        msg="Clone pod {0} to pod {1} failed.".format(
-                            module.params["name"], module.params["target"]
-                        )
+                if LooseVersion(THROTTLE_VERSION) > LooseVersion(api_version):
+                    res = array.post_pods(
+                        pod=PodPost(source=Reference(name=module.params["name"])),
+                        names=[module.params["target"]],
                     )
+                else:
+                    res = array.post_pods(
+                        pod=PodPost(source=Reference(name=module.params["name"])),
+                        names=[module.params["target"]],
+                        allow_throttle=module.params["throttle"],
+                    )
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Clone pod {0} to pod {1} failed. Error: {2}".format(
+                        module.params["name"],
+                        module.params["target"],
+                        res.errors[0].message,
+                    )
+                )
         else:
             module.fail_json(
                 msg="Target pod {0} already exists but deleted.".format(
@@ -344,125 +409,152 @@ def clone_pod(module, array):
 
 def update_pod(module, array):
     """Update Pod configuration"""
+    api_version = array.get_rest_version()
     changed = False
-    current_config = array.get_pod(module.params["name"], failover_preference=True)
+    current_config = list(array.get_pods(names=[module.params["name"]]).items)[0]
     if module.params["failover"]:
-        current_failover = current_config["failover_preference"]
+        current_failover = current_config.failover_preference
         if current_failover == [] or sorted(module.params["failover"]) != sorted(
             current_failover
         ):
             changed = True
             if not module.check_mode:
-                try:
-                    if module.params["failover"] == ["auto"]:
-                        if current_failover != []:
-                            array.set_pod(module.params["name"], failover_preference=[])
-                    else:
-                        array.set_pod(
-                            module.params["name"],
-                            failover_preference=module.params["failover"],
+                if module.params["failover"] == ["auto"]:
+                    if current_failover != []:
+                        res = array.patch_pods(
+                            names=[module.params["name"]],
+                            pod=PodPatch(failover_preferences=[]),
                         )
-                except Exception:
+                        if res.status_code != 200:
+                            module.fail_json(
+                                msg="Failed to clear failover preference for pod {0}. Error: {1}".format(
+                                    module.params["name"],
+                                    res.errors[0].message,
+                                )
+                            )
+                else:
+                    failovers = []
+                    for fo_array in range(0, len(module.params["failover"])):
+                        failovers.append(Reference(module.params["failover"][fo_array]))
+                    res = array.patch_pods(
+                        names=[module.params["name"]],
+                        pod=PodPatch(failover_preferences=failovers),
+                    )
+                if res.status_code != 200:
                     module.fail_json(
-                        msg="Failed to set failover preference for pod {0}.".format(
-                            module.params["name"]
+                        msg="Failed to set failover preference for pod {0}. Error: {1}".format(
+                            module.params["name"],
+                            res.errors[0].message,
                         )
                     )
-    current_config = array.get_pod(module.params["name"], mediator=True)
-    if current_config["mediator"] != module.params["mediator"]:
+    if current_config.mediator != module.params["mediator"]:
         changed = True
         if not module.check_mode:
-            try:
-                array.set_pod(module.params["name"], mediator=module.params["mediator"])
-            except Exception:
+            res = array.patch_pods(
+                names=[module.params["name"]],
+                pod=PodPatch(mediator=module.params["mediator"]),
+            )
+            if res.status_code != 200:
                 module.warn(
-                    "Failed to communicate with mediator {0}. Setting unchanged.".format(
-                        module.params["mediator"]
+                    "Failed to communicate with mediator {0}. Setting unchanged.i Error: {1}".format(
+                        module.params["mediator"],
+                        res.errors[0].message,
                     )
                 )
     if module.params["promote"] is not None:
-        if len(current_config["arrays"]) > 1:
+        if current_config.array_count > 1:
             module.fail_json(
                 msg="Promotion/Demotion not permitted. Pod {0} is stretched".format(
                     module.params["name"]
                 )
             )
         else:
-            if (
-                current_config["promotion_status"] == "demoted"
-                and module.params["promote"]
-            ):
-                try:
+            changed = True
+            if not module.check_mode:
+                if (
+                    current_config.promotion_status == "demoted"
+                    and module.params["promote"]
+                ):
                     if module.params["undo"] is None:
                         module.params["undo"] = True
-                    if current_config["promotion_status"] == "quiescing":
+                    if current_config.promotion_status == "quiescing":
                         module.fail_json(
                             msg="Cannot promote pod {0} as it is still quiesing".format(
                                 module.params["name"]
                             )
                         )
                     elif module.params["undo"]:
-                        changed = True
-                        if not module.check_mode:
-                            if get_undo_pod(module, array):
-                                array.promote_pod(
-                                    module.params["name"],
-                                    promote_from=module.params["name"] + ".undo-demote",
-                                )
-                            else:
-                                array.promote_pod(module.params["name"])
-                                module.warn(
-                                    "undo-demote pod remaining for {0}. Consider eradicating this.".format(
-                                        module.params["name"]
-                                    )
+                        undo_pod = get_undo_pod(module, array)
+                        if len(undo_pod) == 1:
+                            res = array.patch_pods(
+                                names=[module.params["name"]],
+                                promote_from=undo_pod[0].name,
+                            )
+                        else:
+                            res = array.patch_pods(
+                                names=[module.params["name"]],
+                                promote_from=undo_pod[-1].name,
+                            )
+                            module.warn(
+                                "undo-demote pod(s) remaining for {0}. Consider eradicating.".format(
+                                    module.params["name"]
                                 )
+                            )
                     else:
-                        changed = True
-                        if not module.check_mode:
-                            array.promote_pod(module.params["name"])
-                except Exception:
-                    module.fail_json(
-                        msg="Failed to promote pod {0}.".format(module.params["name"])
-                    )
-            elif (
-                current_config["promotion_status"] != "demoted"
-                and not module.params["promote"]
-            ):
-                try:
+                        res = array.patch_pods(
+                            names=[module.params["name"]],
+                            pod=PodPatch(requested_promotion_state="promoted"),
+                        )
+                    if res.status_code != 200:
+                        module.fail_json(
+                            msg="Failed to promote pod {0}. Error: {1}".format(
+                                module.params["name"], res.erroros[0].message
+                            )
+                        )
+                elif (
+                    current_config.promotion_status != "demoted"
+                    and not module.params["promote"]
+                ):
                     if get_undo_pod(module, array):
                         module.fail_json(
-                            msg="Cannot demote pod {0} due to associated undo-demote pod not being eradicated".format(
-                                module.params["name"]
-                            )
+                            msg="Cannot demote pod {0} due to associated undo-demote "
+                            "pod not being eradicated".format(module.params["name"])
                         )
                     if module.params["quiesce"] is None:
                         module.params["quiesce"] = True
                     if current_config["link_target_count"] == 0:
-                        changed = True
-                        if not module.check_mode:
-                            array.demote_pod(module.params["name"])
+                        res = array.patch_pods(
+                            names=[module.params["name"]],
+                            pod=PodPatch(requested_promotion_state="demoted"),
+                        )
                     elif not module.params["quiesce"]:
-                        changed = True
-                        if not module.check_mode:
-                            array.demote_pod(module.params["name"], skip_quiesce=True)
+                        res = array.patch_pods(
+                            names=[module.params["name"]],
+                            pod=PodPatch(requested_promotion_state="demoted"),
+                            skip_quiesce=True,
+                        )
                     else:
-                        changed = True
-                        if not module.check_mode:
-                            array.demote_pod(module.params["name"], quiesce=True)
-                except Exception:
+                        res = array.patch_pods(
+                            names=[module.params["name"]],
+                            pod=PodPatch(requested_promotion_state="demoted"),
+                            quiesce=True,
+                        )
+                if res.status_code != 200:
                     module.fail_json(
-                        msg="Failed to demote pod {0}.".format(module.params["name"])
+                        msg="Failed to demote pod {0}. Error: {1}".format(
+                            module.params["name"], res.errors[0].message
+                        )
                     )
-    if module.params["quota"]:
-        arrayv6 = get_array(module)
-        current_pod = list(arrayv6.get_pods(names=[module.params["name"]]).items)[0]
+    if module.params["quota"] and LooseVersion(POD_QUOTA_VERSION) <= LooseVersion(
+        api_version
+    ):
         quota = human_to_bytes(module.params["quota"])
-        if current_pod.quota_limit != quota:
+        if current_config.quota_limit != quota:
             changed = True
             if not module.check_mode:
-                res = arrayv6.patch_pods(
+                res = array.patch_pods(
                     names=[module.params["name"]],
-                    pod=flasharray.PodPatch(
+                    pod=PodPatch(
                         quota_limit=quota, ignore_usage=module.params["ignore_usage"]
                     ),
                 )
@@ -479,23 +571,27 @@ def update_pod(module, array):
 def stretch_pod(module, array):
     """Stretch/unstretch Pod configuration"""
     changed = False
-    current_config = array.get_pod(module.params["name"], failover_preference=True)
+    current_config = list(array.get_pods(names=[module.params["name"]]).items)[0]
     if module.params["stretch"]:
         current_arrays = []
-        for arr in range(0, len(current_config["arrays"])):
-            current_arrays.append(current_config["arrays"][arr]["name"])
+        for arr in range(0, len(current_config.arrays)):
+            current_arrays.append(current_config.arrays[arr]["name"])
         if (
             module.params["stretch"] not in current_arrays
             and module.params["state"] == "present"
         ):
             changed = True
             if not module.check_mode:
-                try:
-                    array.add_pod(module.params["name"], module.params["stretch"])
-                except Exception:
+                res = array.post_pods_arrays(
+                    group_names=[module.params["name"]],
+                    member_names=[module.params["stretch"]],
+                )
+                if res.status_code != 200:
                     module.fail_json(
-                        msg="Failed to stretch pod {0} to array {1}.".format(
-                            module.params["name"], module.params["stretch"]
+                        msg="Failed to stretch pod {0} to array {1}. Error: {2}".format(
+                            module.params["name"],
+                            module.params["stretch"],
+                            res.errors[0].message,
                         )
                     )
 
@@ -506,7 +602,10 @@ def stretch_pod(module, array):
             changed = True
             if not module.check_mode:
                 try:
-                    array.remove_pod(module.params["name"], module.params["stretch"])
+                    array.delete_pods_arrays(
+                        group_names=[module.params["name"]],
+                        member_names=[module.params["stretch"]],
+                    )
                 except Exception:
                     module.fail_json(
                         msg="Failed to unstretch pod {0} from array {1}.".format(
@@ -521,30 +620,43 @@ def delete_pod(module, array):
     """Delete Pod"""
     changed = True
     if not module.check_mode:
-        try:
-            array.destroy_pod(module.params["name"])
-            if module.params["eradicate"]:
-                try:
-                    array.eradicate_pod(module.params["name"])
-                except Exception:
-                    module.fail_json(
-                        msg="Eradicate pod {0} failed.".format(module.params["name"])
+        res = array.patch_pods(
+            names=[module.params["name"]], pod=PodPatch(destroyed=True)
+        )
+        if res.status_code != 200:
+            module.fail_json(
+                msg="Delete pod {0} failed. Error: {1}".format(
+                    module.params["name"], res.errors[0].message
+                )
+            )
+        if module.params["eradicate"]:
+            res = array.delete_pods(
+                names=[module.params["name"]],
+                eradicate_contents=module.params["delete_contents"],
+            )
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Eradicate pod {0} failed. Error: {1}".format(
+                        module.params["name"], res.errors[0].message
                     )
-        except Exception:
-            module.fail_json(msg="Delete pod {0} failed.".format(module.params["name"]))
+                )
     module.exit_json(changed=changed)
 
 
 def eradicate_pod(module, array):
     """Eradicate Deleted Pod"""
-    changed = True
-    if not module.check_mode:
-        if module.params["eradicate"]:
-            try:
-                array.eradicate_pod(module.params["name"])
-            except Exception:
+    if module.params["eradicate"]:
+        changed = True
+        if not module.check_mode:
+            res = array.delete_pods(
+                names=[module.params["name"]],
+                eradicate_contents=module.params["delete_contents"],
+            )
+            if res.status_code != 200:
                 module.fail_json(
-                    msg="Eradication of pod {0} failed".format(module.params["name"])
+                    msg="Eradication of pod {0} failed. Error: {1}".format(
+                        module.params["name"], res.errors[0].message
+                    )
                 )
     module.exit_json(changed=changed)
 
@@ -553,11 +665,14 @@ def recover_pod(module, array):
     """Recover Deleted Pod"""
     changed = True
     if not module.check_mode:
-        try:
-            array.recover_pod(module.params["name"])
-        except Exception:
+        res = array.patch_pods(
+            names=[module.params["name"]], pod=PodPatch(destroyed=False)
+        )
+        if res.status_code != 200:
             module.fail_json(
-                msg="Recovery of pod {0} failed".format(module.params["name"])
+                msg="Recovery of pod {0} failed. Error: {1}".format(
+                    module.params["name"], res.errors[0].message
+                )
             )
     module.exit_json(changed=changed)
 
@@ -578,6 +693,8 @@ def main():
             state=dict(type="str", default="present", choices=["absent", "present"]),
             quota=dict(type="str"),
             ignore_usage=dict(type="bool", default=False),
+            throttle=dict(type="bool", default=False),
+            delete_contents=dict(type="bool", default=False),
         )
     )
 
@@ -596,20 +713,9 @@ def main():
     )
 
     state = module.params["state"]
-    array = get_system(module)
+    array = get_array(module)
 
-    api_version = array._list_available_rest_versions()
-    if POD_API_VERSION not in api_version:
-        module.fail_json(
-            msg="FlashArray REST version not supported. "
-            "Minimum version required: {0}".format(POD_API_VERSION)
-        )
-
-    if module.params["quota"] and POD_QUOTA_VERSION in api_version:
-        if not HAS_PURESTORAGE:
-            module.fail_json(
-                msg="py-pure-client sdk is required to support 'count' parameter"
-            )
+    api_version = array.get_rest_version()
     pod = get_pod(module, array)
     destroyed = ""
     if not pod:
