@@ -49,12 +49,12 @@ options:
     description:
     - Define whether to eradicate the volume on delete or leave in trash.
     type: bool
-    default: 'no'
+    default: false
   overwrite:
     description:
     - Define whether to overwrite a target volume if it already exisits.
     type: bool
-    default: 'no'
+    default: false
   size:
     description:
     - Volume size in M, G, T or P units.
@@ -86,6 +86,7 @@ options:
       See associated descriptions
     - Only supported from Purity//FA v6.0.0 and higher
     type: str
+    default: ""
   bw_qos:
     description:
     - Bandwidth limit for volume in M or G units.
@@ -184,7 +185,7 @@ EXAMPLES = r"""
 - name: Create new volume named foo in pod bar in protection group pg1
   purestorage.flasharray.purefa_volume:
     name: bar::foo
-    prgoup: pg1
+    pgroup: pg1
     size: 1T
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
@@ -213,7 +214,7 @@ EXAMPLES = r"""
 - name: Delete and eradicate volume named foo
   purestorage.flasharray.purefa_volume:
     name: foo
-    eradicate: yes
+    eradicate: true
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
     state: absent
@@ -230,7 +231,7 @@ EXAMPLES = r"""
   purestorage.flasharray.purefa_volume:
     name: foo
     target: bar
-    overwrite: yes
+    overwrite: true
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
     state: present
@@ -326,7 +327,13 @@ from ansible_collections.purestorage.flasharray.plugins.module_utils.purefa impo
     get_system,
     purefa_argument_spec,
 )
-
+from ansible_collections.purestorage.flasharray.plugins.module_utils.common import (
+    human_to_bytes,
+    human_to_real,
+)
+from ansible_collections.purestorage.flasharray.plugins.module_utils.version import (
+    LooseVersion,
+)
 
 QOS_API_VERSION = "1.14"
 VGROUPS_API_VERSION = "1.13"
@@ -342,6 +349,38 @@ DEFAULT_API_VERSION = "2.16"
 VOLUME_PROMOTION_API_VERSION = "2.2"
 
 
+def _volfact(module, array):
+    api_version = array.get_rest_version()
+    volume_name = module.params["name"]
+    volume_data = list(array.get_volumes(names=[volume_name]).items)[0]
+    volfact = {
+        volume_name: {
+            "size": volume_data.provisioned,
+            "serial": volume_data.serial,
+            "created": time.strftime(
+                "%Y-%m-%d %H:%M:%S", time.localtime(volume_data.created / 1000)
+            ),
+            "page83_naa": PURE_OUI + volume_data.serial.lower(),
+            "nvme_nguid": _create_nguid(volume_data.serial.lower()),
+            "iops_limit": getattr(volume_data.qos, "iops_limit", 0),
+            "bandwidth_limit": getattr(volume_data.qos, "bandwidth_limit", 0),
+            "requested_promotion_state": volume_data.requested_promotion_state,
+            "promotion_status": volume_data.promotion_status,
+            "priority": getattr(volume_data, "priority", 0),
+            "priority_operator": "",
+            "priority_value": "",
+        }
+    }
+    if LooseVersion(PRIORITY_API_VERSION) <= LooseVersion(api_version):
+        volfact[volume_name][
+            "priority_operator"
+        ] = volume_data.priority_adjustment.priority_adjustment_operator
+        volfact[volume_name][
+            "priority_value"
+        ] = volume_data.priority_adjustment.priority_adjustment_value
+    return volfact
+
+
 def _create_nguid(serial):
     nguid = "eui.00" + serial[0:14] + "24a937" + serial[-10:]
     return nguid
@@ -402,54 +441,6 @@ def get_pgroup(module, array):
     return pgroup
 
 
-def human_to_bytes(size):
-    """Given a human-readable byte string (e.g. 2G, 30M),
-    return the number of bytes.  Will return 0 if the argument has
-    unexpected form.
-    """
-    bytes = size[:-1]
-    unit = size[-1].upper()
-    if bytes.isdigit():
-        bytes = int(bytes)
-        if unit == "P":
-            bytes *= 1125899906842624
-        elif unit == "T":
-            bytes *= 1099511627776
-        elif unit == "G":
-            bytes *= 1073741824
-        elif unit == "M":
-            bytes *= 1048576
-        elif unit == "K":
-            bytes *= 1024
-        else:
-            bytes = 0
-    else:
-        bytes = 0
-    return bytes
-
-
-def human_to_real(iops):
-    """Given a human-readable IOPs string (e.g. 2K, 30M),
-    return the real number.  Will return 0 if the argument has
-    unexpected form.
-    """
-    digit = iops[:-1]
-    unit = iops[-1].upper()
-    if unit.isdigit():
-        digit = iops
-    elif digit.isdigit():
-        digit = int(digit)
-        if unit == "M":
-            digit *= 1000000
-        elif unit == "K":
-            digit *= 1000
-        else:
-            digit = 0
-    else:
-        digit = 0
-    return digit
-
-
 def get_multi_volumes(module, destroyed=False):
     """Return True is all volumes exist or None"""
     names = []
@@ -554,7 +545,6 @@ def check_pod(module, array):
 
 def create_volume(module, array):
     """Create Volume"""
-    volfact = []
     changed = False
     api_version = array._list_available_rest_versions()
     if "/" in module.params["name"] and not check_vgroup(module, array):
@@ -592,17 +582,11 @@ def create_volume(module, array):
                         changed = True
                         if not module.check_mode:
                             try:
-                                volfact = array.create_volume(
+                                array.create_volume(
                                     module.params["name"],
                                     module.params["size"],
                                     bandwidth_limit=module.params["bw_qos"],
                                 )
-                                volfact["page83_naa"] = (
-                                    PURE_OUI + volfact["serial"].lower()
-                                )
-                                volfact["nvme_nguid"] = _create_nguid(
-                                    volfact["serial"].lower()
-                                )
                             except Exception:
                                 module.fail_json(
                                     msg="Volume {0} creation failed.".format(
@@ -624,17 +608,11 @@ def create_volume(module, array):
                         changed = True
                         if not module.check_mode:
                             try:
-                                volfact = array.create_volume(
+                                array.create_volume(
                                     module.params["name"],
                                     module.params["size"],
                                     iops_limit=module.params["iops_qos"],
                                 )
-                                volfact["page83_naa"] = (
-                                    PURE_OUI + volfact["serial"].lower()
-                                )
-                                volfact["nvme_nguid"] = _create_nguid(
-                                    volfact["serial"].lower()
-                                )
                             except Exception:
                                 module.fail_json(
                                     msg="Volume {0} creation failed.".format(
@@ -655,18 +633,12 @@ def create_volume(module, array):
                         changed = True
                         if not module.check_mode:
                             try:
-                                volfact = array.create_volume(
+                                array.create_volume(
                                     module.params["name"],
                                     module.params["size"],
                                     iops_limit=module.params["iops_qos"],
                                     bandwidth_limit=module.params["bw_qos"],
                                 )
-                                volfact["page83_naa"] = (
-                                    PURE_OUI + volfact["serial"].lower()
-                                )
-                                volfact["nvme_nguid"] = _create_nguid(
-                                    volfact["serial"].lower()
-                                )
                             except Exception:
                                 module.fail_json(
                                     msg="Volume {0} creation failed.".format(
@@ -685,17 +657,11 @@ def create_volume(module, array):
                         changed = True
                         if not module.check_mode:
                             try:
-                                volfact = array.create_volume(
+                                array.create_volume(
                                     module.params["name"],
                                     module.params["size"],
                                     bandwidth_limit=module.params["bw_qos"],
                                 )
-                                volfact["page83_naa"] = (
-                                    PURE_OUI + volfact["serial"].lower()
-                                )
-                                volfact["nvme_nguid"] = _create_nguid(
-                                    volfact["serial"].lower()
-                                )
                             except Exception:
                                 module.fail_json(
                                     msg="Volume {0} creation failed.".format(
@@ -712,13 +678,9 @@ def create_volume(module, array):
                     changed = True
                     if not module.check_mode:
                         try:
-                            volfact = array.create_volume(
+                            array.create_volume(
                                 module.params["name"], module.params["size"]
                             )
-                            volfact["page83_naa"] = PURE_OUI + volfact["serial"].lower()
-                            volfact["nvme_nguid"] = _create_nguid(
-                                volfact["serial"].lower()
-                            )
                         except Exception:
                             module.fail_json(
                                 msg="Volume {0} creation failed.".format(
@@ -729,17 +691,13 @@ def create_volume(module, array):
         changed = True
         if not module.check_mode:
             try:
-                volfact = array.create_volume(
-                    module.params["name"], module.params["size"]
-                )
-                volfact["page83_naa"] = PURE_OUI + volfact["serial"].lower()
-                volfact["nvme_nguid"] = _create_nguid(volfact["serial"].lower())
+                array.create_volume(module.params["name"], module.params["size"])
             except Exception:
                 module.fail_json(
                     msg="Volume {0} creation failed.".format(module.params["name"])
                 )
+    arrayv6 = get_array(module)
     if VOLUME_PROMOTION_API_VERSION in api_version and module.params["promotion_state"]:
-        arrayv6 = get_array(module)
         volume = flasharray.VolumePatch(
             requested_promotion_state=module.params["promotion_state"]
         )
@@ -747,13 +705,17 @@ def create_volume(module, array):
         if not module.check_mode:
             res = arrayv6.patch_volumes(names=[module.params["name"]], volume=volume)
             if res.status_code != 200:
+                arrayv6.patch_volumes(
+                    names=[module.params["name"]],
+                    volume=flasharray.VolumePatch(destroyed=True),
+                )
+                arrayv6.delete_volumes(names=[module.params["name"]])
                 module.fail_json(
                     msg="Failed to set Promotion State for volume {0}.".format(
                         module.params["name"]
                     )
                 )
     if PRIORITY_API_VERSION in api_version and module.params["priority_operator"]:
-        arrayv6 = get_array(module)
         volume = flasharray.VolumePatch(
             priority_adjustment=flasharray.PriorityAdjustment(
                 priority_adjustment_operator=module.params["priority_operator"],
@@ -772,9 +734,6 @@ def create_volume(module, array):
                     module.params["name"], res.errors[0].message
                 )
             )
-        else:
-            volfact["priority_operator"] = module.params["priority_operator"]
-            volfact["priority_value"] = module.params["priority_value"]
     if module.params["pgroup"] and DEFAULT_API_VERSION not in api_version:
         changed = True
         if not module.check_mode:
@@ -789,7 +748,7 @@ def create_volume(module, array):
                     )
                 )
 
-    module.exit_json(changed=changed, volume=volfact)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def create_multi_volume(module, array, single=False):
@@ -904,6 +863,11 @@ def create_multi_volume(module, array, single=False):
                 )
                 prom_res = array.patch_volumes(names=names, volume=volume)
                 if prom_res.status_code != 200:
+                    array.patch_volumes(
+                        names=names,
+                        volume=flasharray.VolumePatch(destroyed=True),
+                    )
+                    array.delete_volumes(names=names)
                     module.warn(
                         "Failed to set promotion status on volumes. Error: {0}".format(
                             prom_res.errors[0].message
@@ -950,6 +914,13 @@ def create_multi_volume(module, array, single=False):
                     ].qos.bandwidth_limit
                 if iops_qos_size != 0:
                     volfact[vol_name]["iops_limit"] = temp[count].qos.iops_limit
+                if (
+                    VOLUME_PROMOTION_API_VERSION in api_version
+                    and module.params["promotion_state"]
+                ):
+                    volfact[vol_name]["promotion_status"] = prio_temp[
+                        count
+                    ].promotion_status
                 if (
                     PRIORITY_API_VERSION in api_version
                     and module.params["priority_operator"]
@@ -978,7 +949,6 @@ def create_multi_volume(module, array, single=False):
 
 def copy_from_volume(module, array):
     """Create Volume Clone"""
-    volfact = []
     changed = False
     tgt = get_target(module, array)
     api_version = array._list_available_rest_versions()
@@ -1024,23 +994,9 @@ def copy_from_volume(module, array):
                             res.errors[0].message,
                         )
                     )
-                vol_data = list(res.items)
-                volfact = {
-                    "size": vol_data[0].provisioned,
-                    "serial": vol_data[0].serial,
-                    "created": time.strftime(
-                        "%Y-%m-%d %H:%M:%S", time.localtime(vol_data[0].created / 1000)
-                    ),
-                    "page83_naa": PURE_OUI + vol_data[0].serial.lower(),
-                    "nvme_nguid": _create_nguid(vol_data[0].serial.lower()),
-                }
             else:
                 try:
-                    volfact = array.copy_volume(
-                        module.params["name"], module.params["target"]
-                    )
-                    volfact["page83_naa"] = PURE_OUI + volfact["serial"].lower()
-                    volfact["nvme_nguid"] = _create_nguid(volfact["serial"].lower())
+                    array.copy_volume(module.params["name"], module.params["target"])
                     changed = True
                 except Exception:
                     module.fail_json(
@@ -1053,13 +1009,11 @@ def copy_from_volume(module, array):
         if not module.check_mode:
             if DEFAULT_API_VERSION not in api_version:
                 try:
-                    volfact = array.copy_volume(
+                    array.copy_volume(
                         module.params["name"],
                         module.params["target"],
                         overwrite=module.params["overwrite"],
                     )
-                    volfact["page83_naa"] = PURE_OUI + volfact["serial"].lower()
-                    volfact["nvme_nguid"] = _create_nguid(volfact["serial"].lower())
                     changed = True
                 except Exception:
                     module.fail_json(
@@ -1068,10 +1022,8 @@ def copy_from_volume(module, array):
                         )
                     )
             else:
-                res = arrayv6.post_volume(
+                res = arrayv6.post_volumes(
                     overwrite=module.params["overwrite"],
-                    with_default_protection=module.params["with_default_protection"],
-                    add_to_protection_groups=module.params["add_to_pgs"],
                     names=[module.params["target"]],
                     volume=flasharray.VolumePost(
                         source=flasharray.Reference(name=module.params["name"])
@@ -1085,25 +1037,17 @@ def copy_from_volume(module, array):
                             res.errors[0].message,
                         )
                     )
-                vol_data = list(res.items)
-                volfact = {
-                    "size": vol_data[0].provisioned,
-                    "serial": vol_data[0].serial,
-                    "created": time.strftime(
-                        "%Y-%m-%d %H:%M:%S", time.localtime(vol_data[0].created / 1000)
-                    ),
-                    "page83_naa": PURE_OUI + vol_data[0].serial.lower(),
-                    "nvme_nguid": _create_nguid(vol_data[0].serial.lower()),
-                }
 
-    module.exit_json(changed=changed, volume=volfact)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def update_volume(module, array):
     """Update Volume size and/or QoS"""
-    volfact = []
     changed = False
+    arrayv6 = None
     api_version = array._list_available_rest_versions()
+    if MULTI_VOLUME_VERSION in api_version:
+        arrayv6 = get_array(module)
     vol = array.get_volume(module.params["name"])
     vol_qos = array.get_volume(module.params["name"], qos=True)
     if QOS_API_VERSION in api_version:
@@ -1125,7 +1069,7 @@ def update_volume(module, array):
                 changed = True
                 if not module.check_mode:
                     try:
-                        volfact = array.extend_volume(
+                        array.extend_volume(
                             module.params["name"], module.params["size"]
                         )
                     except Exception:
@@ -1135,14 +1079,14 @@ def update_volume(module, array):
                             )
                         )
     if module.params["bw_qos"] and QOS_API_VERSION in api_version:
-        if human_to_bytes(module.params["bw_qos"]) != vol_qos["bandwidth_limit"]:
+        if int(human_to_bytes(module.params["bw_qos"])) != int(
+            vol_qos["bandwidth_limit"]
+        ):
             if module.params["bw_qos"] == "0":
                 changed = True
                 if not module.check_mode:
                     try:
-                        volfact = array.set_volume(
-                            module.params["name"], bandwidth_limit=""
-                        )
+                        array.set_volume(module.params["name"], bandwidth_limit="")
                     except Exception:
                         module.fail_json(
                             msg="Volume {0} Bandwidth QoS removal failed.".format(
@@ -1155,7 +1099,7 @@ def update_volume(module, array):
                 changed = True
                 if not module.check_mode:
                     try:
-                        volfact = array.set_volume(
+                        array.set_volume(
                             module.params["name"],
                             bandwidth_limit=module.params["bw_qos"],
                         )
@@ -1172,12 +1116,12 @@ def update_volume(module, array):
                     )
                 )
     if module.params["iops_qos"] and IOPS_API_VERSION in api_version:
-        if human_to_real(module.params["iops_qos"]) != vol_qos["iops_limit"]:
+        if int(human_to_real(module.params["iops_qos"])) != int(vol_qos["iops_limit"]):
             if module.params["iops_qos"] == "0":
                 changed = True
                 if not module.check_mode:
                     try:
-                        volfact = array.set_volume(module.params["name"], iops_limit="")
+                        array.set_volume(module.params["name"], iops_limit="")
                     except Exception:
                         module.fail_json(
                             msg="Volume {0} IOPs QoS removal failed.".format(
@@ -1188,7 +1132,7 @@ def update_volume(module, array):
                 changed = True
                 if not module.check_mode:
                     try:
-                        volfact = array.set_volume(
+                        array.set_volume(
                             module.params["name"], iops_limit=module.params["iops_qos"]
                         )
                     except Exception:
@@ -1204,7 +1148,6 @@ def update_volume(module, array):
                     )
                 )
     if VOLUME_PROMOTION_API_VERSION in api_version and module.params["promotion_state"]:
-        arrayv6 = get_array(module)
         vol6 = list(arrayv6.get_volumes(names=[module.params["name"]]).items)[0]
         if module.params["promotion_state"] != vol6.promotion_status:
             volume_patch = flasharray.VolumePatch(
@@ -1221,11 +1164,7 @@ def update_volume(module, array):
                             module.params["name"]
                         )
                     )
-                else:
-                    if not volfact:
-                        volfact = array.get_volume(module.params["name"])
     if PRIORITY_API_VERSION in api_version and module.params["priority_operator"]:
-        arrayv6 = get_array(module)
         volv6 = list(arrayv6.get_volumes(names=[module.params["name"]]).items)[0]
         change_prio = False
         if (
@@ -1268,20 +1207,13 @@ def update_volume(module, array):
                         module.params["name"], prio_res.errors[0].message
                     )
                 )
-            else:
-                if not volfact:
-                    volfact = array.get_volume(module.params["name"])
-                volfact["priority_operator"] = module.params["priority_operator"]
-                volfact["priority_value"] = module.params["priority_value"]
-    if not changed:
-        volfact = array.get_volume(module.params["name"])
-    module.exit_json(changed=changed, volume=volfact)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def rename_volume(module, array):
     """Rename volume within a container, ie pod, vgroup or local array"""
-    volfact = []
     changed = False
+    arrayv6 = get_array(module)
     pod_name = ""
     vgroup_name = ""
     target_name = module.params["rename"]
@@ -1323,9 +1255,7 @@ def rename_volume(module, array):
             changed = True
             if not module.check_mode:
                 try:
-                    volfact = array.rename_volume(
-                        module.params["name"], module.params["rename"]
-                    )
+                    array.rename_volume(module.params["name"], module.params["rename"])
                 except Exception:
                     module.fail_json(
                         msg="Rename volume {0} to {1} failed.".format(
@@ -1335,12 +1265,11 @@ def rename_volume(module, array):
     else:
         module.fail_json(msg="Target volume {0} already exists.".format(target_name))
 
-    module.exit_json(changed=changed, volume=volfact)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def move_volume(module, array):
     """Move volume between pods, vgroups or local array"""
-    volfact = []
     changed = vgroup_exists = target_exists = pod_exists = False
     api_version = array._list_available_rest_versions()
     pod_name = ""
@@ -1437,7 +1366,7 @@ def move_volume(module, array):
     changed = True
     if not module.check_mode:
         try:
-            volfact = array.move_volume(module.params["name"], target_location)
+            array.move_volume(module.params["name"], target_location)
         except Exception:
             if target_location == "":
                 target_location = "[local]"
@@ -1446,28 +1375,30 @@ def move_volume(module, array):
                     module.params["name"], target_location
                 )
             )
-    module.exit_json(changed=changed, volume=volfact)
+    arrayv6 = get_array(module)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def delete_volume(module, array):
     """Delete Volume"""
     changed = True
-    volfact = []
     if not module.check_mode:
         try:
             array.destroy_volume(module.params["name"])
             if module.params["eradicate"]:
                 try:
-                    volfact = array.eradicate_volume(module.params["name"])
+                    array.eradicate_volume(module.params["name"])
                 except Exception:
                     module.fail_json(
                         msg="Eradicate volume {0} failed.".format(module.params["name"])
                     )
+                module.exit_json(changed=changed, volume=[])
         except Exception:
             module.fail_json(
                 msg="Delete volume {0} failed.".format(module.params["name"])
             )
-    module.exit_json(changed=changed, volume=volfact)
+    arrayv6 = get_array(module)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def eradicate_volume(module, array):
@@ -1488,7 +1419,6 @@ def eradicate_volume(module, array):
 def recover_volume(module, array):
     """Recover Deleted Volume"""
     changed = True
-    volfact = []
     if not module.check_mode:
         try:
             array.recover_volume(module.params["name"])
@@ -1496,10 +1426,9 @@ def recover_volume(module, array):
             module.fail_json(
                 msg="Recovery of volume {0} failed".format(module.params["name"])
             )
-        volfact = array.get_volume(module.params["name"])
-        volfact["page83_naa"] = PURE_OUI + volfact["serial"].lower()
-        volfact["nvme_nguid"] = _create_nguid(volfact["serial"].lower())
-    module.exit_json(changed=changed, volume=volfact)
+        array.get_volume(module.params["name"])
+    arrayv6 = get_array(module)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def main():
@@ -1519,7 +1448,7 @@ def main():
             count=dict(type="int"),
             start=dict(type="int", default=0),
             digits=dict(type="int", default=1),
-            suffix=dict(type="str"),
+            suffix=dict(type="str", default=""),
             priority_operator=dict(type="str", choices=["+", "-", "="]),
             priority_value=dict(type="int", choices=[-10, 0, 10]),
             size=dict(type="str"),
