@@ -21,11 +21,15 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 DOCUMENTATION = r"""
-name: t_systems_mms.icinga_director.icinga_director_inventory
-plugin_type: inventory
+name: icinga_director_inventory
 short_description: Returns Ansible inventory from Icinga
 description: Returns Ansible inventory from Icinga
-author: Sebastian Gumprich (@rndmh3ro)
+deprecated:
+  why: moved collection to new organisation telekom_mms
+  removed_in: 3.0.0
+  alternative: telekom_mms.icinga_director.icinga_director_inventory
+author:
+- Sebastian Gumprich (@rndmh3ro)
 options:
     plugin:
         description: Name of the plugin
@@ -36,6 +40,7 @@ options:
         required: true
 extends_documentation_fragment:
   - ansible.builtin.url
+  - constructed
 """
 
 EXAMPLES = r"""
@@ -44,16 +49,31 @@ url: 'https://example.com'
 url_username: foo
 url_password: bar
 force_basic_auth: False
+strict: False
+
+# use the object_name you defined as hostname
+compose:
+  hostname: object_name
+
+# create a group based on the operating system defined in a custom variable
+keyed_groups:
+  - prefix: os
+    key: vars.HostOS
+
+# create groups based on jinja templates
+# here we create a group called "rb" if the host variable "check_period" is "24/7"
+groups:
+  rb: check_period == "24/7"
 """
 
 
-from ansible.plugins.inventory import BaseInventoryPlugin
+from ansible.plugins.inventory import BaseInventoryPlugin, Constructable
 
 from ansible.module_utils.urls import open_url
 import json
 
 
-class InventoryModule(BaseInventoryPlugin):
+class InventoryModule(BaseInventoryPlugin, Constructable):
     NAME = "t_systems_mms.icinga_director.icinga_director_inventory"
 
     def call_url(self, url, url_username, url_password, url_path):
@@ -89,21 +109,6 @@ class InventoryModule(BaseInventoryPlugin):
                 return True
         return False
 
-    def set_hosts(self):
-        host_list = self.call_url(
-            self.url,
-            self.url_username,
-            self.url_password,
-            url_path="/director/hosts" + "?resolved",
-        )
-
-        for host in host_list["objects"]:
-            self.inventory.add_host(host["object_name"])
-            for item in host:
-                self.inventory.set_variable(
-                    host["object_name"], item, host[item]
-                )
-
     def add_hosts_to_groups(self):
         hostgroups = self.set_hostgroups()
 
@@ -149,6 +154,46 @@ class InventoryModule(BaseInventoryPlugin):
         self.url_username = self.get_option("url_username")
         self.url_password = self.get_option("url_password")
         self.force_basic_auth = self.get_option("force_basic_auth")
+        strict = self.get_option("strict")
+        compose = self.get_option("compose")
+
+        host_list = self.call_url(
+            self.url,
+            self.url_username,
+            self.url_password,
+            url_path="/director/hosts" + "?resolved",
+        )
+
+        for host in host_list["objects"]:
+            self.inventory.add_host(host["object_name"], group="all")
+            for item in host:
+                self.inventory.set_variable(
+                    host["object_name"], item, host[item]
+                )
+
+            host_vars = self.inventory.get_host(host["object_name"]).get_vars()
+
+            # Add variables created by the user's Jinja2 expressions to the host
+            self._set_composite_vars(
+                compose,
+                host_vars,
+                host["object_name"],
+                strict=strict,
+            )
+
+            # The following two methods combine the provided variables dictionary with the latest host variables
+            # Using these methods after _set_composite_vars() allows groups to be created with the composed variables
+            self._add_host_to_composed_groups(
+                self.get_option("groups"),
+                host_vars,
+                host["object_name"],
+                strict=strict,
+            )
+            self._add_host_to_keyed_groups(
+                self.get_option("keyed_groups"),
+                host_vars,
+                host["object_name"],
+                strict=strict,
+            )
 
-        self.set_hosts()
         self.add_hosts_to_groups()
