@@ -575,6 +575,21 @@ class ForemanAnsibleModule(AnsibleModule):
             _organization_create['params'].append(_ignore_types_param)
             _organization_update['params'].append(_ignore_types_param)
 
+    @_check_patch_needed(fixed_version='3.8.0', plugins=['katello'])
+    def _patch_products_repositories_allow_nil_credential(self):
+        """
+        This is a workaround for the missing allow_nil: true in the Products and Repositories controllers
+        See https://projects.theforeman.org/issues/36497
+        """
+
+        for resource in ['products', 'repositories']:
+            methods = self.foremanapi.apidoc['docs']['resources'][resource]['methods']
+            for action in ['create', 'update']:
+                resource_action = next(x for x in methods if x['name'] == action)
+                for param in ['gpg_key_id', 'ssl_ca_cert_id', 'ssl_client_cert_id', 'ssl_client_key_id']:
+                    resource_param = next(x for x in resource_action['params'] if x['name'] == param)
+                    resource_param['allow_nil'] = True
+
     def check_requirements(self):
         if not HAS_APYPIE:
             self.fail_json(msg=missing_required_lib("requests"), exception=APYPIE_IMP_ERR)
@@ -620,6 +635,7 @@ class ForemanAnsibleModule(AnsibleModule):
         self._patch_cv_filter_rule_api()
         self._patch_ak_product_content_per_page()
         self._patch_organization_ignore_types_api()
+        self._patch_products_repositories_allow_nil_credential()
 
     @_exception2fail_json(msg="Failed to connect to Foreman server: {0}")
     def status(self):
@@ -775,7 +791,8 @@ class ForemanAnsibleModule(AnsibleModule):
 
         # workaround for https://projects.theforeman.org/issues/31874
         if compute_resource['provider'].lower() == 'vmware':
-            cluster['_api_identifier'] = cluster['name']
+            path_or_name = cluster.get('full_path', cluster['name'])
+            cluster['_api_identifier'] = path_or_name
         else:
             cluster['_api_identifier'] = cluster['id']
 
@@ -799,11 +816,18 @@ class ForemanAnsibleModule(AnsibleModule):
 
         additional_params = {'id': compute_resource['id']}
         if cluster is not None:
-            additional_params['cluster_id'] = cluster['_api_identifier']
+            # apypie will quote the params for us, but we need to do it twice for the cluster_id
+            # see https://projects.theforeman.org/issues/35438
+            # and https://github.com/theforeman/hammer-cli-foreman/pull/604
+            # and https://github.com/theforeman/foreman/pull/9383
+            # and https://httpd.apache.org/docs/current/mod/core.html#allowencodedslashes
+            additional_params['cluster_id'] = six.moves.urllib.parse.quote(cluster['_api_identifier'], safe='')
         api_name = 'available_{0}'.format(part_name)
         available_parts = self.resource_action('compute_resources', api_name, params=additional_params,
                                                ignore_check_mode=True, record_change=False)['results']
-        part = next((part for part in available_parts if str(part['name']) == str(name) or str(part['id']) == str(name)), None)
+        part = next((part for part in available_parts
+                     if str(part['name']) == str(name) or str(part['id']) == str(name) or part.get('full_path') == str(name)),
+                    None)
         if part is None:
             err_msg = "Could not find {0} '{1}' on compute resource '{2}'.".format(part_name, name, compute_resource.get('name'))
             self.fail_json(msg=err_msg)
@@ -834,6 +858,8 @@ class ForemanAnsibleModule(AnsibleModule):
         return result
 
     def _lookup_entity(self, identifier, entity_spec, params=None):
+        if identifier is NoEntity:
+            return NoEntity
         resource_type = entity_spec['resource_type']
         failsafe = entity_spec.get('failsafe', False)
         thin = entity_spec.get('thin', True)
@@ -1290,8 +1316,8 @@ class ForemanStatelessEntityAnsibleModule(ForemanAnsibleModule):
         ))[0])
 
         if 'parent' in self.foreman_spec and self.foreman_spec['parent'].get('type') == 'entity':
-            if 'resouce_type' not in self.foreman_spec['parent']:
-                self.foreman_spec['parent']['resource_type'] = self.foreman_spec['entity']['resource_type']
+            # ensure parent and entity are the same type
+            self.foreman_spec['parent']['resource_type'] = self.foreman_spec['entity']['resource_type']
             if 'failsafe' not in self.foreman_spec['parent']:
                 self.foreman_spec['parent']['failsafe'] = True
             current, parent = split_fqn(self.foreman_params[self.entity_key])
@@ -1530,6 +1556,78 @@ class KatelloEntityAnsibleModule(KatelloScopedMixin, ForemanEntityAnsibleModule)
     pass
 
 
+class KatelloContentExportBaseModule(KatelloAnsibleModule):
+
+    def __init__(self, **kwargs):
+        foreman_spec = dict(
+            chunk_size_gb=dict(required=False, type='int'),
+            format=dict(required=False, type='str', choices=['syncable', 'importable']),
+            from_history_id=dict(required=False, type='int'),
+        )
+        argument_spec = dict(
+            incremental=dict(required=False, type='bool'),
+        )
+
+        foreman_spec.update(kwargs.pop('foreman_spec', {}))
+        argument_spec.update(kwargs.pop('argument_spec', {}))
+
+        self.export_action = kwargs.pop('export_action')
+
+        super(KatelloContentExportBaseModule, self).__init__(foreman_spec=foreman_spec, argument_spec=argument_spec, **kwargs)
+
+        # needs to happen after super().__init__()
+        self.task_timeout = 12 * 60 * 60
+
+    def run(self, **kwargs):
+        incremental = self.params['incremental']
+        endpoint = 'content_export_incrementals' if incremental else 'content_exports'
+
+        if self.params.get('from_history_id') and incremental is not True:
+            self.fail_json(msg='from_history_id is only valid for incremental exports')
+
+        self.auto_lookup_entities()
+
+        payload = _flatten_entity(self.foreman_params, self.foreman_spec)
+        task = self.resource_action(endpoint, self.export_action, payload)
+
+        self.exit_json(task=task)
+
+
+class KatelloContentImportBaseModule(KatelloAnsibleModule):
+
+    def __init__(self, **kwargs):
+        foreman_spec = dict(
+            path=dict(required=True, type='str'),
+            metadata_file=dict(required=False, type='str'),
+            metadata=dict(required=False, type='dict')
+        )
+        argument_spec = {}
+        foreman_spec.update(kwargs.pop('foreman_spec', {}))
+        argument_spec.update(kwargs.pop('argument_spec', {}))
+
+        self.import_action = kwargs.pop('import_action')
+
+        super(KatelloContentImportBaseModule, self).__init__(foreman_spec=foreman_spec,
+                                                             required_one_of=[['metadata', 'metadata_file']],
+                                                             argument_spec=argument_spec, **kwargs)
+
+        # needs to happen after super().__init__()
+        self.task_timeout = 12 * 60 * 60
+
+    def run(self, **kwargs):
+        metadata_file = self.params.get('metadata_file')
+        self.auto_lookup_entities()
+        payload = _flatten_entity(self.foreman_params, self.foreman_spec)
+
+        if payload.get("metadata") is None and metadata_file:
+            payload["metadata"] = json.load(open(metadata_file))
+            payload.pop("metadata_file")
+
+        endpoint = 'content_imports'
+        task = self.resource_action(endpoint, self.import_action, payload)
+        self.exit_json(task=task)
+
+
 def _foreman_spec_helper(spec):
     """Extend an entity spec by adding entries for all flat_names.
     Extract Ansible compatible argument_spec on the way.
@@ -1706,7 +1804,7 @@ def parameters_list_to_str_list(parameters):
     filtered_params = []
     for param in parameters:
         new_param = {k: v for (k, v) in param.items() if k in parameter_ansible_spec.keys()}
-        new_param['value'] = parameter_value_to_str(new_param['value'], new_param['parameter_type'])
+        new_param['value'] = parameter_value_to_str(new_param['value'], new_param.get('parameter_type', 'string'))
         filtered_params.append(new_param)
     return filtered_params
 
@@ -1843,6 +1941,7 @@ interfaces_spec = dict(
     managed=dict(type='bool'),
     primary=dict(type='bool'),
     provision=dict(type='bool'),
+    execution=dict(type='bool'),
     username=dict(),
     password=dict(no_log=True),
     provider=dict(choices=['IPMI', 'Redfish', 'SSH']),
